@@ -108,9 +108,9 @@ DFLT_LOG_FMT_LOGFILE = "%(asctime)s,%(msecs)03d [%(name)-17s:%(lineno)-4d][%(lev
 class SaltLogRecord(logging.LogRecord):
     def __init__(self, *args, **kwargs):
         logging.LogRecord.__init__(self, *args, **kwargs)
-        self.bracketname = "[{:<17}]".format(str(self.name))
-        self.bracketlevel = "[{:<8}]".format(str(self.levelname))
-        self.bracketprocess = "[{:>5}]".format(str(self.process))
+        self.bracketname = f"[{str(self.name):<17}]"
+        self.bracketlevel = f"[{str(self.levelname):<8}]"
+        self.bracketprocess = f"[{str(self.process):>5}]"
 
 
 class SaltColorLogRecord(SaltLogRecord):
@@ -124,11 +124,11 @@ class SaltColorLogRecord(SaltLogRecord):
         self.colorname = "{}[{:<17}]{}".format(
             LOG_COLORS["name"], str(self.name), reset
         )
-        self.colorlevel = "{}[{:<8}]{}".format(clevel, str(self.levelname), reset)
+        self.colorlevel = f"{clevel}[{str(self.levelname):<8}]{reset}"
         self.colorprocess = "{}[{:>5}]{}".format(
             LOG_COLORS["process"], str(self.process), reset
         )
-        self.colormsg = "{}{}{}".format(cmsg, self.getMessage(), reset)
+        self.colormsg = f"{cmsg}{self.getMessage()}{reset}"
 
 
 def get_log_record_factory():
@@ -169,7 +169,7 @@ class SaltLoggingClass(LOGGING_LOGGER_CLASS, metaclass=LoggingMixinMeta):
             logging.getLogger(__name__)
 
         """
-        instance = super().__new__(cls)
+        instance = super().__new__(cls)  # pylint: disable=no-value-for-parameter
 
         try:
             max_logger_length = len(
@@ -726,7 +726,7 @@ def setup_logfile_handler(
                     syslog_opts["address"] = str(path.resolve().parent)
             except OSError as exc:
                 raise LoggingRuntimeError(
-                    "Failed to setup the Syslog logging handler: {}".format(exc)
+                    f"Failed to setup the Syslog logging handler: {exc}"
                 ) from exc
         elif parsed_log_path.path:
             # In case of udp or tcp with a facility specified
@@ -736,7 +736,7 @@ def setup_logfile_handler(
                 # Logging facilities start with LOG_ if this is not the case
                 # fail right now!
                 raise LoggingRuntimeError(
-                    "The syslog facility '{}' is not known".format(facility_name)
+                    f"The syslog facility '{facility_name}' is not known"
                 )
         else:
             # This is the case of udp or tcp without a facility specified
@@ -747,7 +747,7 @@ def setup_logfile_handler(
             # This python syslog version does not know about the user provided
             # facility name
             raise LoggingRuntimeError(
-                "The syslog facility '{}' is not known".format(facility_name)
+                f"The syslog facility '{facility_name}' is not known"
             )
         syslog_opts["facility"] = facility
 
@@ -767,7 +767,7 @@ def setup_logfile_handler(
             handler = SysLogHandler(**syslog_opts)
         except OSError as exc:
             raise LoggingRuntimeError(
-                "Failed to setup the Syslog logging handler: {}".format(exc)
+                f"Failed to setup the Syslog logging handler: {exc}"
             ) from exc
     else:
         # make sure, the logging directory exists and attempt to create it if necessary
