@@ -1,15 +1,12 @@
-# -*- coding: utf-8 -*-
 """
 Provide authentication using OpenStack Keystone
 
 :depends:   - keystoneclient Python module
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
-
 try:
-    from keystoneclient.v2_0 import client
     from keystoneclient.exceptions import AuthorizationFailure, Unauthorized
+    from keystoneclient.v2_0 import client
 except ImportError:
     pass
 
