@@ -13,6 +13,7 @@ import time
 import salt.defaults.exitcodes
 import salt.utils.json
 import salt.utils.nb_popen
+import salt.utils.path
 import salt.utils.vt
 
 log = logging.getLogger(__name__)
@@ -33,12 +34,16 @@ SUDO_PROMPT_RE = re.compile(
 RSTR = "_edbc7885e4f9aac9b83b35999b68d015148caf467b78fa39c05f669c0ff89878"
 RSTR_RE = re.compile(r"(?:^|\r?\n)" + RSTR + r"(?:\r?\n|$)")
 
+SSH_KEYGEN_PATH = salt.utils.path.which("ssh-keygen") or "ssh-keygen"
+SSH_PATH = salt.utils.path.which("ssh") or "ssh"
+SCP_PATH = salt.utils.path.which("scp") or "scp"
+
 
 def gen_key(path):
     """
     Generate a key for use with salt-ssh
     """
-    cmd = ["ssh-keygen", "-P", "", "-f", path, "-t", "rsa", "-q"]
+    cmd = [SSH_KEYGEN_PATH, "-P", "", "-f", path, "-t", "rsa", "-q"]
     dirname = os.path.dirname(path)
     if dirname and not os.path.isdir(dirname):
         os.makedirs(os.path.dirname(path))
@@ -127,26 +132,26 @@ class Shell:
             options.append("PasswordAuthentication=yes")
         else:
             options.append("PasswordAuthentication=no")
-        options.append("ConnectTimeout={}".format(self.timeout))
+        options.append(f"ConnectTimeout={self.timeout}")
         if self.opts.get("ignore_host_keys"):
             options.append("StrictHostKeyChecking=no")
         if self.opts.get("no_host_keys"):
             options.extend(["StrictHostKeyChecking=no", "UserKnownHostsFile=/dev/null"])
         known_hosts = self.opts.get("known_hosts_file")
         if known_hosts and os.path.isfile(known_hosts):
-            options.append("UserKnownHostsFile={}".format(known_hosts))
+            options.append(f"UserKnownHostsFile={known_hosts}")
         if self.port:
-            options.append("Port={}".format(self.port))
+            options.append(f"Port={self.port}")
         if self.priv and self.priv != "agent-forwarding":
-            options.append("IdentityFile={}".format(self.priv))
+            options.append(f"IdentityFile={self.priv}")
         if self.user:
-            options.append("User={}".format(self.user))
+            options.append(f"User={self.user}")
         if self.identities_only:
             options.append("IdentitiesOnly=yes")
 
         ret = []
         for option in options:
-            ret.append("-o {} ".format(option))
+            ret.append(f"-o {option} ")
         return "".join(ret)
 
     def _passwd_opts(self):
@@ -160,7 +165,7 @@ class Shell:
             "ControlMaster=auto",
             "StrictHostKeyChecking=no",
         ]
-        options.append("ConnectTimeout={}".format(self.timeout))
+        options.append(f"ConnectTimeout={self.timeout}")
         if self.opts.get("ignore_host_keys"):
             options.append("StrictHostKeyChecking=no")
         if self.opts.get("no_host_keys"):
@@ -179,19 +184,19 @@ class Shell:
                 ]
             )
         if self.port:
-            options.append("Port={}".format(self.port))
+            options.append(f"Port={self.port}")
         if self.user:
-            options.append("User={}".format(self.user))
+            options.append(f"User={self.user}")
         if self.identities_only:
             options.append("IdentitiesOnly=yes")
 
         ret = []
         for option in options:
-            ret.append("-o {} ".format(option))
+            ret.append(f"-o {option} ")
         return "".join(ret)
 
     def _ssh_opts(self):
-        return " ".join(["-o {}".format(opt) for opt in self.ssh_options])
+        return " ".join([f"-o {opt}" for opt in self.ssh_options])
 
     def _copy_id_str_old(self):
         """
@@ -202,7 +207,7 @@ class Shell:
             # passwords containing '$'
             return "{} {} '{} -p {} {} {}@{}'".format(
                 "ssh-copy-id",
-                "-i {}.pub".format(self.priv),
+                f"-i {self.priv}.pub",
                 self._passwd_opts(),
                 self.port,
                 self._ssh_opts(),
@@ -221,7 +226,7 @@ class Shell:
             # passwords containing '$'
             return "{} {} {} -p {} {} {}@{}".format(
                 "ssh-copy-id",
-                "-i {}.pub".format(self.priv),
+                f"-i {self.priv}.pub",
                 self._passwd_opts(),
                 self.port,
                 self._ssh_opts(),
@@ -239,7 +244,7 @@ class Shell:
             stdout, stderr, retcode = self._run_cmd(self._copy_id_str_new())
         return stdout, stderr, retcode
 
-    def _cmd_str(self, cmd, ssh="ssh"):
+    def _cmd_str(self, cmd, ssh=SSH_PATH):
         """
         Return the cmd string to execute
         """
@@ -248,19 +253,16 @@ class Shell:
         # need to deliver the SHIM to the remote host and execute it there
 
         command = [ssh]
-        if ssh != "scp":
+        if ssh != SCP_PATH:
             command.append(self.host)
-        if self.tty and ssh == "ssh":
+        if self.tty and ssh == SSH_PATH:
             command.append("-t -t")
         if self.passwd or self.priv:
             command.append(self.priv and self._key_opts() or self._passwd_opts())
-        if ssh != "scp" and self.remote_port_forwards:
+        if ssh != SCP_PATH and self.remote_port_forwards:
             command.append(
                 " ".join(
-                    [
-                        "-R {}".format(item)
-                        for item in self.remote_port_forwards.split(",")
-                    ]
+                    [f"-R {item}" for item in self.remote_port_forwards.split(",")]
                 )
             )
         if self.ssh_options:
@@ -302,7 +304,7 @@ class Shell:
         rcode = None
         cmd = self._cmd_str(cmd)
 
-        logmsg = "Executing non-blocking command: {}".format(cmd)
+        logmsg = f"Executing non-blocking command: {cmd}"
         if self.passwd:
             logmsg = logmsg.replace(self.passwd, ("*" * 6))
         log.debug(logmsg)
@@ -321,7 +323,7 @@ class Shell:
         """
         cmd = self._cmd_str(cmd)
 
-        logmsg = "Executing command: {}".format(cmd)
+        logmsg = f"Executing command: {cmd}"
         if self.passwd:
             logmsg = logmsg.replace(self.passwd, ("*" * 6))
         if 'decode("base64")' in logmsg or "base64.b64decode(" in logmsg:
@@ -338,17 +340,17 @@ class Shell:
         scp a file or files to a remote system
         """
         if makedirs:
-            self.exec_cmd("mkdir -p {}".format(os.path.dirname(remote)))
+            self.exec_cmd(f"mkdir -p {os.path.dirname(remote)}")
 
         # scp needs [<ipv6}
         host = self.host
         if ":" in host:
-            host = "[{}]".format(host)
+            host = f"[{host}]"
 
-        cmd = "{} {}:{}".format(local, host, remote)
-        cmd = self._cmd_str(cmd, ssh="scp")
+        cmd = f"{local} {host}:{remote}"
+        cmd = self._cmd_str(cmd, ssh=SCP_PATH)
 
-        logmsg = "Executing command: {}".format(cmd)
+        logmsg = f"Executing command: {cmd}"
         if self.passwd:
             logmsg = logmsg.replace(self.passwd, ("*" * 6))
         log.debug(logmsg)
@@ -367,7 +369,7 @@ class Shell:
             cmd_lst = shlex.split(cmd)
         else:
             cmd_lst = shlex.split(ssh_part)
-            cmd_lst.append("/bin/sh {}".format(cmd_part))
+            cmd_lst.append(f"/bin/sh {cmd_part}")
         return cmd_lst
 
     def _run_cmd(self, cmd, key_accept=False, passwd_retries=3):
