@@ -8,6 +8,13 @@ Azure ARM Cloud Module
 
 The Azure ARM cloud module is used to control access to Microsoft Azure Resource Manager
 
+.. warning::
+
+    This cloud provider will be removed from Salt in version 3007 in favor of
+    the `saltext.azurerm Salt Extension
+    <https://github.com/salt-extensions/saltext-azurerm>`_
+
+:maintainer: <devops@eitr.tech>
 :depends:
     * `azure <https://pypi.python.org/pypi/azure>`_ >= 2.0.0rc6
     * `azure-common <https://pypi.python.org/pypi/azure-common>`_ >= 1.1.4
@@ -95,6 +102,7 @@ import os.path
 import pprint
 import string
 import time
+from functools import wraps
 from multiprocessing import cpu_count
 from multiprocessing.pool import ThreadPool
 
@@ -156,6 +164,28 @@ def _get_active_provider_name():
         return __active_provider_name__
 
 
+def _deprecation_message(function):
+    """
+    Decorator wrapper to warn about msazure deprecation
+    """
+
+    @wraps(function)
+    def wrapped(*args, **kwargs):
+        salt.utils.versions.warn_until(
+            "Chlorine",
+            "This cloud provider will be removed from Salt in version 3007 due to "
+            "the deprecation of the 'Classic' API for Azure. Please migrate to "
+            "Azure Resource Manager by March 1, 2023 "
+            "(https://docs.microsoft.com/en-us/azure/virtual-machines/classic-vm-deprecation)",
+            category=FutureWarning,
+        )
+        ret = function(*args, **salt.utils.args.clean_kwargs(**kwargs))
+        return ret
+
+    return wrapped
+
+
+@_deprecation_message
 def get_api_versions(call=None, kwargs=None):  # pylint: disable=unused-argument
     """
     Get a resource type api versions
@@ -187,6 +217,7 @@ def get_api_versions(call=None, kwargs=None):  # pylint: disable=unused-argument
     return api_versions
 
 
+@_deprecation_message
 def get_resource_by_id(resource_id, api_version, extract_value=None):
     """
     Get an AzureARM resource by id
@@ -222,7 +253,9 @@ def get_configured_provider():
 
     for combo in key_combos:
         provider = config.is_provider_configured(
-            __opts__, _get_active_provider_name() or __virtualname__, combo,
+            __opts__,
+            _get_active_provider_name() or __virtualname__,
+            combo,
         )
 
         if provider:
@@ -231,6 +264,7 @@ def get_configured_provider():
     return provider
 
 
+@_deprecation_message
 def get_dependencies():
     """
     Warn if dependencies aren't met.
@@ -238,6 +272,7 @@ def get_dependencies():
     return config.check_driver_dependencies(__virtualname__, {"azurearm": HAS_LIBS})
 
 
+@_deprecation_message
 def get_conn(client_type):
     """
     Return a connection object for a client type.
@@ -285,6 +320,7 @@ def get_conn(client_type):
     return client
 
 
+@_deprecation_message
 def get_location(call=None, kwargs=None):  # pylint: disable=unused-argument
     """
     Return the location that is configured for this provider
@@ -298,6 +334,7 @@ def get_location(call=None, kwargs=None):  # pylint: disable=unused-argument
     )
 
 
+@_deprecation_message
 def avail_locations(call=None):
     """
     Return a dict of all available regions.
@@ -331,6 +368,7 @@ def avail_locations(call=None):
     return ret
 
 
+@_deprecation_message
 def avail_images(call=None):
     """
     Return a dict of all available images on the provider
@@ -352,12 +390,15 @@ def avail_images(call=None):
         data = {}
         try:
             offers = compconn.virtual_machine_images.list_offers(
-                location=region, publisher_name=publisher,
+                location=region,
+                publisher_name=publisher,
             )
             for offer_obj in offers:
                 offer = offer_obj.as_dict()
                 skus = compconn.virtual_machine_images.list_skus(
-                    location=region, publisher_name=publisher, offer=offer["name"],
+                    location=region,
+                    publisher_name=publisher,
+                    offer=offer["name"],
                 )
                 for sku_obj in skus:
                     sku = sku_obj.as_dict()
@@ -370,7 +411,12 @@ def avail_images(call=None):
                     for version_obj in results:
                         version = version_obj.as_dict()
                         name = "|".join(
-                            (publisher, offer["name"], sku["name"], version["name"],)
+                            (
+                                publisher,
+                                offer["name"],
+                                sku["name"],
+                                version["name"],
+                            )
                         )
                         data[name] = {
                             "publisher": publisher,
@@ -403,6 +449,7 @@ def avail_images(call=None):
     return ret
 
 
+@_deprecation_message
 def avail_sizes(call=None):
     """
     Return a list of sizes available from the provider
@@ -430,6 +477,7 @@ def avail_sizes(call=None):
     return ret
 
 
+@_deprecation_message
 def list_nodes(call=None):
     """
     List VMs on this Azure account
@@ -449,6 +497,7 @@ def list_nodes(call=None):
     return ret
 
 
+@_deprecation_message
 def list_nodes_full(call=None):
     """
     List all VMs on the subscription with full information
@@ -534,13 +583,14 @@ def list_nodes_full(call=None):
     return ret
 
 
+@_deprecation_message
 def list_resource_groups(call=None):
     """
     List resource groups associated with the subscription
     """
     if call == "action":
         raise SaltCloudSystemExit(
-            "The list_hosted_services function must be called with " "-f or --function"
+            "The list_hosted_services function must be called with -f or --function"
         )
 
     resconn = get_conn(client_type="resource")
@@ -558,6 +608,7 @@ def list_resource_groups(call=None):
     return ret
 
 
+@_deprecation_message
 def show_instance(name, call=None):
     """
     Show the details from AzureARM concerning an instance
@@ -577,6 +628,7 @@ def show_instance(name, call=None):
     return node
 
 
+@_deprecation_message
 def delete_interface(call=None, kwargs=None):  # pylint: disable=unused-argument
     """
     Delete a network interface.
@@ -593,14 +645,16 @@ def delete_interface(call=None, kwargs=None):  # pylint: disable=unused-argument
 
     ips = []
     iface = netconn.network_interfaces.get(
-        kwargs["resource_group"], kwargs["iface_name"],
+        kwargs["resource_group"],
+        kwargs["iface_name"],
     )
     iface_name = iface.name
     for ip_ in iface.ip_configurations:
         ips.append(ip_.name)
 
     poller = netconn.network_interfaces.delete(
-        kwargs["resource_group"], kwargs["iface_name"],
+        kwargs["resource_group"],
+        kwargs["iface_name"],
     )
     poller.wait()
 
@@ -661,6 +715,7 @@ def _get_network_interface(name, resource_group):
     return netiface, public_ips, private_ips
 
 
+@_deprecation_message
 def create_network_interface(call=None, kwargs=None):
     """
     Create a network interface.
@@ -735,7 +790,9 @@ def create_network_interface(call=None, kwargs=None):
                 for pool in be_pools:
                     try:
                         lbbep_data = netconn.load_balancer_backend_address_pools.get(
-                            kwargs["resource_group"], load_bal, pool,
+                            kwargs["resource_group"],
+                            load_bal,
+                            pool,
                         )
                         pool_ids.append({"id": lbbep_data.as_dict()["id"]})
                     except CloudError as exc:
@@ -768,7 +825,8 @@ def create_network_interface(call=None, kwargs=None):
         while True:
             try:
                 pub_ip_data = netconn.public_ip_addresses.get(
-                    kwargs["resource_group"], pub_ip_name,
+                    kwargs["resource_group"],
+                    pub_ip_name,
                 )
                 if pub_ip_data.ip_address:  # pylint: disable=no-member
                     ip_kwargs["public_ip_address"] = PublicIPAddress(
@@ -778,7 +836,7 @@ def create_network_interface(call=None, kwargs=None):
                         NetworkInterfaceIPConfiguration(
                             name="{}-ip".format(kwargs["iface_name"]),
                             subnet=subnet_obj,
-                            **ip_kwargs
+                            **ip_kwargs,
                         )
                     ]
                     break
@@ -834,7 +892,7 @@ def create_network_interface(call=None, kwargs=None):
             time.sleep(5)
 
 
-def request_instance(vm_):
+def request_instance(vm_, kwargs=None):
     """
     Request a VM from Azure.
     """
@@ -921,8 +979,9 @@ def request_instance(vm_):
                 ssh_publickeyfile_contents = spkc_.read()
         except Exception as exc:  # pylint: disable=broad-except
             raise SaltCloudConfigError(
-                "Failed to read ssh publickey file '{}': "
-                "{}".format(ssh_publickeyfile, exc.args[-1])
+                "Failed to read ssh publickey file '{}': {}".format(
+                    ssh_publickeyfile, exc.args[-1]
+                )
             )
 
     disable_password_authentication = config.get_cloud_config_value(
@@ -940,9 +999,11 @@ def request_instance(vm_):
     if not win_installer and ssh_publickeyfile_contents is not None:
         sshpublickey = SshPublicKey(
             key_data=ssh_publickeyfile_contents,
-            path="/home/{}/.ssh/authorized_keys".format(vm_username),
+            path=f"/home/{vm_username}/.ssh/authorized_keys",
+        )
+        sshconfiguration = SshConfiguration(
+            public_keys=[sshpublickey],
         )
-        sshconfiguration = SshConfiguration(public_keys=[sshpublickey],)
         linuxconfiguration = LinuxConfiguration(
             disable_password_authentication=disable_password_authentication,
             ssh=sshconfiguration,
@@ -1074,7 +1135,10 @@ def request_instance(vm_):
             if "|" in vm_["image"]:
                 img_pub, img_off, img_sku, img_ver = vm_["image"].split("|")
                 img_ref = ImageReference(
-                    publisher=img_pub, offer=img_off, sku=img_sku, version=img_ver,
+                    publisher=img_pub,
+                    offer=img_off,
+                    sku=img_sku,
+                    version=img_ver,
                 )
             elif vm_["image"].startswith("/subscriptions"):
                 img_ref = ImageReference(id=vm_["image"])
@@ -1088,7 +1152,9 @@ def request_instance(vm_):
             name=disk_name,
             vhd=VirtualHardDisk(
                 uri="https://{}.blob.{}/vhds/{}.vhd".format(
-                    vm_["storage_account"], storage_endpoint_suffix, disk_name,
+                    vm_["storage_account"],
+                    storage_endpoint_suffix,
+                    disk_name,
                 ),
             ),
             os_type=os_type,
@@ -1105,7 +1171,10 @@ def request_instance(vm_):
         if "|" in vm_["image"]:
             img_pub, img_off, img_sku, img_ver = vm_["image"].split("|")
             img_ref = ImageReference(
-                publisher=img_pub, offer=img_off, sku=img_sku, version=img_ver,
+                publisher=img_pub,
+                offer=img_off,
+                sku=img_sku,
+                version=img_ver,
             )
         elif vm_["image"].startswith("/subscriptions"):
             img_ref = ImageReference(id=vm_["image"])
@@ -1189,10 +1258,12 @@ def request_instance(vm_):
         location=vm_["location"],
         plan=None,
         hardware_profile=HardwareProfile(
-            vm_size=getattr(VirtualMachineSizeTypes, vm_["size"].lower()),
+            vm_size=getattr(VirtualMachineSizeTypes, vm_["size"].lower(), kwargs),
         ),
         storage_profile=StorageProfile(
-            os_disk=os_disk, data_disks=data_disks, image_reference=img_ref,
+            os_disk=os_disk,
+            data_disks=data_disks,
+            image_reference=img_ref,
         ),
         os_profile=OSProfile(
             admin_username=vm_username, computer_name=vm_["name"], **os_kwargs
@@ -1232,6 +1303,7 @@ def request_instance(vm_):
     return vm_result
 
 
+@_deprecation_message
 def create(vm_):
     """
     Create a single VM from a data dict.
@@ -1298,7 +1370,10 @@ def create(vm_):
     try:
         data = salt.utils.cloud.wait_for_ip(
             _query_node_data,
-            update_args=(vm_["name"], vm_["bootstrap_interface"],),
+            update_args=(
+                vm_["name"],
+                vm_["bootstrap_interface"],
+            ),
             timeout=config.get_cloud_config_value(
                 "wait_for_ip_timeout", vm_, __opts__, default=10 * 60
             ),
@@ -1347,6 +1422,7 @@ def create(vm_):
     return ret
 
 
+@_deprecation_message
 def destroy(name, call=None, kwargs=None):  # pylint: disable=unused-argument
     """
     Destroy a VM.
@@ -1363,7 +1439,7 @@ def destroy(name, call=None, kwargs=None):  # pylint: disable=unused-argument
 
     if call == "function":
         raise SaltCloudSystemExit(
-            "The destroy action must be called with -d, --destroy, " "-a or --action."
+            "The destroy action must be called with -d, --destroy, -a or --action."
         )
 
     compconn = get_conn(client_type="compute")
@@ -1507,13 +1583,14 @@ def destroy(name, call=None, kwargs=None):  # pylint: disable=unused-argument
     return ret
 
 
+@_deprecation_message
 def list_storage_accounts(call=None):
     """
     List storage accounts within the subscription.
     """
     if call == "action":
         raise SaltCloudSystemExit(
-            "The list_storage_accounts function must be called with " "-f or --function"
+            "The list_storage_accounts function must be called with -f or --function"
         )
 
     storconn = get_conn(client_type="storage")
@@ -1543,7 +1620,7 @@ def _get_cloud_environment():
         cloud_env = getattr(cloud_env_module, cloud_environment or "AZURE_PUBLIC_CLOUD")
     except (AttributeError, ImportError):
         raise SaltCloudSystemExit(
-            "The azure {} cloud environment is not available.".format(cloud_environment)
+            f"The azure {cloud_environment} cloud environment is not available."
         )
 
     return cloud_env
@@ -1592,6 +1669,7 @@ def _get_block_blob_service(kwargs=None):
     )
 
 
+@_deprecation_message
 def list_blobs(call=None, kwargs=None):  # pylint: disable=unused-argument
     """
     List blobs.
@@ -1618,6 +1696,7 @@ def list_blobs(call=None, kwargs=None):  # pylint: disable=unused-argument
     return ret
 
 
+@_deprecation_message
 def delete_blob(call=None, kwargs=None):  # pylint: disable=unused-argument
     """
     Delete a blob from a container.
@@ -1637,6 +1716,7 @@ def delete_blob(call=None, kwargs=None):  # pylint: disable=unused-argument
     return True
 
 
+@_deprecation_message
 def delete_managed_disk(call=None, kwargs=None):  # pylint: disable=unused-argument
     """
     Delete a managed disk from a resource group.
@@ -1648,13 +1728,16 @@ def delete_managed_disk(call=None, kwargs=None):  # pylint: disable=unused-argum
         compconn.disks.delete(kwargs["resource_group"], kwargs["blob"])
     except Exception as exc:  # pylint: disable=broad-except
         log.error(
-            "Error deleting managed disk %s - %s", kwargs.get("blob"), str(exc),
+            "Error deleting managed disk %s - %s",
+            kwargs.get("blob"),
+            str(exc),
         )
         return False
 
     return True
 
 
+@_deprecation_message
 def list_virtual_networks(call=None, kwargs=None):
     """
     List virtual networks.
@@ -1664,7 +1747,7 @@ def list_virtual_networks(call=None, kwargs=None):
 
     if call == "action":
         raise SaltCloudSystemExit(
-            "The avail_sizes function must be called with " "-f or --function"
+            "The avail_sizes function must be called with -f or --function"
         )
 
     netconn = get_conn(client_type="network")
@@ -1686,6 +1769,7 @@ def list_virtual_networks(call=None, kwargs=None):
     return ret
 
 
+@_deprecation_message
 def list_subnets(call=None, kwargs=None):
     """
     List subnets in a virtual network.
@@ -1695,7 +1779,7 @@ def list_subnets(call=None, kwargs=None):
 
     if call == "action":
         raise SaltCloudSystemExit(
-            "The avail_sizes function must be called with " "-f or --function"
+            "The avail_sizes function must be called with -f or --function"
         )
 
     netconn = get_conn(client_type="network")
@@ -1732,6 +1816,7 @@ def list_subnets(call=None, kwargs=None):
     return ret
 
 
+@_deprecation_message
 def create_or_update_vmextension(
     call=None, kwargs=None
 ):  # pylint: disable=unused-argument
@@ -1797,7 +1882,8 @@ def create_or_update_vmextension(
         raise SaltCloudSystemExit("VM extension settings are not valid")
     elif "commandToExecute" not in settings and "script" not in settings:
         raise SaltCloudSystemExit(
-            "VM extension settings are not valid. Either commandToExecute or script must be specified."
+            "VM extension settings are not valid. Either commandToExecute or script"
+            " must be specified."
         )
 
     log.info("Creating VM extension %s", kwargs["extension_name"])
@@ -1825,13 +1911,14 @@ def create_or_update_vmextension(
     except CloudError as exc:
         salt.utils.azurearm.log_cloud_error(
             "compute",
-            "Error attempting to create the VM extension: {}".format(exc.message),
+            f"Error attempting to create the VM extension: {exc.message}",
         )
         ret = {"error": exc.message}
 
     return ret
 
 
+@_deprecation_message
 def stop(name, call=None):
     """
     .. versionadded:: 2019.2.0
@@ -1872,9 +1959,9 @@ def stop(name, call=None):
                     ret = {"error": exc.message}
         if not ret:
             salt.utils.azurearm.log_cloud_error(
-                "compute", "Unable to find virtual machine with name: {}".format(name)
+                "compute", f"Unable to find virtual machine with name: {name}"
             )
-            ret = {"error": "Unable to find virtual machine with name: {}".format(name)}
+            ret = {"error": f"Unable to find virtual machine with name: {name}"}
     else:
         try:
             instance = compconn.virtual_machines.deallocate(
@@ -1885,13 +1972,14 @@ def stop(name, call=None):
             ret = vm_result.as_dict()
         except CloudError as exc:
             salt.utils.azurearm.log_cloud_error(
-                "compute", "Error attempting to stop {}: {}".format(name, exc.message)
+                "compute", f"Error attempting to stop {name}: {exc.message}"
             )
             ret = {"error": exc.message}
 
     return ret
 
 
+@_deprecation_message
 def start(name, call=None):
     """
     .. versionadded:: 2019.2.0
@@ -1934,9 +2022,9 @@ def start(name, call=None):
                     ret = {"error": exc.message}
         if not ret:
             salt.utils.azurearm.log_cloud_error(
-                "compute", "Unable to find virtual machine with name: {}".format(name)
+                "compute", f"Unable to find virtual machine with name: {name}"
             )
-            ret = {"error": "Unable to find virtual machine with name: {}".format(name)}
+            ret = {"error": f"Unable to find virtual machine with name: {name}"}
     else:
         try:
             instance = compconn.virtual_machines.start(
@@ -1947,7 +2035,8 @@ def start(name, call=None):
             ret = vm_result.as_dict()
         except CloudError as exc:
             salt.utils.azurearm.log_cloud_error(
-                "compute", "Error attempting to start {}: {}".format(name, exc.message),
+                "compute",
+                f"Error attempting to start {name}: {exc.message}",
             )
             ret = {"error": exc.message}
 
