@@ -29,7 +29,9 @@ Set up the cloud configuration at ``/etc/salt/cloud.providers`` or
 import logging
 import pprint
 import re
+import socket
 import time
+import urllib
 
 import salt.config as config
 import salt.utils.cloud
@@ -133,9 +135,13 @@ def _authenticate():
     )
 
     connect_data = {"username": username, "password": passwd}
-    full_url = "https://{}:{}/api2/json/access/ticket".format(url, port)
+    full_url = f"https://{url}:{port}/api2/json/access/ticket"
 
-    returned_data = requests.post(full_url, verify=verify_ssl, data=connect_data).json()
+    response = requests.post(
+        full_url, verify=verify_ssl, data=connect_data, timeout=120
+    )
+    response.raise_for_status()
+    returned_data = response.json()
 
     ticket = {"PVEAuthCookie": returned_data["data"]["ticket"]}
     csrf = str(returned_data["data"]["CSRFPreventionToken"])
@@ -149,7 +155,7 @@ def query(conn_type, option, post_data=None):
         log.debug("Not authenticated yet, doing that now..")
         _authenticate()
 
-    full_url = "https://{}:{}/api2/json/{}".format(url, port, option)
+    full_url = f"https://{url}:{port}/api2/json/{option}"
 
     log.debug("%s: %s (%s)", conn_type, full_url, post_data)
 
@@ -167,6 +173,7 @@ def query(conn_type, option, post_data=None):
             data=post_data,
             cookies=ticket,
             headers=httpheaders,
+            timeout=120,
         )
     elif conn_type == "put":
         httpheaders["CSRFPreventionToken"] = csrf
@@ -176,6 +183,7 @@ def query(conn_type, option, post_data=None):
             data=post_data,
             cookies=ticket,
             headers=httpheaders,
+            timeout=120,
         )
     elif conn_type == "delete":
         httpheaders["CSRFPreventionToken"] = csrf
@@ -185,11 +193,19 @@ def query(conn_type, option, post_data=None):
             data=post_data,
             cookies=ticket,
             headers=httpheaders,
+            timeout=120,
         )
     elif conn_type == "get":
-        response = requests.get(full_url, verify=verify_ssl, cookies=ticket)
+        response = requests.get(
+            full_url, verify=verify_ssl, cookies=ticket, timeout=120
+        )
 
-    response.raise_for_status()
+    try:
+        response.raise_for_status()
+    except requests.exceptions.RequestException:
+        # Log the details of the response.
+        log.error("Error in %s query to %s:\n%s", conn_type, full_url, response.text)
+        raise
 
     try:
         returned_data = response.json()
@@ -314,7 +330,7 @@ def get_resources_nodes(call=None, resFilter=None):
             ret[name] = resource
 
     if resFilter is not None:
-        log.debug("Filter given: %s, returning requested " "resource: nodes", resFilter)
+        log.debug("Filter given: %s, returning requested resource: nodes", resFilter)
         return ret[resFilter]
 
     log.debug("Filter not given: %s, returning all resource: nodes", ret)
@@ -355,9 +371,7 @@ def get_resources_vms(call=None, resFilter=None, includeConfig=True):
                     )
 
         if time.time() > timeoutTime:
-            raise SaltCloudExecutionTimeout(
-                "FAILED to get the proxmox " "resources vms"
-            )
+            raise SaltCloudExecutionTimeout("FAILED to get the proxmox resources vms")
 
         # Carry on if there wasn't a bad resource return from Proxmox
         if not badResource:
@@ -366,7 +380,7 @@ def get_resources_vms(call=None, resFilter=None, includeConfig=True):
         time.sleep(0.5)
 
     if resFilter is not None:
-        log.debug("Filter given: %s, returning requested " "resource: nodes", resFilter)
+        log.debug("Filter given: %s, returning requested resource: nodes", resFilter)
         return ret[resFilter]
 
     log.debug("Filter not given: %s, returning all resource: nodes", ret)
@@ -436,9 +450,7 @@ def avail_images(call=None, location="local"):
 
     ret = {}
     for host_name, host_details in avail_locations().items():
-        for item in query(
-            "get", "nodes/{}/storage/{}/content".format(host_name, location)
-        ):
+        for item in query("get", f"nodes/{host_name}/storage/{location}/content"):
             ret[item["volid"]] = item
     return ret
 
@@ -520,7 +532,9 @@ def list_nodes_select(call=None):
         salt-cloud -S my-proxmox-config
     """
     return salt.utils.cloud.list_nodes_select(
-        list_nodes_full(), __opts__["query.selection"], call,
+        list_nodes_full(),
+        __opts__["query.selection"],
+        call,
     )
 
 
@@ -543,7 +557,7 @@ def _dictionary_to_stringlist(input_dict):
 
     setting1=value1,setting2=value2
     """
-    return ",".join("{}={}".format(k, input_dict[k]) for k in sorted(input_dict.keys()))
+    return ",".join(f"{k}={input_dict[k]}" for k in sorted(input_dict.keys()))
 
 
 def _reconfigure_clone(vm_, vmid):
@@ -557,18 +571,18 @@ def _reconfigure_clone(vm_, vmid):
         log.warning("Reconfiguring clones is only available under `qemu`")
         return
 
-    # TODO: Support other settings here too as these are not the only ones that can be modified after a clone operation
+    # Determine which settings can be reconfigured.
+    query_path = "nodes/{}/qemu/{}/config"
+    valid_settings = set(_get_properties(query_path.format("{node}", "{vmid}"), "POST"))
+
     log.info("Configuring cloned VM")
 
     # Modify the settings for the VM one at a time so we can see any problems with the values
     # as quickly as possible
     for setting in vm_:
-        if re.match(r"^(ide|sata|scsi)(\d+)$", setting):
-            postParams = {setting: vm_[setting]}
-            query(
-                "post", "nodes/{}/qemu/{}/config".format(vm_["host"], vmid), postParams,
-            )
-
+        postParams = None
+        if setting == "vmid":
+            pass  # vmid gets passed in the URL and can't be reconfigured
         elif re.match(r"^net(\d+)$", setting):
             # net strings are a list of comma seperated settings. We need to merge the settings so that
             # the setting in the profile only changes the settings it touches and the other settings
@@ -588,8 +602,17 @@ def _reconfigure_clone(vm_, vmid):
 
             # Convert the dictionary back into a string list
             postParams = {setting: _dictionary_to_stringlist(new_setting)}
+
+        elif setting == "sshkeys":
+            postParams = {setting: urllib.parse.quote(vm_[setting], safe="")}
+        elif setting in valid_settings:
+            postParams = {setting: vm_[setting]}
+
+        if postParams:
             query(
-                "post", "nodes/{}/qemu/{}/config".format(vm_["host"], vmid), postParams,
+                "post",
+                "nodes/{}/qemu/{}/config".format(vm_["host"], vmid),
+                postParams,
             )
 
 
@@ -637,7 +660,7 @@ def create(vm_):
     if "use_dns" in vm_ and "ip_address" not in vm_:
         use_dns = vm_["use_dns"]
         if use_dns:
-            from socket import gethostbyname, gaierror
+            from socket import gaierror, gethostbyname
 
             try:
                 ip_address = gethostbyname(str(vm_["name"]))
@@ -650,12 +673,18 @@ def create(vm_):
         newid = _get_next_vmid()
         data = create_node(vm_, newid)
     except Exception as exc:  # pylint: disable=broad-except
+        msg = str(exc)
+        if (
+            isinstance(exc, requests.exceptions.RequestException)
+            and exc.response is not None
+        ):
+            msg = msg + "\n" + exc.response.text
         log.error(
             "Error creating %s on PROXMOX\n\n"
             "The following exception was thrown when trying to "
             "run the initial deployment: \n%s",
             vm_["name"],
-            exc,
+            msg,
             # Show the traceback if the debug logging level is enabled
             exc_info_on_loglevel=logging.DEBUG,
         )
@@ -663,28 +692,28 @@ def create(vm_):
 
     ret["creation_data"] = data
     name = vm_["name"]  # hostname which we know
-    if "clone" in vm_ and vm_["clone"] is True:
-        vmid = newid
-    else:
-        vmid = data["vmid"]  # vmid which we have received
+    vmid = data["vmid"]  # vmid which we have received
     host = data["node"]  # host which we have received
     nodeType = data["technology"]  # VM tech (Qemu / OpenVZ)
 
-    # Determine which IP to use in order of preference:
-    if "ip_address" in vm_:
-        ip_address = str(vm_["ip_address"])
-    elif "public_ips" in data:
-        ip_address = str(data["public_ips"][0])  # first IP
-    elif "private_ips" in data:
-        ip_address = str(data["private_ips"][0])  # first IP
-    else:
-        raise SaltCloudExecutionFailure("Could not determine an IP address to use")
+    agent_get_ip = vm_.get("agent_get_ip", False)
 
-    log.debug("Using IP address %s", ip_address)
+    if agent_get_ip is False:
+        # Determine which IP to use in order of preference:
+        if "ip_address" in vm_:
+            ip_address = str(vm_["ip_address"])
+        elif "public_ips" in data:
+            ip_address = str(data["public_ips"][0])  # first IP
+        elif "private_ips" in data:
+            ip_address = str(data["private_ips"][0])  # first IP
+        else:
+            raise SaltCloudExecutionFailure("Could not determine an IP address to use")
+
+        log.debug("Using IP address %s", ip_address)
 
     # wait until the vm has been created so we can start it
     if not wait_for_created(data["upid"], timeout=300):
-        return {"Error": "Unable to create {}, command timed out".format(name)}
+        return {"Error": f"Unable to create {name}, command timed out"}
 
     if vm_.get("clone") is True:
         _reconfigure_clone(vm_, vmid)
@@ -697,12 +726,32 @@ def create(vm_):
     # Wait until the VM has fully started
     log.debug('Waiting for state "running" for vm %s on %s', vmid, host)
     if not wait_for_state(vmid, "running"):
-        return {"Error": "Unable to start {}, command timed out".format(name)}
+        return {"Error": f"Unable to start {name}, command timed out"}
+
+    if agent_get_ip is True:
+        try:
+            ip_address = salt.utils.cloud.wait_for_fun(
+                _find_agent_ip, vm_=vm_, vmid=vmid
+            )
+        except (SaltCloudExecutionTimeout, SaltCloudExecutionFailure) as exc:
+            try:
+                # If VM was created but we can't connect, destroy it.
+                destroy(vm_["name"])
+            except SaltCloudSystemExit:
+                pass
+            finally:
+                raise SaltCloudSystemExit(str(exc))
+
+        log.debug("Using IP address %s", ip_address)
 
     ssh_username = config.get_cloud_config_value(
         "ssh_username", vm_, __opts__, default="root"
     )
-    ssh_password = config.get_cloud_config_value("password", vm_, __opts__,)
+    ssh_password = config.get_cloud_config_value(
+        "password",
+        vm_,
+        __opts__,
+    )
 
     ret["ip_address"] = ip_address
     ret["username"] = ssh_username
@@ -729,6 +778,87 @@ def create(vm_):
     return ret
 
 
+def preferred_ip(vm_, ips):
+    """
+    Return either an 'ipv4' (default) or 'ipv6' address depending on 'protocol' option.
+    The list of 'ipv4' IPs is filtered by ignore_cidr() to remove any unreachable private addresses.
+    """
+    proto = config.get_cloud_config_value(
+        "protocol", vm_, __opts__, default="ipv4", search_global=False
+    )
+
+    family = socket.AF_INET
+    if proto == "ipv6":
+        family = socket.AF_INET6
+    for ip in ips:
+        ignore_ip = ignore_cidr(vm_, ip)
+        if ignore_ip:
+            continue
+        try:
+            socket.inet_pton(family, ip)
+            return ip
+        except Exception:  # pylint: disable=broad-except
+            continue
+    return False
+
+
+def ignore_cidr(vm_, ip):
+    """
+    Return True if we are to ignore the specified IP.
+    """
+    from ipaddress import ip_address, ip_network
+
+    cidrs = config.get_cloud_config_value(
+        "ignore_cidr", vm_, __opts__, default=[], search_global=False
+    )
+    if cidrs and isinstance(cidrs, str):
+        cidrs = [cidrs]
+    for cidr in cidrs or []:
+        if ip_address(ip) in ip_network(cidr):
+            log.warning("IP %r found within %r; ignoring it.", ip, cidr)
+            return True
+
+    return False
+
+
+def _find_agent_ip(vm_, vmid):
+    """
+    If VM is started we would return the IP-addresses that are returned by the qemu agent on the VM.
+    """
+
+    # This functionality is only available on qemu
+    if not vm_.get("technology") == "qemu":
+        log.warning("Find agent IP is only available under `qemu`")
+        return
+
+    # Create an empty list of IP-addresses:
+    ips = []
+
+    endpoint = "nodes/{}/qemu/{}/agent/network-get-interfaces".format(vm_["host"], vmid)
+    interfaces = query("get", endpoint)
+
+    # If we get a result from the agent, parse it
+    for interface in interfaces["result"]:
+
+        # Skip interface if hardware-address is 00:00:00:00:00:00 (loopback interface)
+        if str(interface.get("hardware-address")) == "00:00:00:00:00:00":
+            continue
+
+        # Skip entries without ip-addresses information
+        if "ip-addresses" not in interface:
+            continue
+
+        for if_addr in interface["ip-addresses"]:
+            ip_addr = if_addr.get("ip-address")
+            if ip_addr is not None:
+                ips.append(str(ip_addr))
+
+    if len(ips) > 0:
+        return preferred_ip(vm_, ips)
+
+    raise SaltCloudExecutionFailure
+
+
 def _import_api():
     """
     Download https://<url>/pve-docs/api-viewer/apidoc.js
@@ -736,10 +866,10 @@ def _import_api():
     Load this json content into global variable "api"
     """
     global api
-    full_url = "https://{}:{}/pve-docs/api-viewer/apidoc.js".format(url, port)
-    returned_data = requests.get(full_url, verify=verify_ssl)
+    full_url = f"https://{url}:{port}/pve-docs/api-viewer/apidoc.js"
+    returned_data = requests.get(full_url, verify=verify_ssl, timeout=120)
 
-    re_filter = re.compile("(?<=pveapi =)(.*)(?=^;)", re.DOTALL | re.MULTILINE)
+    re_filter = re.compile(" (?:pveapi|apiSchema) = (.*)^;", re.DOTALL | re.MULTILINE)
     api_json = re_filter.findall(returned_data.text)[0]
     api = salt.utils.json.loads(api_json)
 
@@ -793,7 +923,8 @@ def create_node(vm_, newid):
     if vm_["technology"] not in ["qemu", "openvz", "lxc"]:
         # Wrong VM type given
         log.error(
-            "Wrong VM type. Valid options are: qemu, openvz (proxmox3) or lxc (proxmox4)"
+            "Wrong VM type. Valid options are: qemu, openvz (proxmox3) or lxc"
+            " (proxmox4)"
         )
         raise SaltCloudExecutionFailure
 
@@ -897,6 +1028,7 @@ def create_node(vm_, newid):
         )
         for prop in _get_properties("/nodes/{node}/qemu", "POST", static_props):
             if prop in vm_:  # if the property is set, use it for the VM request
+                # If specified, vmid will override newid.
                 newnode[prop] = vm_[prop]
 
     # The node is ready. Lets request it to be added
@@ -916,6 +1048,8 @@ def create_node(vm_, newid):
     if "clone" in vm_ and vm_["clone"] is True and vm_["technology"] == "qemu":
         postParams = {}
         postParams["newid"] = newnode["vmid"]
+        if "pool" in vm_:
+            postParams["pool"] = vm_["pool"]
 
         for prop in "description", "format", "full", "name":
             if (
@@ -937,7 +1071,12 @@ def create_node(vm_, newid):
         )
     else:
         node = query("post", "nodes/{}/{}".format(vmhost, vm_["technology"]), newnode)
-    return _parse_proxmox_upid(node, vm_)
+    result = _parse_proxmox_upid(node, vm_)
+
+    # When cloning, the upid contains the clone_from vmid instead of the new vmid
+    result["vmid"] = newnode["vmid"]
+
+    return result
 
 
 def show_instance(name, call=None):
@@ -961,12 +1100,12 @@ def get_vmconfig(vmid, node=None, node_type="openvz"):
     if node is None:
         # We need to figure out which node this VM is on.
         for host_name, host_details in avail_locations().items():
-            for item in query("get", "nodes/{}/{}".format(host_name, node_type)):
+            for item in query("get", f"nodes/{host_name}/{node_type}"):
                 if item["vmid"] == vmid:
                     node = host_name
 
     # If we reached this point, we have all the information we need
-    data = query("get", "nodes/{}/{}/{}/config".format(node, node_type, vmid))
+    data = query("get", f"nodes/{node}/{node_type}/{vmid}/config")
 
     return data
 
@@ -979,8 +1118,7 @@ def wait_for_created(upid, timeout=300):
     info = _lookup_proxmox_task(upid)
     if not info:
         log.error(
-            "wait_for_created: No task information "
-            "retrieved based on given criteria."
+            "wait_for_created: No task information retrieved based on given criteria."
         )
         raise SaltCloudExecutionFailure
 
@@ -1033,13 +1171,13 @@ def destroy(name, call=None):
     """
     if call == "function":
         raise SaltCloudSystemExit(
-            "The destroy action must be called with -d, --destroy, " "-a or --action."
+            "The destroy action must be called with -d, --destroy, -a or --action."
         )
 
     __utils__["cloud.fire_event"](
         "event",
         "destroying instance",
-        "salt/cloud/{}/destroying".format(name),
+        f"salt/cloud/{name}/destroying",
         args={"name": name},
         sock_dir=__opts__["sock_dir"],
         transport=__opts__["transport"],
@@ -1053,7 +1191,7 @@ def destroy(name, call=None):
 
         # wait until stopped
         if not wait_for_state(vmobj["vmid"], "stopped"):
-            return {"Error": "Unable to stop {}, command timed out".format(name)}
+            return {"Error": f"Unable to stop {name}, command timed out"}
 
         # required to wait a bit here, otherwise the VM is sometimes
         # still locked and destroy fails.
@@ -1063,7 +1201,7 @@ def destroy(name, call=None):
         __utils__["cloud.fire_event"](
             "event",
             "destroyed instance",
-            "salt/cloud/{}/destroyed".format(name),
+            f"salt/cloud/{name}/destroyed",
             args={"name": name},
             sock_dir=__opts__["sock_dir"],
             transport=__opts__["transport"],
@@ -1073,7 +1211,7 @@ def destroy(name, call=None):
                 name, _get_active_provider_name().split(":")[0], __opts__
             )
 
-        return {"Destroyed": "{} was destroyed.".format(name)}
+        return {"Destroyed": f"{name} was destroyed."}
 
 
 def set_vm_status(status, name=None, vmid=None):
@@ -1162,7 +1300,7 @@ def start(name, vmid=None, call=None):
 
     # xxx: TBD: Check here whether the status was actually changed to 'started'
 
-    return {"Started": "{} was started.".format(name)}
+    return {"Started": f"{name} was started."}
 
 
 def stop(name, vmid=None, call=None):
@@ -1184,7 +1322,7 @@ def stop(name, vmid=None, call=None):
 
     # xxx: TBD: Check here whether the status was actually changed to 'stopped'
 
-    return {"Stopped": "{} was stopped.".format(name)}
+    return {"Stopped": f"{name} was stopped."}
 
 
 def shutdown(name=None, vmid=None, call=None):
@@ -1208,4 +1346,4 @@ def shutdown(name=None, vmid=None, call=None):
 
     # xxx: TBD: Check here whether the status was actually changed to 'stopped'
 
-    return {"Shutdown": "{} was shutdown.".format(name)}
+    return {"Shutdown": f"{name} was shutdown."}
