@@ -284,7 +284,8 @@ class SlackClient:
                 ret_groups[name]["targets"].update(config.get("targets", {}))
             except (IndexError, AttributeError):
                 log.warning(
-                    "Couldn't use group %s. Check that targets is a dictionary and not a list",
+                    "Couldn't use group %s. Check that targets is a dictionary and not"
+                    " a list",
                     name,
                 )
 
@@ -516,9 +517,7 @@ class SlackClient:
                     )
                     user_id = m_data["message"]["user"]
                 elif "comment" in m_data and "user" in m_data["comment"]:
-                    log.debug(
-                        "Comment was added, " "so we look for user in " "the comment."
-                    )
+                    log.debug("Comment was added, so we look for user in the comment.")
                     user_id = m_data["comment"]["user"]
             else:
                 user_id = m_data.get("user")
@@ -581,13 +580,13 @@ class SlackClient:
                     loaded_groups = self.get_config_groups(groups, groups_pillar_name)
                     if not data.get("user_name"):
                         log.error(
-                            "The user %s can not be looked up via slack. What has happened here?",
+                            "The user %s can not be looked up via slack. What has"
+                            " happened here?",
                             m_data.get("user"),
                         )
                         channel.send_message(
-                            "The user {} can not be looked up via slack.  Not running {}".format(
-                                data["user_id"], msg_text
-                            )
+                            "The user {} can not be looked up via slack.  Not"
+                            " running {}".format(data["user_id"], msg_text)
                         )
                         yield {"message_data": m_data}
                         continue
@@ -696,7 +695,9 @@ class SlackClient:
             except (StopIteration, AttributeError):
                 outputter = None
             return salt.output.string_format(
-                {x: y["return"] for x, y in data.items()}, out=outputter, opts=__opts__,
+                {x: y["return"] for x, y in data.items()},
+                out=outputter,
+                opts=__opts__,
             )
         except Exception as exc:  # pylint: disable=broad-except
             import pprint
@@ -746,7 +747,7 @@ class SlackClient:
         results = {}
         for jid in outstanding_jids:
             # results[jid] = runner.cmd('jobs.lookup_jid', [jid])
-            if self.master_minion.returners["{}.get_jid".format(source)](jid):
+            if self.master_minion.returners[f"{source}.get_jid"](jid):
                 job_result = runner.cmd("jobs.list_job", [jid])
                 jid_result = job_result.get("Result", {})
                 jid_function = job_result.get("Function", {})
@@ -799,9 +800,9 @@ class SlackClient:
                     channel = self.sc.server.channels.find(msg["channel"])
                     jid = self.run_command_async(msg)
                     log.debug("Submitted a job and got jid: %s", jid)
-                    outstanding[
-                        jid
-                    ] = msg  # record so we can return messages to the caller
+                    outstanding[jid] = (
+                        msg  # record so we can return messages to the caller
+                    )
                     channel.send_message(
                         "@{}'s job is submitted as salt jid {}".format(
                             msg["user_name"], jid
@@ -826,16 +827,18 @@ class SlackClient:
                     this_job = outstanding[jid]
                     channel = self.sc.server.channels.find(this_job["channel"])
                     return_text = self.format_return_text(result, function)
-                    return_prefix = "@{}'s job `{}` (id: {}) (target: {}) returned".format(
-                        this_job["user_name"],
-                        this_job["cmdline"],
-                        jid,
-                        this_job["target"],
+                    return_prefix = (
+                        "@{}'s job `{}` (id: {}) (target: {}) returned".format(
+                            this_job["user_name"],
+                            this_job["cmdline"],
+                            jid,
+                            this_job["target"],
+                        )
                     )
                     channel.send_message(return_prefix)
                     ts = time.time()
                     st = datetime.datetime.fromtimestamp(ts).strftime("%Y%m%d%H%M%S%f")
-                    filename = "salt-results-{}.yaml".format(st)
+                    filename = f"salt-results-{st}.yaml"
                     r = self.sc.api_call(
                         "files.upload",
                         channels=channel.id,
@@ -852,7 +855,6 @@ class SlackClient:
                     del outstanding[jid]
 
     def run_command_async(self, msg):
-
         """
         :type message_generator: generator of dict
         :param message_generator: Generates messages from slack that should be run
@@ -887,9 +889,7 @@ class SlackClient:
         if cmd in runner_functions:
             runner = salt.runner.RunnerClient(__opts__)
             log.debug("Command %s will run via runner_functions", cmd)
-            # pylint is tripping
-            # pylint: disable=missing-whitespace-after-comma
-            job_id_dict = runner.asynchronous(cmd, {"args": args, "kwargs": kwargs})
+            job_id_dict = runner.asynchronous(cmd, {"arg": args, "kwarg": kwargs})
             job_id = job_id_dict["jid"]
 
         # Default to trying to run as a client module.
@@ -901,7 +901,11 @@ class SlackClient:
             # according to https://github.com/saltstack/salt-api/issues/164, tgt_type has changed to expr_form
             with salt.client.LocalClient() as local:
                 job_id = local.cmd_async(
-                    str(target), cmd, arg=args, kwarg=kwargs, tgt_type=str(tgt_type),
+                    str(target),
+                    cmd,
+                    arg=args,
+                    kwarg=kwargs,
+                    tgt_type=str(tgt_type),
                 )
             log.info("ret from local.cmd_async is %s", job_id)
         return job_id
@@ -920,6 +924,14 @@ def start(
     Listen to slack events and forward them to salt, new version
     """
 
+    salt.utils.versions.warn_until(
+        "Argon",
+        "This 'slack' engine will be deprecated and "
+        "will be replace by the slack_bolt engine. This new "
+        "engine will use the new Bolt library from Slack and requires "
+        "a Slack app and a Slack bot account.",
+    )
+
     if (not token) or (not token.startswith("xoxb")):
         time.sleep(2)  # don't respawn too quickly
         log.error("Slack bot token not found, bailing...")
@@ -932,4 +944,4 @@ def start(
         )
         client.run_commands_from_slack_async(message_generator, fire_all, tag, control)
     except Exception:  # pylint: disable=broad-except
-        raise Exception("{}".format(traceback.format_exc()))
+        raise Exception(f"{traceback.format_exc()}")
