@@ -30,7 +30,6 @@ This backend assumes a standard svn layout with directories for ``branches``,
     :conf_master:`documentation <svnfs_remotes>` for more information.
 """
 
-
 import copy
 import errno
 import fnmatch
@@ -137,7 +136,7 @@ def init():
 
     per_remote_defaults = {}
     for param in PER_REMOTE_OVERRIDES:
-        per_remote_defaults[param] = str(__opts__["svnfs_{}".format(param)])
+        per_remote_defaults[param] = str(__opts__[f"svnfs_{param}"])
 
     for remote in __opts__["svnfs_remotes"]:
         repo_conf = copy.deepcopy(per_remote_defaults)
@@ -240,7 +239,7 @@ def init():
         try:
             with salt.utils.files.fopen(remote_map, "w+") as fp_:
                 timestamp = datetime.now().strftime("%d %b %Y %H:%M:%S.%f")
-                fp_.write("# svnfs_remote map as of {}\n".format(timestamp))
+                fp_.write(f"# svnfs_remote map as of {timestamp}\n")
                 for repo_conf in repos:
                     fp_.write(
                         salt.utils.stringutils.to_str(
@@ -307,7 +306,7 @@ def clear_cache():
             try:
                 shutil.rmtree(rdir)
             except OSError as exc:
-                errors.append("Unable to delete {}: {}".format(rdir, exc))
+                errors.append(f"Unable to delete {rdir}: {exc}")
     return errors
 
 
@@ -721,7 +720,7 @@ def _file_lists(load, form):
     if not os.path.isdir(list_cachedir):
         try:
             os.makedirs(list_cachedir)
-        except os.error:
+        except OSError:
             log.critical("Unable to make cachedir %s", list_cachedir)
             return []
     list_cache = os.path.join(list_cachedir, "{}.p".format(load["saltenv"]))
