@@ -1,17 +1,11 @@
-# -*- coding: utf-8 -*-
 """
 Generate baseline proxy minion grains for panos hosts.
 
 """
 
-# Import Python Libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import logging
 
 import salt.proxy.panos
-
-# Import Salt Libs
 import salt.utils.platform
 
 __proxyenabled__ = ["panos"]
