@@ -1,10 +1,15 @@
-# -*- coding: utf-8 -*-
 """
 Azure (ARM) Network Execution Module
 
 .. versionadded:: 2019.2.0
 
-:maintainer: <devops@decisionlab.io>
+.. warning::
+
+    This cloud provider will be removed from Salt in version 3007 in favor of
+    the `saltext.azurerm Salt Extension
+    <https://github.com/salt-extensions/saltext-azurerm>`_
+
+:maintainer: <devops@eitr.tech>
 :maturity: new
 :depends:
     * `azure <https://pypi.python.org/pypi/azure>`_ >= 2.0.0
@@ -47,13 +52,13 @@ Azure (ARM) Network Execution Module
 """
 
 # Python libs
-from __future__ import absolute_import
 
 import logging
+from functools import wraps
 
 # Salt libs
+import salt.utils.azurearm
 from salt.exceptions import SaltInvocationError  # pylint: disable=unused-import
-from salt.ext.six.moves import range
 
 # Azure libs
 HAS_LIBS = False
@@ -83,6 +88,28 @@ def __virtual__():
     return __virtualname__
 
 
+def _deprecation_message(function):
+    """
+    Decorator wrapper to warn about azurearm deprecation
+    """
+
+    @wraps(function)
+    def wrapped(*args, **kwargs):
+        salt.utils.versions.warn_until(
+            "Chlorine",
+            "The 'azurearm' functionality in Salt has been deprecated and its "
+            "functionality will be removed in version 3007 in favor of the "
+            "saltext.azurerm Salt Extension. "
+            "(https://github.com/salt-extensions/saltext-azurerm)",
+            category=FutureWarning,
+        )
+        ret = function(*args, **salt.utils.args.clean_kwargs(**kwargs))
+        return ret
+
+    return wrapped
+
+
+@_deprecation_message
 def check_dns_name_availability(name, region, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -113,6 +140,7 @@ def check_dns_name_availability(name, region, **kwargs):
     return result
 
 
+@_deprecation_message
 def check_ip_address_availability(
     ip_address, virtual_network, resource_group, **kwargs
 ):
@@ -152,6 +180,7 @@ def check_ip_address_availability(
     return result
 
 
+@_deprecation_message
 def default_security_rule_get(name, security_group, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -187,9 +216,7 @@ def default_security_rule_get(name, security_group, resource_group, **kwargs):
             if default_rule["name"] == name:
                 result = default_rule
         if not result:
-            result = {
-                "error": "Unable to find {0} in {1}!".format(name, security_group)
-            }
+            result = {"error": f"Unable to find {name} in {security_group}!"}
     except KeyError as exc:
         log.error("Unable to find %s in %s!", name, security_group)
         result = {"error": str(exc)}
@@ -197,6 +224,7 @@ def default_security_rule_get(name, security_group, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def default_security_rules_list(security_group, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -233,6 +261,7 @@ def default_security_rules_list(security_group, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def security_rules_list(security_group, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -265,6 +294,7 @@ def security_rules_list(security_group, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def security_rule_create_or_update(
     name,
     access,
@@ -281,7 +311,7 @@ def security_rule_create_or_update(
     destination_address_prefixes=None,
     source_port_ranges=None,
     destination_port_ranges=None,
-    **kwargs
+    **kwargs,
 ):
     """
     .. versionadded:: 2019.2.0
@@ -368,7 +398,7 @@ def security_rule_create_or_update(
         # pylint: disable=eval-used
         if eval(params[0]):
             # pylint: disable=exec-used
-            exec("{0} = None".format(params[1]))
+            exec(f"{params[1]} = None")
 
     netconn = __utils__["azurearm.get_client"]("network", **kwargs)
 
@@ -389,12 +419,10 @@ def security_rule_create_or_update(
             destination_port_range=destination_port_range,
             destination_address_prefixes=destination_address_prefixes,
             destination_address_prefix=destination_address_prefix,
-            **kwargs
+            **kwargs,
         )
     except TypeError as exc:
-        result = {
-            "error": "The object model could not be built. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be built. ({str(exc)})"}
         return result
 
     try:
@@ -411,13 +439,12 @@ def security_rule_create_or_update(
         __utils__["azurearm.log_cloud_error"]("network", str(exc), **kwargs)
         result = {"error": str(exc)}
     except SerializationError as exc:
-        result = {
-            "error": "The object model could not be parsed. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be parsed. ({str(exc)})"}
 
     return result
 
 
+@_deprecation_message
 def security_rule_delete(security_rule, security_group, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -455,6 +482,7 @@ def security_rule_delete(security_rule, security_group, resource_group, **kwargs
     return result
 
 
+@_deprecation_message
 def security_rule_get(security_rule, security_group, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -491,6 +519,7 @@ def security_rule_get(security_rule, security_group, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def network_security_group_create_or_update(
     name, resource_group, **kwargs
 ):  # pylint: disable=invalid-name
@@ -528,9 +557,7 @@ def network_security_group_create_or_update(
             "network", "NetworkSecurityGroup", **kwargs
         )
     except TypeError as exc:
-        result = {
-            "error": "The object model could not be built. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be built. ({str(exc)})"}
         return result
 
     try:
@@ -546,13 +573,12 @@ def network_security_group_create_or_update(
         __utils__["azurearm.log_cloud_error"]("network", str(exc), **kwargs)
         result = {"error": str(exc)}
     except SerializationError as exc:
-        result = {
-            "error": "The object model could not be parsed. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be parsed. ({str(exc)})"}
 
     return result
 
 
+@_deprecation_message
 def network_security_group_delete(name, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -585,6 +611,7 @@ def network_security_group_delete(name, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def network_security_group_get(name, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -616,6 +643,7 @@ def network_security_group_get(name, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def network_security_groups_list(resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -647,6 +675,7 @@ def network_security_groups_list(resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def network_security_groups_list_all(**kwargs):  # pylint: disable=invalid-name
     """
     .. versionadded:: 2019.2.0
@@ -675,6 +704,7 @@ def network_security_groups_list_all(**kwargs):  # pylint: disable=invalid-name
     return result
 
 
+@_deprecation_message
 def subnets_list(virtual_network, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -711,6 +741,7 @@ def subnets_list(virtual_network, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def subnet_get(name, virtual_network, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -748,6 +779,7 @@ def subnet_get(name, virtual_network, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def subnet_create_or_update(
     name, address_prefix, virtual_network, resource_group, **kwargs
 ):
@@ -781,7 +813,7 @@ def subnet_create_or_update(
         nsg = network_security_group_get(
             name=kwargs["network_security_group"],
             resource_group=resource_group,
-            **kwargs
+            **kwargs,
         )
         if "error" not in nsg:
             kwargs["network_security_group"] = {"id": str(nsg["id"])}
@@ -800,12 +832,10 @@ def subnet_create_or_update(
             "Subnet",
             address_prefix=address_prefix,
             resource_group=resource_group,
-            **kwargs
+            **kwargs,
         )
     except TypeError as exc:
-        result = {
-            "error": "The object model could not be built. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be built. ({str(exc)})"}
         return result
 
     try:
@@ -822,13 +852,12 @@ def subnet_create_or_update(
         __utils__["azurearm.log_cloud_error"]("network", str(exc), **kwargs)
         result = {"error": str(exc)}
     except SerializationError as exc:
-        result = {
-            "error": "The object model could not be parsed. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be parsed. ({str(exc)})"}
 
     return result
 
 
+@_deprecation_message
 def subnet_delete(name, virtual_network, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -866,6 +895,7 @@ def subnet_delete(name, virtual_network, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def virtual_networks_list_all(**kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -895,6 +925,7 @@ def virtual_networks_list_all(**kwargs):
     return result
 
 
+@_deprecation_message
 def virtual_networks_list(resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -928,6 +959,7 @@ def virtual_networks_list(resource_group, **kwargs):
 
 
 # pylint: disable=invalid-name
+@_deprecation_message
 def virtual_network_create_or_update(name, address_prefixes, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -976,12 +1008,10 @@ def virtual_network_create_or_update(name, address_prefixes, resource_group, **k
             "VirtualNetwork",
             address_space=address_space,
             dhcp_options=dhcp_options,
-            **kwargs
+            **kwargs,
         )
     except TypeError as exc:
-        result = {
-            "error": "The object model could not be built. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be built. ({str(exc)})"}
         return result
 
     try:
@@ -997,13 +1027,12 @@ def virtual_network_create_or_update(name, address_prefixes, resource_group, **k
         __utils__["azurearm.log_cloud_error"]("network", str(exc), **kwargs)
         result = {"error": str(exc)}
     except SerializationError as exc:
-        result = {
-            "error": "The object model could not be parsed. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be parsed. ({str(exc)})"}
 
     return result
 
 
+@_deprecation_message
 def virtual_network_delete(name, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -1036,6 +1065,7 @@ def virtual_network_delete(name, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def virtual_network_get(name, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -1067,6 +1097,7 @@ def virtual_network_get(name, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def load_balancers_list_all(**kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -1096,6 +1127,7 @@ def load_balancers_list_all(**kwargs):
     return result
 
 
+@_deprecation_message
 def load_balancers_list(resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -1128,6 +1160,7 @@ def load_balancers_list(resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def load_balancer_get(name, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -1159,6 +1192,7 @@ def load_balancer_get(name, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def load_balancer_create_or_update(name, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -1196,7 +1230,7 @@ def load_balancer_create_or_update(name, resource_group, **kwargs):
                 pub_ip = public_ip_address_get(
                     name=kwargs["frontend_ip_configurations"][idx]["public_ip_address"],
                     resource_group=resource_group,
-                    **kwargs
+                    **kwargs,
                 )
                 if "error" not in pub_ip:
                     kwargs["frontend_ip_configurations"][idx]["public_ip_address"] = {
@@ -1210,7 +1244,7 @@ def load_balancer_create_or_update(name, resource_group, **kwargs):
                         subnets = subnets_list(
                             virtual_network=vnet,
                             resource_group=resource_group,
-                            **kwargs
+                            **kwargs,
                         )
                         if (
                             kwargs["frontend_ip_configurations"][idx]["subnet"]
@@ -1322,9 +1356,7 @@ def load_balancer_create_or_update(name, resource_group, **kwargs):
             "network", "LoadBalancer", **kwargs
         )
     except TypeError as exc:
-        result = {
-            "error": "The object model could not be built. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be built. ({str(exc)})"}
         return result
 
     try:
@@ -1340,13 +1372,12 @@ def load_balancer_create_or_update(name, resource_group, **kwargs):
         __utils__["azurearm.log_cloud_error"]("network", str(exc), **kwargs)
         result = {"error": str(exc)}
     except SerializationError as exc:
-        result = {
-            "error": "The object model could not be parsed. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be parsed. ({str(exc)})"}
 
     return result
 
 
+@_deprecation_message
 def load_balancer_delete(name, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -1379,6 +1410,7 @@ def load_balancer_delete(name, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def usages_list(location, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -1406,6 +1438,7 @@ def usages_list(location, **kwargs):
     return result
 
 
+@_deprecation_message
 def network_interface_delete(name, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -1439,6 +1472,7 @@ def network_interface_delete(name, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def network_interface_get(name, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -1471,6 +1505,7 @@ def network_interface_get(name, resource_group, **kwargs):
 
 
 # pylint: disable=invalid-name
+@_deprecation_message
 def network_interface_create_or_update(
     name, ip_configurations, subnet, virtual_network, resource_group, **kwargs
 ):
@@ -1517,7 +1552,7 @@ def network_interface_create_or_update(
         nsg = network_security_group_get(
             name=kwargs["network_security_group"],
             resource_group=resource_group,
-            **kwargs
+            **kwargs,
         )
         if "error" not in nsg:
             kwargs["network_security_group"] = {"id": str(nsg["id"])}
@@ -1536,7 +1571,7 @@ def network_interface_create_or_update(
             name=subnet,
             virtual_network=virtual_network,
             resource_group=resource_group,
-            **kwargs
+            **kwargs,
         )
         if "error" not in subnet:
             subnet = {"id": str(subnet["id"])}
@@ -1562,7 +1597,7 @@ def network_interface_create_or_update(
                         pub_ip = public_ip_address_get(
                             name=ipconfig["public_ip_address"],
                             resource_group=resource_group,
-                            **kwargs
+                            **kwargs,
                         )
                         if "error" not in pub_ip:
                             ipconfig["public_ip_address"] = {"id": str(pub_ip["id"])}
@@ -1572,9 +1607,7 @@ def network_interface_create_or_update(
             "network", "NetworkInterface", ip_configurations=ip_configurations, **kwargs
         )
     except TypeError as exc:
-        result = {
-            "error": "The object model could not be built. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be built. ({str(exc)})"}
         return result
 
     try:
@@ -1590,13 +1623,12 @@ def network_interface_create_or_update(
         __utils__["azurearm.log_cloud_error"]("network", str(exc), **kwargs)
         result = {"error": str(exc)}
     except SerializationError as exc:
-        result = {
-            "error": "The object model could not be parsed. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be parsed. ({str(exc)})"}
 
     return result
 
 
+@_deprecation_message
 def network_interfaces_list_all(**kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -1626,6 +1658,7 @@ def network_interfaces_list_all(**kwargs):
     return result
 
 
+@_deprecation_message
 def network_interfaces_list(resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -1659,6 +1692,7 @@ def network_interfaces_list(resource_group, **kwargs):
 
 
 # pylint: disable=invalid-name
+@_deprecation_message
 def network_interface_get_effective_route_table(name, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -1694,6 +1728,7 @@ def network_interface_get_effective_route_table(name, resource_group, **kwargs):
 
 
 # pylint: disable=invalid-name
+@_deprecation_message
 def network_interface_list_effective_network_security_groups(
     name, resource_group, **kwargs
 ):
@@ -1731,6 +1766,7 @@ def network_interface_list_effective_network_security_groups(
 
 
 # pylint: disable=invalid-name
+@_deprecation_message
 def list_virtual_machine_scale_set_vm_network_interfaces(
     scale_set, vm_index, resource_group, **kwargs
 ):
@@ -1774,6 +1810,7 @@ def list_virtual_machine_scale_set_vm_network_interfaces(
 
 
 # pylint: disable=invalid-name
+@_deprecation_message
 def list_virtual_machine_scale_set_network_interfaces(
     scale_set, resource_group, **kwargs
 ):
@@ -1814,6 +1851,7 @@ def list_virtual_machine_scale_set_network_interfaces(
 
 
 # pylint: disable=invalid-name
+@_deprecation_message
 def get_virtual_machine_scale_set_network_interface(
     name, scale_set, vm_index, resource_group, **kwargs
 ):
@@ -1858,6 +1896,7 @@ def get_virtual_machine_scale_set_network_interface(
     return result
 
 
+@_deprecation_message
 def public_ip_address_delete(name, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -1890,6 +1929,7 @@ def public_ip_address_delete(name, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def public_ip_address_get(name, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -1926,6 +1966,7 @@ def public_ip_address_get(name, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def public_ip_address_create_or_update(name, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -1961,9 +2002,7 @@ def public_ip_address_create_or_update(name, resource_group, **kwargs):
             "network", "PublicIPAddress", **kwargs
         )
     except TypeError as exc:
-        result = {
-            "error": "The object model could not be built. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be built. ({str(exc)})"}
         return result
 
     try:
@@ -1979,13 +2018,12 @@ def public_ip_address_create_or_update(name, resource_group, **kwargs):
         __utils__["azurearm.log_cloud_error"]("network", str(exc), **kwargs)
         result = {"error": str(exc)}
     except SerializationError as exc:
-        result = {
-            "error": "The object model could not be parsed. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be parsed. ({str(exc)})"}
 
     return result
 
 
+@_deprecation_message
 def public_ip_addresses_list_all(**kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -2015,6 +2053,7 @@ def public_ip_addresses_list_all(**kwargs):
     return result
 
 
+@_deprecation_message
 def public_ip_addresses_list(resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -2047,6 +2086,7 @@ def public_ip_addresses_list(resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def route_filter_rule_delete(name, route_filter, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -2083,6 +2123,7 @@ def route_filter_rule_delete(name, route_filter, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def route_filter_rule_get(name, route_filter, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -2120,6 +2161,7 @@ def route_filter_rule_get(name, route_filter, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def route_filter_rule_create_or_update(
     name, access, communities, route_filter, resource_group, **kwargs
 ):
@@ -2169,12 +2211,10 @@ def route_filter_rule_create_or_update(
             "RouteFilterRule",
             access=access,
             communities=communities,
-            **kwargs
+            **kwargs,
         )
     except TypeError as exc:
-        result = {
-            "error": "The object model could not be built. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be built. ({str(exc)})"}
         return result
 
     try:
@@ -2194,13 +2234,12 @@ def route_filter_rule_create_or_update(
         __utils__["azurearm.log_cloud_error"]("network", message, **kwargs)
         result = {"error": message}
     except SerializationError as exc:
-        result = {
-            "error": "The object model could not be parsed. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be parsed. ({str(exc)})"}
 
     return result
 
 
+@_deprecation_message
 def route_filter_rules_list(route_filter, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -2237,6 +2276,7 @@ def route_filter_rules_list(route_filter, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def route_filter_delete(name, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -2269,6 +2309,7 @@ def route_filter_delete(name, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def route_filter_get(name, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -2303,6 +2344,7 @@ def route_filter_get(name, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def route_filter_create_or_update(name, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -2338,9 +2380,7 @@ def route_filter_create_or_update(name, resource_group, **kwargs):
             "network", "RouteFilter", **kwargs
         )
     except TypeError as exc:
-        result = {
-            "error": "The object model could not be built. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be built. ({str(exc)})"}
         return result
 
     try:
@@ -2356,13 +2396,12 @@ def route_filter_create_or_update(name, resource_group, **kwargs):
         __utils__["azurearm.log_cloud_error"]("network", str(exc), **kwargs)
         result = {"error": str(exc)}
     except SerializationError as exc:
-        result = {
-            "error": "The object model could not be parsed. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be parsed. ({str(exc)})"}
 
     return result
 
 
+@_deprecation_message
 def route_filters_list(resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -2397,6 +2436,7 @@ def route_filters_list(resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def route_filters_list_all(**kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -2426,6 +2466,7 @@ def route_filters_list_all(**kwargs):
     return result
 
 
+@_deprecation_message
 def route_delete(name, route_table, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -2462,6 +2503,7 @@ def route_delete(name, route_table, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def route_get(name, route_table, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -2499,6 +2541,7 @@ def route_get(name, route_table, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def route_create_or_update(
     name,
     address_prefix,
@@ -2506,7 +2549,7 @@ def route_create_or_update(
     route_table,
     resource_group,
     next_hop_ip_address=None,
-    **kwargs
+    **kwargs,
 ):
     """
     .. versionadded:: 2019.2.0
@@ -2544,12 +2587,10 @@ def route_create_or_update(
             address_prefix=address_prefix,
             next_hop_type=next_hop_type,
             next_hop_ip_address=next_hop_ip_address,
-            **kwargs
+            **kwargs,
         )
     except TypeError as exc:
-        result = {
-            "error": "The object model could not be built. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be built. ({str(exc)})"}
         return result
 
     try:
@@ -2566,13 +2607,12 @@ def route_create_or_update(
         __utils__["azurearm.log_cloud_error"]("network", str(exc), **kwargs)
         result = {"error": str(exc)}
     except SerializationError as exc:
-        result = {
-            "error": "The object model could not be parsed. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be parsed. ({str(exc)})"}
 
     return result
 
 
+@_deprecation_message
 def routes_list(route_table, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -2609,6 +2649,7 @@ def routes_list(route_table, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def route_table_delete(name, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -2641,6 +2682,7 @@ def route_table_delete(name, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def route_table_get(name, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -2675,6 +2717,7 @@ def route_table_get(name, resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def route_table_create_or_update(name, resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -2710,9 +2753,7 @@ def route_table_create_or_update(name, resource_group, **kwargs):
             "network", "RouteTable", **kwargs
         )
     except TypeError as exc:
-        result = {
-            "error": "The object model could not be built. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be built. ({str(exc)})"}
         return result
 
     try:
@@ -2728,13 +2769,12 @@ def route_table_create_or_update(name, resource_group, **kwargs):
         __utils__["azurearm.log_cloud_error"]("network", str(exc), **kwargs)
         result = {"error": str(exc)}
     except SerializationError as exc:
-        result = {
-            "error": "The object model could not be parsed. ({0})".format(str(exc))
-        }
+        result = {"error": f"The object model could not be parsed. ({str(exc)})"}
 
     return result
 
 
+@_deprecation_message
 def route_tables_list(resource_group, **kwargs):
     """
     .. versionadded:: 2019.2.0
@@ -2767,6 +2807,7 @@ def route_tables_list(resource_group, **kwargs):
     return result
 
 
+@_deprecation_message
 def route_tables_list_all(**kwargs):
     """
     .. versionadded:: 2019.2.0
