@@ -1,7 +1,8 @@
 """
 Module for handling kubernetes calls.
 
-:optdepends:    - kubernetes Python client
+:optdepends:    - kubernetes Python client < 4.0
+                - PyYAML < 6.0
 :configuration: The k8s API settings are provided either in a pillar, in
     the minion's config file, or in master's config file::
 
@@ -18,6 +19,8 @@ The data format for `kubernetes.kubeconfig-data` value is the content of
 Only `kubeconfig` or `kubeconfig-data` should be provided. In case both are
 provided `kubeconfig` entry is preferred.
 
+CLI Example:
+
 .. code-block:: bash
 
     salt '*' kubernetes.nodes kubeconfig=/etc/salt/k8s/kubeconfig context=minikube
@@ -72,8 +75,7 @@ try:
         from kubernetes.client import V1beta1Deployment as AppsV1beta1Deployment
         from kubernetes.client import V1beta1DeploymentSpec as AppsV1beta1DeploymentSpec
     except ImportError:
-        from kubernetes.client import AppsV1beta1Deployment
-        from kubernetes.client import AppsV1beta1DeploymentSpec
+        from kubernetes.client import AppsV1beta1Deployment, AppsV1beta1DeploymentSpec
     # pylint: enable=no-name-in-module
 
     HAS_LIBS = True
@@ -152,7 +154,7 @@ def _setup_conn_old(**kwargs):
         or kubernetes.client.configuration.password != password
     ):
         # Recreates API connection if settings are changed
-        kubernetes.client.configuration.__init__()
+        kubernetes.client.configuration.__init__()  # pylint: disable=unnecessary-dunder-call
 
     kubernetes.client.configuration.host = host
     kubernetes.client.configuration.user = username
@@ -215,11 +217,13 @@ def _setup_conn(**kwargs):
                 return _setup_conn_old(**kwargs)
             except Exception:  # pylint: disable=broad-except
                 raise CommandExecutionError(
-                    "Old style kubernetes configuration is only supported up to python-kubernetes 2.0.0"
+                    "Old style kubernetes configuration is only supported up to"
+                    " python-kubernetes 2.0.0"
                 )
         else:
             raise CommandExecutionError(
-                "Invalid kubernetes configuration. Parameter 'kubeconfig' and 'context' are required."
+                "Invalid kubernetes configuration. Parameter 'kubeconfig' and 'context'"
+                " are required."
             )
     kubernetes.config.load_kube_config(config_file=kubeconfig, context=context)
 
@@ -501,9 +505,7 @@ def services(namespace="default", **kwargs):
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception(
-                "Exception when calling " "CoreV1Api->list_namespaced_service"
-            )
+            log.exception("Exception when calling CoreV1Api->list_namespaced_service")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -530,7 +532,7 @@ def pods(namespace="default", **kwargs):
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception("Exception when calling " "CoreV1Api->list_namespaced_pod")
+            log.exception("Exception when calling CoreV1Api->list_namespaced_pod")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -559,7 +561,7 @@ def secrets(namespace="default", **kwargs):
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception("Exception when calling " "CoreV1Api->list_namespaced_secret")
+            log.exception("Exception when calling CoreV1Api->list_namespaced_secret")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -589,7 +591,7 @@ def configmaps(namespace="default", **kwargs):
             return None
         else:
             log.exception(
-                "Exception when calling " "CoreV1Api->list_namespaced_config_map"
+                "Exception when calling CoreV1Api->list_namespaced_config_map"
             )
             raise CommandExecutionError(exc)
     finally:
@@ -647,9 +649,7 @@ def show_service(name, namespace="default", **kwargs):
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception(
-                "Exception when calling " "CoreV1Api->read_namespaced_service"
-            )
+            log.exception("Exception when calling CoreV1Api->read_namespaced_service")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -676,7 +676,7 @@ def show_pod(name, namespace="default", **kwargs):
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception("Exception when calling " "CoreV1Api->read_namespaced_pod")
+            log.exception("Exception when calling CoreV1Api->read_namespaced_pod")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -702,7 +702,7 @@ def show_namespace(name, **kwargs):
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception("Exception when calling " "CoreV1Api->read_namespace")
+            log.exception("Exception when calling CoreV1Api->read_namespace")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -737,7 +737,7 @@ def show_secret(name, namespace="default", decode=False, **kwargs):
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception("Exception when calling " "CoreV1Api->read_namespaced_secret")
+            log.exception("Exception when calling CoreV1Api->read_namespaced_secret")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -765,7 +765,7 @@ def show_configmap(name, namespace="default", **kwargs):
             return None
         else:
             log.exception(
-                "Exception when calling " "CoreV1Api->read_namespaced_config_map"
+                "Exception when calling CoreV1Api->read_namespaced_config_map"
             )
             raise CommandExecutionError(exc)
     finally:
@@ -885,7 +885,7 @@ def delete_pod(name, namespace="default", **kwargs):
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception("Exception when calling " "CoreV1Api->delete_namespaced_pod")
+            log.exception("Exception when calling CoreV1Api->delete_namespaced_pod")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -913,7 +913,7 @@ def delete_namespace(name, **kwargs):
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception("Exception when calling " "CoreV1Api->delete_namespace")
+            log.exception("Exception when calling CoreV1Api->delete_namespace")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -976,7 +976,7 @@ def delete_configmap(name, namespace="default", **kwargs):
             return None
         else:
             log.exception(
-                "Exception when calling " "CoreV1Api->delete_namespaced_config_map"
+                "Exception when calling CoreV1Api->delete_namespaced_config_map"
             )
             raise CommandExecutionError(exc)
     finally:
@@ -1050,7 +1050,7 @@ def create_pod(name, namespace, metadata, spec, source, template, saltenv, **kwa
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception("Exception when calling " "CoreV1Api->create_namespaced_pod")
+            log.exception("Exception when calling CoreV1Api->create_namespaced_pod")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -1086,9 +1086,7 @@ def create_service(
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception(
-                "Exception when calling " "CoreV1Api->create_namespaced_service"
-            )
+            log.exception("Exception when calling CoreV1Api->create_namespaced_service")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -1101,7 +1099,7 @@ def create_secret(
     source=None,
     template=None,
     saltenv="base",
-    **kwargs
+    **kwargs,
 ):
     """
     Creates the kubernetes secret as defined by the user.
@@ -1142,9 +1140,7 @@ def create_secret(
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception(
-                "Exception when calling " "CoreV1Api->create_namespaced_secret"
-            )
+            log.exception("Exception when calling CoreV1Api->create_namespaced_secret")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -1189,7 +1185,7 @@ def create_configmap(
             return None
         else:
             log.exception(
-                "Exception when calling " "CoreV1Api->create_namespaced_config_map"
+                "Exception when calling CoreV1Api->create_namespaced_config_map"
             )
             raise CommandExecutionError(exc)
     finally:
@@ -1223,7 +1219,7 @@ def create_namespace(name, **kwargs):
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception("Exception when calling " "CoreV1Api->create_namespace")
+            log.exception("Exception when calling CoreV1Api->create_namespace")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -1278,7 +1274,7 @@ def replace_service(
     old_service,
     saltenv,
     namespace="default",
-    **kwargs
+    **kwargs,
 ):
     """
     Replaces an existing service with a new one defined by name and namespace,
@@ -1314,7 +1310,7 @@ def replace_service(
             return None
         else:
             log.exception(
-                "Exception when calling " "CoreV1Api->replace_namespaced_service"
+                "Exception when calling CoreV1Api->replace_namespaced_service"
             )
             raise CommandExecutionError(exc)
     finally:
@@ -1328,7 +1324,7 @@ def replace_secret(
     template=None,
     saltenv="base",
     namespace="default",
-    **kwargs
+    **kwargs,
 ):
     """
     Replaces an existing secret with a new one defined by name and namespace,
@@ -1370,9 +1366,7 @@ def replace_secret(
         if isinstance(exc, ApiException) and exc.status == 404:
             return None
         else:
-            log.exception(
-                "Exception when calling " "CoreV1Api->replace_namespaced_secret"
-            )
+            log.exception("Exception when calling CoreV1Api->replace_namespaced_secret")
             raise CommandExecutionError(exc)
     finally:
         _cleanup(**cfg)
@@ -1385,7 +1379,7 @@ def replace_configmap(
     template=None,
     saltenv="base",
     namespace="default",
-    **kwargs
+    **kwargs,
 ):
     """
     Replaces an existing configmap with a new one defined by name and
@@ -1422,7 +1416,7 @@ def replace_configmap(
             return None
         else:
             log.exception(
-                "Exception when calling " "CoreV1Api->replace_namespaced_configmap"
+                "Exception when calling CoreV1Api->replace_namespaced_configmap"
             )
             raise CommandExecutionError(exc)
     finally:
@@ -1452,7 +1446,7 @@ def __create_object_body(
             or src_obj["kind"] != kind
         ):
             raise CommandExecutionError(
-                "The source file should define only " "a {} object".format(kind)
+                f"The source file should define only a {kind} object"
             )
 
         if "metadata" in src_obj:
@@ -1473,7 +1467,7 @@ def __read_and_render_yaml_file(source, template, saltenv):
     """
     sfn = __salt__["cp.cache_file"](source, saltenv)
     if not sfn:
-        raise CommandExecutionError("Source file '{}' not found".format(source))
+        raise CommandExecutionError(f"Source file '{source}' not found")
 
     with salt.utils.files.fopen(sfn, "r") as src:
         contents = src.read()
@@ -1497,15 +1491,12 @@ def __read_and_render_yaml_file(source, template, saltenv):
                 if not data["result"]:
                     # Failed to render the template
                     raise CommandExecutionError(
-                        "Failed to render file path with error: "
-                        "{}".format(data["data"])
+                        "Failed to render file path with error: {}".format(data["data"])
                     )
 
                 contents = data["data"].encode("utf-8")
             else:
-                raise CommandExecutionError(
-                    "Unknown template specified: {}".format(template)
-                )
+                raise CommandExecutionError(f"Unknown template specified: {template}")
 
         return salt.utils.yaml.safe_load(contents)
 
