@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
 """
 Support for nftables
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import python libs
 import json
 import logging
 import re
@@ -13,12 +10,8 @@ import salt.utils.data
 import salt.utils.files
 import salt.utils.path
 from salt.exceptions import CommandExecutionError
-
-# Import salt libs
-from salt.ext import six
 from salt.state import STATE_INTERNAL_KEYWORDS as _STATE_INTERNAL_KEYWORDS
 
-# Set up logging
 log = logging.getLogger(__name__)
 
 _NFTABLES_FAMILIES = {
@@ -80,7 +73,7 @@ def version():
         salt '*' nftables.version
 
     """
-    cmd = "{0} --version".format(_nftables_cmd())
+    cmd = f"{_nftables_cmd()} --version"
     out = __salt__["cmd.run"](cmd).split()
     return out[1]
 
@@ -92,7 +85,7 @@ def build_rule(
     position="",
     full=None,
     family="ipv4",
-    **kwargs
+    **kwargs,
 ):
     """
     Build a well-formatted nftables rule based on kwargs.
@@ -142,11 +135,11 @@ def build_rule(
     nft_family = _NFTABLES_FAMILIES[family]
 
     if "if" in kwargs:
-        rule += "meta iifname {0} ".format(kwargs["if"])
+        rule += "meta iifname {} ".format(kwargs["if"])
         del kwargs["if"]
 
     if "of" in kwargs:
-        rule += "meta oifname {0} ".format(kwargs["of"])
+        rule += "meta oifname {} ".format(kwargs["of"])
         del kwargs["of"]
 
     if "proto" in kwargs:
@@ -156,18 +149,48 @@ def build_rule(
         del kwargs["state"]
 
     if "connstate" in kwargs:
-        rule += "ct state {{ {0}}} ".format(kwargs["connstate"])
+        rule += "ct state {{ {0} }} ".format(kwargs["connstate"])
         del kwargs["connstate"]
 
+    if "icmp-type" in kwargs:
+        rule += "icmp type {{ {0} }} ".format(kwargs["icmp-type"])
+        del kwargs["icmp-type"]
+
+    if "pkttype" in kwargs:
+        rule += "meta pkttype {{ {0} }} ".format(kwargs["pkttype"])
+        del kwargs["pkttype"]
+
+    if "counter" in kwargs:
+        rule += "counter "
+        del kwargs["counter"]
+
+    if "saddr" in kwargs or "source" in kwargs:
+        rule += "{} saddr {} ".format(
+            nft_family, kwargs.get("saddr") or kwargs.get("source")
+        )
+        if "saddr" in kwargs:
+            del kwargs["saddr"]
+        if "source" in kwargs:
+            del kwargs["source"]
+
+    if "daddr" in kwargs or "destination" in kwargs:
+        rule += "{} daddr {} ".format(
+            nft_family, kwargs.get("daddr") or kwargs.get("destination")
+        )
+        if "daddr" in kwargs:
+            del kwargs["daddr"]
+        if "destination" in kwargs:
+            del kwargs["destination"]
+
     if "dport" in kwargs:
-        kwargs["dport"] = six.text_type(kwargs["dport"])
+        kwargs["dport"] = str(kwargs["dport"])
         if ":" in kwargs["dport"]:
             kwargs["dport"] = kwargs["dport"].replace(":", "-")
         rule += "dport {{ {0} }} ".format(kwargs["dport"])
         del kwargs["dport"]
 
     if "sport" in kwargs:
-        kwargs["sport"] = six.text_type(kwargs["sport"])
+        kwargs["sport"] = str(kwargs["sport"])
         if ":" in kwargs["sport"]:
             kwargs["sport"] = kwargs["sport"].replace(":", "-")
         rule += "sport {{ {0} }} ".format(kwargs["sport"])
@@ -180,7 +203,7 @@ def build_rule(
         _dports = kwargs["dports"].split(",")
         _dports = [int(x) for x in _dports]
         _dports.sort(reverse=True)
-        kwargs["dports"] = ", ".join(six.text_type(x) for x in _dports)
+        kwargs["dports"] = ", ".join(str(x) for x in _dports)
 
         rule += "dport {{ {0} }} ".format(kwargs["dports"])
         del kwargs["dports"]
@@ -192,7 +215,7 @@ def build_rule(
         _sports = kwargs["sports"].split(",")
         _sports = [int(x) for x in _sports]
         _sports.sort(reverse=True)
-        kwargs["sports"] = ", ".join(six.text_type(x) for x in _sports)
+        kwargs["sports"] = ", ".join(str(x) for x in _sports)
 
         rule += "sport {{ {0} }} ".format(kwargs["sports"])
         del kwargs["sports"]
@@ -202,27 +225,36 @@ def build_rule(
     after_jump = []
 
     if "jump" in kwargs:
-        after_jump.append("{0} ".format(kwargs["jump"]))
+        after_jump.append("{} ".format(kwargs["jump"]))
         del kwargs["jump"]
 
     if "j" in kwargs:
-        after_jump.append("{0} ".format(kwargs["j"]))
+        after_jump.append("{} ".format(kwargs["j"]))
         del kwargs["j"]
 
-    if "to-port" in kwargs:
-        after_jump.append("--to-port {0} ".format(kwargs["to-port"]))
-        del kwargs["to-port"]
+    if "redirect-to" in kwargs or "to-port" in kwargs:
+        after_jump.append(
+            "redirect to {} ".format(kwargs.get("redirect-to") or kwargs.get("to-port"))
+        )
+        if "redirect-to" in kwargs:
+            del kwargs["redirect-to"]
+        if "to-port" in kwargs:
+            del kwargs["to-port"]
 
     if "to-ports" in kwargs:
-        after_jump.append("--to-ports {0} ".format(kwargs["to-ports"]))
+        after_jump.append("--to-ports {} ".format(kwargs["to-ports"]))
         del kwargs["to-ports"]
 
+    if "to-source" in kwargs:
+        after_jump.append("{} ".format(kwargs["to-source"]))
+        del kwargs["to-source"]
+
     if "to-destination" in kwargs:
-        after_jump.append("--to-destination {0} ".format(kwargs["to-destination"]))
+        after_jump.append("{} ".format(kwargs["to-destination"]))
         del kwargs["to-destination"]
 
     if "reject-with" in kwargs:
-        after_jump.append("--reject-with {0} ".format(kwargs["reject-with"]))
+        after_jump.append("reject with {} ".format(kwargs["reject-with"]))
         del kwargs["reject-with"]
 
     for item in after_jump:
@@ -232,8 +264,8 @@ def build_rule(
     rule = rule.strip()
 
     # Insert the protocol prior to dport or sport
-    rule = rule.replace("dport", "{0} dport".format(proto))
-    rule = rule.replace("sport", "{0} sport".format(proto))
+    rule = rule.replace("dport", f"{proto} dport")
+    rule = rule.replace("sport", f"{proto} sport")
 
     ret["rule"] = rule
 
@@ -253,15 +285,15 @@ def build_rule(
 
         if command in ["Insert", "insert", "INSERT"]:
             if position:
-                ret["rule"] = "{0} insert rule {1} {2} {3} " "position {4} {5}".format(
+                ret["rule"] = "{} insert rule {} {} {} position {} {}".format(
                     _nftables_cmd(), nft_family, table, chain, position, rule
                 )
             else:
-                ret["rule"] = "{0} insert rule " "{1} {2} {3} {4}".format(
+                ret["rule"] = "{} insert rule {} {} {} {}".format(
                     _nftables_cmd(), nft_family, table, chain, rule
                 )
         else:
-            ret["rule"] = "{0} {1} rule {2} {3} {4} {5}".format(
+            ret["rule"] = "{} {} rule {} {} {} {}".format(
                 _nftables_cmd(), command, nft_family, table, chain, rule
             )
 
@@ -313,13 +345,20 @@ def list_tables(family="ipv4"):
     """
     nft_family = _NFTABLES_FAMILIES[family]
     tables = []
-    cmd = "{0} --json --numeric --numeric --numeric " "list tables {1}".format(
+    cmd = "{} --json --numeric --numeric --numeric list tables {}".format(
         _nftables_cmd(), nft_family
     )
     out = __salt__["cmd.run"](cmd, python_shell=False)
     if not out:
         return tables
-    data = json.loads(out)
+
+    try:
+        data = json.loads(out)
+    except ValueError:
+        return tables
+
+    if not data or not data.get("nftables"):
+        return tables
 
     for item in data.get("nftables", []):
         if "metainfo" not in item:
@@ -347,7 +386,7 @@ def get_rules(family="ipv4"):
     rules = []
     for table in tables:
         table_name = table["name"]
-        cmd = "{0} --numeric --numeric --numeric " "list table {1} {2}".format(
+        cmd = "{} --numeric --numeric --numeric list table {} {}".format(
             _nftables_cmd(), nft_family, table_name
         )
         out = __salt__["cmd.run"](cmd, python_shell=False)
@@ -355,9 +394,48 @@ def get_rules(family="ipv4"):
     return rules
 
 
+def get_rules_json(family="ipv4"):
+    """
+    .. versionadded:: 3002
+
+    Return a list of dictionaries comprising the current, in-memory rules
+
+    family
+        Networking family, either ipv4 or ipv6
+
+    CLI Example:
+
+    .. code-block:: bash
+
+        salt '*' nftables.get_rules_json
+
+        salt '*' nftables.get_rules_json family=ipv6
+
+    """
+    nft_family = _NFTABLES_FAMILIES[family]
+    rules = []
+    cmd = "{} --numeric --numeric --numeric --json list ruleset {}".format(
+        _nftables_cmd(), nft_family
+    )
+    out = __salt__["cmd.run"](cmd, python_shell=False)
+    if not out:
+        return rules
+
+    try:
+        rules = (json.loads(out))["nftables"]
+    except (KeyError, ValueError):
+        return rules
+
+    return rules
+
+
 def save(filename=None, family="ipv4"):
     """
-    Save the current in-memory rules to disk
+    .. versionchanged:: 3002
+
+    Save the current in-memory rules to disk. On systems where /etc/nftables is
+    a directory, a file named salt-all-in-one.nft will be dropped inside by default.
+    The main nftables configuration will need to include this file.
 
     CLI Example:
 
@@ -368,8 +446,12 @@ def save(filename=None, family="ipv4"):
     if _conf() and not filename:
         filename = _conf()
 
-    nft_families = ["ip", "ip6", "arp", "bridge"]
+    # Invert the dictionary twice to get unique values only.
+    nft_families = {v: k for k, v in _NFTABLES_FAMILIES.items()}
+    nft_families = {v: k for k, v in nft_families.items()}
+
     rules = "#! nft -f\n"
+
     for family in nft_families:
         out = get_rules(family)
         if out:
@@ -377,14 +459,15 @@ def save(filename=None, family="ipv4"):
         rules = rules + "\n".join(out)
     rules = rules + "\n"
 
+    if __salt__["file.directory_exists"](filename):
+        filename = f"{filename}/salt-all-in-one.nft"
+
     try:
         with salt.utils.files.fopen(filename, "wb") as _fh:
             # Write out any changes
             _fh.write(salt.utils.data.encode(rules))
-    except (IOError, OSError) as exc:
-        raise CommandExecutionError(
-            "Problem writing to configuration file: {0}".format(exc)
-        )
+    except OSError as exc:
+        raise CommandExecutionError(f"Problem writing to configuration file: {exc}")
     return rules
 
 
@@ -432,18 +515,18 @@ def get_rule_handle(table="filter", chain=None, rule=None, family="ipv4"):
         return res
 
     nft_family = _NFTABLES_FAMILIES[family]
-    cmd = "{0} --numeric --numeric --numeric --handle list chain {1} {2} {3}".format(
+    cmd = "{} --numeric --numeric --numeric --handle list chain {} {} {}".format(
         _nftables_cmd(), nft_family, table, chain
     )
     out = __salt__["cmd.run"](cmd, python_shell=False)
     rules = re.split("\n+", out)
 
-    pat = re.compile(r"{0} # handle (?P<handle>\d+)".format(rule))
+    pat = re.compile(rf"{rule} # handle (?P<handle>\d+)")
     for r in rules:
         match = pat.search(r)
         if match:
             return {"result": True, "handle": match.group("handle")}
-    return {"result": False, "comment": "Could not find rule {0}".format(rule)}
+    return {"result": False, "comment": f"Could not find rule {rule}"}
 
 
 def check(table="filter", chain=None, rule=None, family="ipv4"):
@@ -486,22 +569,20 @@ def check(table="filter", chain=None, rule=None, family="ipv4"):
         return res
 
     nft_family = _NFTABLES_FAMILIES[family]
-    cmd = "{0} --handle --numeric --numeric --numeric list chain {1} {2} {3}".format(
+    cmd = "{} --handle --numeric --numeric --numeric list chain {} {} {}".format(
         _nftables_cmd(), nft_family, table, chain
     )
-    search_rule = "{0} #".format(rule)
+    search_rule = f"{rule} #"
     out = __salt__["cmd.run"](cmd, python_shell=False).find(search_rule)
 
     if out == -1:
-        ret[
-            "comment"
-        ] = "Rule {0} in chain {1} in table {2} in family {3} does not exist".format(
-            rule, chain, table, family
+        ret["comment"] = (
+            "Rule {} in chain {} in table {} in family {} does not exist".format(
+                rule, chain, table, family
+            )
         )
     else:
-        ret[
-            "comment"
-        ] = "Rule {0} in chain {1} in table {2} in family {3} exists".format(
+        ret["comment"] = "Rule {} in chain {} in table {} in family {} exists".format(
             rule, chain, table, family
         )
         ret["result"] = True
@@ -531,17 +612,15 @@ def check_chain(table="filter", chain=None, family="ipv4"):
         return ret
 
     nft_family = _NFTABLES_FAMILIES[family]
-    cmd = "{0} list table {1} {2}".format(_nftables_cmd(), nft_family, table)
-    out = __salt__["cmd.run"](cmd, python_shell=False).find(
-        "chain {0} {{".format(chain)
-    )
+    cmd = f"{_nftables_cmd()} list table {nft_family} {table}"
+    out = __salt__["cmd.run"](cmd, python_shell=False).find(f"chain {chain} {{")
 
     if out == -1:
-        ret["comment"] = "Chain {0} in table {1} in family {2} does not exist".format(
+        ret["comment"] = "Chain {} in table {} in family {} does not exist".format(
             chain, table, family
         )
     else:
-        ret["comment"] = "Chain {0} in table {1} in family {2} exists".format(
+        ret["comment"] = "Chain {} in table {} in family {} exists".format(
             chain, table, family
         )
         ret["result"] = True
@@ -552,7 +631,9 @@ def check_table(table=None, family="ipv4"):
     """
     Check for the existence of a table
 
-    CLI Example::
+    CLI Example:
+
+    .. code-block:: bash
 
         salt '*' nftables.check_table nat
     """
@@ -563,15 +644,15 @@ def check_table(table=None, family="ipv4"):
         return ret
 
     nft_family = _NFTABLES_FAMILIES[family]
-    cmd = "{0} list tables {1}".format(_nftables_cmd(), nft_family)
+    cmd = f"{_nftables_cmd()} list tables {nft_family}"
     out = __salt__["cmd.run"](cmd, python_shell=False).find(
-        "table {0} {1}".format(nft_family, table)
+        f"table {nft_family} {table}"
     )
 
     if out == -1:
-        ret["comment"] = "Table {0} in family {1} does not exist".format(table, family)
+        ret["comment"] = f"Table {table} in family {family} does not exist"
     else:
-        ret["comment"] = "Table {0} in family {1} exists".format(table, family)
+        ret["comment"] = f"Table {table} in family {family} exists"
         ret["result"] = True
     return ret
 
@@ -602,14 +683,14 @@ def new_table(table, family="ipv4"):
         return res
 
     nft_family = _NFTABLES_FAMILIES[family]
-    cmd = "{0} add table {1} {2}".format(_nftables_cmd(), nft_family, table)
+    cmd = f"{_nftables_cmd()} add table {nft_family} {table}"
     out = __salt__["cmd.run"](cmd, python_shell=False)
 
     if not out:
-        ret["comment"] = "Table {0} in family {1} created".format(table, family)
+        ret["comment"] = f"Table {table} in family {family} created"
         ret["result"] = True
     else:
-        ret["comment"] = "Table {0} in family {1} could not be created".format(
+        ret["comment"] = "Table {} in family {} could not be created".format(
             table, family
         )
     return ret
@@ -641,14 +722,14 @@ def delete_table(table, family="ipv4"):
         return res
 
     nft_family = _NFTABLES_FAMILIES[family]
-    cmd = "{0} delete table {1} {2}".format(_nftables_cmd(), nft_family, table)
+    cmd = f"{_nftables_cmd()} delete table {nft_family} {table}"
     out = __salt__["cmd.run"](cmd, python_shell=False)
 
     if not out:
-        ret["comment"] = "Table {0} in family {1} deleted".format(table, family)
+        ret["comment"] = f"Table {table} in family {family} deleted"
         ret["result"] = True
     else:
-        ret["comment"] = "Table {0} in family {1} could not be deleted".format(
+        ret["comment"] = "Table {} in family {} could not be deleted".format(
             table, family
         )
     return ret
@@ -693,15 +774,15 @@ def new_chain(
 
     res = check_chain(table, chain, family=family)
     if res["result"]:
-        ret["comment"] = "Chain {0} in table {1} in family {2} already exists".format(
+        ret["comment"] = "Chain {} in table {} in family {} already exists".format(
             chain, table, family
         )
         return ret
 
     nft_family = _NFTABLES_FAMILIES[family]
-    cmd = "{0} add chain {1} {2} {3}".format(_nftables_cmd(), nft_family, table, chain)
+    cmd = f"{_nftables_cmd()} -- add chain {nft_family} {table} {chain}"
     if table_type or hook or priority:
-        if table_type and hook and six.text_type(priority):
+        if table_type and hook and str(priority):
             cmd = r"{0} \{{ type {1} hook {2} priority {3}\; \}}".format(
                 cmd, table_type, hook, priority
             )
@@ -713,15 +794,15 @@ def new_chain(
     out = __salt__["cmd.run"](cmd, python_shell=False)
 
     if not out:
-        ret["comment"] = "Chain {0} in table {1} in family {2} created".format(
+        ret["comment"] = "Chain {} in table {} in family {} created".format(
             chain, table, family
         )
         ret["result"] = True
     else:
-        ret[
-            "comment"
-        ] = "Chain {0} in table {1} in family {2} could not be created".format(
-            chain, table, family
+        ret["comment"] = (
+            "Chain {} in table {} in family {} could not be created".format(
+                chain, table, family
+            )
         )
     return ret
 
@@ -760,21 +841,19 @@ def delete_chain(table="filter", chain=None, family="ipv4"):
         return res
 
     nft_family = _NFTABLES_FAMILIES[family]
-    cmd = "{0} delete chain {1} {2} {3}".format(
-        _nftables_cmd(), nft_family, table, chain
-    )
+    cmd = f"{_nftables_cmd()} delete chain {nft_family} {table} {chain}"
     out = __salt__["cmd.run"](cmd, python_shell=False)
 
     if not out:
-        ret["comment"] = "Chain {0} in table {1} in family {2} deleted".format(
+        ret["comment"] = "Chain {} in table {} in family {} deleted".format(
             chain, table, family
         )
         ret["result"] = True
     else:
-        ret[
-            "comment"
-        ] = "Chain {0} in table {1} in family {2} could not be deleted".format(
-            chain, table, family
+        ret["comment"] = (
+            "Chain {} in table {} in family {} could not be deleted".format(
+                chain, table, family
+            )
         )
     return ret
 
@@ -801,7 +880,7 @@ def append(table="filter", chain=None, rule=None, family="ipv4"):
             family=ipv6
     """
     ret = {
-        "comment": "Failed to append rule {0} to chain {1} in table {2}.".format(
+        "comment": "Failed to append rule {} to chain {} in table {}.".format(
             rule, chain, table
         ),
         "result": False,
@@ -825,31 +904,29 @@ def append(table="filter", chain=None, rule=None, family="ipv4"):
 
     res = check(table, chain, rule, family=family)
     if res["result"]:
-        ret[
-            "comment"
-        ] = "Rule {0} chain {1} in table {2} in family {3} already exists".format(
-            rule, chain, table, family
+        ret["comment"] = (
+            "Rule {} chain {} in table {} in family {} already exists".format(
+                rule, chain, table, family
+            )
         )
         return ret
 
     nft_family = _NFTABLES_FAMILIES[family]
-    cmd = "{0} add rule {1} {2} {3} {4}".format(
+    cmd = "{} add rule {} {} {} {}".format(
         _nftables_cmd(), nft_family, table, chain, rule
     )
     out = __salt__["cmd.run"](cmd, python_shell=False)
 
-    if len(out) == 0:
+    if not out:
         ret["result"] = True
-        ret[
-            "comment"
-        ] = 'Added rule "{0}" chain {1} in table {2} in family {3}.'.format(
+        ret["comment"] = 'Added rule "{}" chain {} in table {} in family {}.'.format(
             rule, chain, table, family
         )
     else:
-        ret[
-            "comment"
-        ] = 'Failed to add rule "{0}" chain {1} in table {2} in family {3}.'.format(
-            rule, chain, table, family
+        ret["comment"] = (
+            'Failed to add rule "{}" chain {} in table {} in family {}.'.format(
+                rule, chain, table, family
+            )
         )
     return ret
 
@@ -885,7 +962,7 @@ def insert(table="filter", chain=None, position=None, rule=None, family="ipv4"):
             family=ipv6
     """
     ret = {
-        "comment": "Failed to insert rule {0} to table {1}.".format(rule, table),
+        "comment": f"Failed to insert rule {rule} to table {table}.",
         "result": False,
     }
 
@@ -907,36 +984,34 @@ def insert(table="filter", chain=None, position=None, rule=None, family="ipv4"):
 
     res = check(table, chain, rule, family=family)
     if res["result"]:
-        ret[
-            "comment"
-        ] = "Rule {0} chain {1} in table {2} in family {3} already exists".format(
-            rule, chain, table, family
+        ret["comment"] = (
+            "Rule {} chain {} in table {} in family {} already exists".format(
+                rule, chain, table, family
+            )
         )
         return ret
 
     nft_family = _NFTABLES_FAMILIES[family]
     if position:
-        cmd = "{0} insert rule {1} {2} {3} position {4} {5}".format(
+        cmd = "{} insert rule {} {} {} position {} {}".format(
             _nftables_cmd(), nft_family, table, chain, position, rule
         )
     else:
-        cmd = "{0} insert rule {1} {2} {3} {4}".format(
+        cmd = "{} insert rule {} {} {} {}".format(
             _nftables_cmd(), nft_family, table, chain, rule
         )
     out = __salt__["cmd.run"](cmd, python_shell=False)
 
-    if len(out) == 0:
+    if not out:
         ret["result"] = True
-        ret[
-            "comment"
-        ] = 'Added rule "{0}" chain {1} in table {2} in family {3}.'.format(
+        ret["comment"] = 'Added rule "{}" chain {} in table {} in family {}.'.format(
             rule, chain, table, family
         )
     else:
-        ret[
-            "comment"
-        ] = 'Failed to add rule "{0}" chain {1} in table {2} in family {3}.'.format(
-            rule, chain, table, family
+        ret["comment"] = (
+            'Failed to add rule "{}" chain {} in table {} in family {}.'.format(
+                rule, chain, table, family
+            )
         )
     return ret
 
@@ -968,7 +1043,7 @@ def delete(table, chain=None, position=None, rule=None, family="ipv4"):
             family=ipv6
     """
     ret = {
-        "comment": "Failed to delete rule {0} in table {1}.".format(rule, table),
+        "comment": f"Failed to delete rule {rule} in table {table}.",
         "result": False,
     }
 
@@ -986,10 +1061,10 @@ def delete(table, chain=None, position=None, rule=None, family="ipv4"):
 
     res = check(table, chain, rule, family=family)
     if not res["result"]:
-        ret[
-            "comment"
-        ] = "Rule {0} chain {1} in table {2} in family {3} does not exist".format(
-            rule, chain, table, family
+        ret["comment"] = (
+            "Rule {} chain {} in table {} in family {} does not exist".format(
+                rule, chain, table, family
+            )
         )
         return ret
 
@@ -999,23 +1074,23 @@ def delete(table, chain=None, position=None, rule=None, family="ipv4"):
         position = get_rule_handle(table, chain, rule, family)
 
     nft_family = _NFTABLES_FAMILIES[family]
-    cmd = "{0} delete rule {1} {2} {3} handle {4}".format(
+    cmd = "{} delete rule {} {} {} handle {}".format(
         _nftables_cmd(), nft_family, table, chain, position
     )
     out = __salt__["cmd.run"](cmd, python_shell=False)
 
-    if len(out) == 0:
+    if not out:
         ret["result"] = True
-        ret[
-            "comment"
-        ] = 'Deleted rule "{0}" in chain {1} in table {2} in family {3}.'.format(
-            rule, chain, table, family
+        ret["comment"] = (
+            'Deleted rule "{}" in chain {} in table {} in family {}.'.format(
+                rule, chain, table, family
+            )
         )
     else:
-        ret[
-            "comment"
-        ] = 'Failed to delete rule "{0}" in chain {1}  table {2} in family {3}'.format(
-            rule, chain, table, family
+        ret["comment"] = (
+            'Failed to delete rule "{}" in chain {}  table {} in family {}'.format(
+                rule, chain, table, family
+            )
         )
     return ret
 
@@ -1037,7 +1112,7 @@ def flush(table="filter", chain="", family="ipv4"):
         salt '*' nftables.flush filter input family=ipv6
     """
     ret = {
-        "comment": "Failed to flush rules from chain {0} in table {1}.".format(
+        "comment": "Failed to flush rules from chain {} in table {}.".format(
             chain, table
         ),
         "result": False,
@@ -1053,20 +1128,129 @@ def flush(table="filter", chain="", family="ipv4"):
         res = check_chain(table, chain, family=family)
         if not res["result"]:
             return res
-        cmd = "{0} flush chain {1} {2} {3}".format(
+        cmd = "{} flush chain {} {} {}".format(
             _nftables_cmd(), nft_family, table, chain
         )
-        comment = "from chain {0} in table {1} in family {2}.".format(
-            chain, table, family
-        )
+        comment = f"from chain {chain} in table {table} in family {family}."
     else:
-        cmd = "{0} flush table {1} {2}".format(_nftables_cmd(), nft_family, table)
-        comment = "from table {0} in family {1}.".format(table, family)
+        cmd = f"{_nftables_cmd()} flush table {nft_family} {table}"
+        comment = f"from table {table} in family {family}."
     out = __salt__["cmd.run"](cmd, python_shell=False)
 
-    if len(out) == 0:
+    if not out:
         ret["result"] = True
-        ret["comment"] = "Flushed rules {0}".format(comment)
+        ret["comment"] = f"Flushed rules {comment}"
     else:
-        ret["comment"] = "Failed to flush rules {0}".format(comment)
+        ret["comment"] = f"Failed to flush rules {comment}"
     return ret
+
+
+def get_policy(table="filter", chain=None, family="ipv4"):
+    """
+    .. versionadded:: 3002
+
+    Return the current policy for the specified table/chain
+
+    table
+        Name of the table containing the chain to check
+
+    chain
+        Name of the chain to get the policy for
+
+    family
+        Networking family, either ipv4 or ipv6
+
+    CLI Example:
+
+    .. code-block:: bash
+
+        salt '*' nftables.get_policy filter input
+
+        IPv6:
+        salt '*' nftables.get_policy filter input family=ipv6
+    """
+    if not chain:
+        return "Error: Chain needs to be specified"
+
+    nft_family = _NFTABLES_FAMILIES[family]
+
+    rules = get_rules_json(family=nft_family)
+
+    try:
+        for rule in rules["nftables"]:
+            if (
+                rule.get("chain", {}).get("name") == chain
+                and rule.get("chain", {}).get("type") == table
+            ):
+                return rule["chain"]["policy"]
+    except (KeyError, TypeError, ValueError):
+        return None
+
+
+def set_policy(table="filter", chain=None, policy=None, family="ipv4"):
+    """
+    .. versionadded:: 3002
+
+    Set the current policy for the specified table/chain. This only works on
+    chains with an existing base chain.
+
+    table
+        Name of the table containing the chain to modify
+
+    chain
+        Name of the chain to set the policy for
+
+    policy
+        accept or drop
+
+    family
+        Networking family, either ipv4 or ipv6
+
+    CLI Example:
+
+    .. code-block:: bash
+
+        salt '*' nftables.set_policy filter input accept
+
+        IPv6:
+        salt '*' nftables.set_policy filter input accept family=ipv6
+    """
+    if not chain:
+        return "Error: Chain needs to be specified"
+    if not policy:
+        return "Error: Policy needs to be specified"
+
+    nft_family = _NFTABLES_FAMILIES[family]
+
+    chain_info = {}
+    rules = get_rules_json(family=nft_family)
+
+    if not rules:
+        return False
+
+    for rule in rules:
+        try:
+            if rule["chain"]["table"] == table and rule["chain"]["name"] == chain:
+                chain_info = rule["chain"]
+                break
+        except KeyError:
+            continue
+
+    if not chain_info:
+        return False
+
+    cmd = f"{_nftables_cmd()} add chain {nft_family} {table} {chain}"
+
+    # We can't infer the base chain parameters. Bail out if they're not present.
+    if "type" not in chain_info or "hook" not in chain_info or "prio" not in chain_info:
+        return False
+
+    params = "type {} hook {} priority {};".format(
+        chain_info["type"], chain_info["hook"], chain_info["prio"]
+    )
+
+    cmd = f'{cmd} "{{ {params} policy {policy}; }}"'
+
+    out = __salt__["cmd.run_all"](cmd, python_shell=False)
+
+    return not out["retcode"]
