@@ -67,7 +67,7 @@ salt-call from the GuestShell environment as follows.
 
 .. code-block:: bash
 
-    salt-call --local nxos.show 'show lldp neighbors' raw_text
+    salt-call --local nxos.sendline 'show lldp neighbors' raw_text
 
 .. note::
 
@@ -83,14 +83,12 @@ salt-call from the GuestShell environment as follows.
     salt '*' nxos.cmd get_user username=admin
 """
 
-# Import python stdlib
 import ast
 import difflib
 import logging
 import re
 from socket import error as socket_error
 
-# Import Salt libs
 import salt.utils.nxos
 import salt.utils.platform
 from salt.exceptions import CommandExecutionError, NxosError, SaltInvocationError
@@ -221,13 +219,13 @@ def cmd(command, *args, **kwargs):
         salt '*' nxos.cmd show_run
         salt '*' nxos.cmd check_password username=admin password='$5$lkjsdfoi$blahblahblah' encrypted=True
     """
-    warn_until("Silicon", "'nxos.cmd COMMAND' is deprecated in favor of 'nxos.COMMAND'")
+    warn_until("Argon", "'nxos.cmd COMMAND' is deprecated in favor of 'nxos.COMMAND'")
 
     for k in list(kwargs):
         if k.startswith("__pub_"):
             kwargs.pop(k)
     local_command = ".".join(["nxos", command])
-    log.info("local command: {}".format(local_command))
+    log.info("local command: %s", local_command)
     if local_command not in __salt__:
         return False
     return __salt__[local_command](*args, **kwargs)
@@ -260,8 +258,8 @@ def get_roles(username, **kwargs):
     user = get_user(username)
     if not user:
         return []
-    command = "show user-account {}".format(username)
-    info = show(command, **kwargs)
+    command = f"show user-account {username}"
+    info = sendline(command, **kwargs)
     if isinstance(info, list):
         info = info[0]
     roles = re.search(r"^\s*roles:(.*)$", info, re.MULTILINE)
@@ -280,8 +278,8 @@ def get_user(username, **kwargs):
 
         salt '*' nxos.get_user username=admin
     """
-    command = 'show run | include "^username {} password 5 "'.format(username)
-    info = show(command, **kwargs)
+    command = f'show run | include "^username {username} password 5 "'
+    info = sendline(command, **kwargs)
     if isinstance(info, list):
         info = info[0]
     return info
@@ -385,7 +383,7 @@ def show(commands, raw_text=True, **kwargs):
         salt 'regular-minion' nxos.show 'show interfaces' host=sw01.example.com username=test password=test
     """
     warn_until(
-        "Silicon",
+        "Argon",
         "'nxos.show commands' is deprecated in favor of 'nxos.sendline commands'",
     )
 
@@ -423,7 +421,7 @@ def show_ver(**kwargs):
         salt '*' nxos.show_ver
     """
     command = "show version"
-    info = show(command, **kwargs)
+    info = sendline(command, **kwargs)
     if isinstance(info, list):
         info = info[0]
     return info
@@ -438,7 +436,7 @@ def show_run(**kwargs):
         salt '*' nxos.show_run
     """
     command = "show running-config"
-    info = show(command, **kwargs)
+    info = sendline(command, **kwargs)
     if isinstance(info, list):
         info = info[0]
     return info
@@ -452,7 +450,7 @@ def system_info(**kwargs):
 
         salt '*' nxos.system_info
     """
-    warn_until("Silicon", "'nxos.system_info' is deprecated in favor of 'nxos.grains'")
+    warn_until("Argon", "'nxos.system_info' is deprecated in favor of 'nxos.grains'")
     return salt.utils.nxos.system_info(show_ver(**kwargs))["nxos"]
 
 
@@ -479,7 +477,7 @@ def add_config(lines, **kwargs):
         For more than one config added per command, lines should be a list.
     """
     warn_until(
-        "Silicon",
+        "Argon",
         "'nxos.add_config lines' is deprecated in favor of 'nxos.config commands'",
     )
 
@@ -494,7 +492,7 @@ def config(
     context=None,
     defaults=None,
     saltenv="base",
-    **kwargs
+    **kwargs,
 ):
     """
     Configures the Nexus switch with the specified commands.
@@ -558,13 +556,13 @@ def config(
         salt '*' nxos.config config_file=https://bit.ly/2LGLcDy context="{'servers': ['1.2.3.4']}"
     """
     kwargs = clean_kwargs(**kwargs)
-    initial_config = show("show running-config", **kwargs)
+    initial_config = sendline("show running-config", **kwargs)
     if isinstance(initial_config, list):
         initial_config = initial_config[0]
     if config_file:
         file_str = __salt__["cp.get_file_str"](config_file, saltenv=saltenv)
         if file_str is False:
-            raise CommandExecutionError("Source file {} not found".format(config_file))
+            raise CommandExecutionError(f"Source file {config_file} not found")
     elif commands:
         if isinstance(commands, str):
             commands = [commands]
@@ -588,7 +586,7 @@ def config(
         return e.strerror + "\n" + CONNECTION_ERROR_MSG
 
     config_result = _parse_config_result(config_result)
-    current_config = show("show running-config", **kwargs)
+    current_config = sendline("show running-config", **kwargs)
     if isinstance(current_config, list):
         current_config = current_config[0]
     diff = difflib.unified_diff(
@@ -666,7 +664,7 @@ def remove_user(username, **kwargs):
 
         salt '*' nxos.remove_user username=daniel
     """
-    user_line = "no username {}".format(username)
+    user_line = f"no username {username}"
     kwargs = clean_kwargs(**kwargs)
     return config(user_line, **kwargs)
 
@@ -683,7 +681,7 @@ def replace(old_value, new_value, full_match=False, **kwargs):
         salt '*' nxos.replace 'TESTSTRINGHERE' 'NEWTESTSTRINGHERE'
     """
     if full_match is False:
-        matcher = re.compile("^.*{}.*$".format(re.escape(old_value)), re.MULTILINE)
+        matcher = re.compile(f"^.*{re.escape(old_value)}.*$", re.MULTILINE)
         repl = re.compile(re.escape(old_value))
     else:
         matcher = re.compile(old_value, re.MULTILINE)
@@ -698,7 +696,7 @@ def replace(old_value, new_value, full_match=False, **kwargs):
     if lines["old"]:
         delete_config(lines["old"], **kwargs)
     if lines["new"]:
-        add_config(lines["new"], **kwargs)
+        config(lines["new"], **kwargs)
 
     return lines
 
@@ -721,7 +719,7 @@ def set_password(
     role=None,
     crypt_salt=None,
     algorithm="sha256",
-    **kwargs
+    **kwargs,
 ):
     """
     Set users password on switch.
@@ -769,9 +767,9 @@ def set_password(
         )
     else:
         hashed_pass = password
-    password_line = "username {} password 5 {}".format(username, hashed_pass)
+    password_line = f"username {username} password 5 {hashed_pass}"
     if role is not None:
-        password_line += " role {}".format(role)
+        password_line += f" role {role}"
     kwargs = clean_kwargs(**kwargs)
     return config(password_line, **kwargs)
 
@@ -795,7 +793,7 @@ def set_role(username, role, **kwargs):
 
         salt '*' nxos.set_role username=daniel role=vdc-admin.
     """
-    role_line = "username {} role {}".format(username, role)
+    role_line = f"username {username} role {role}"
     kwargs = clean_kwargs(**kwargs)
     return config(role_line, **kwargs)
 
@@ -819,7 +817,7 @@ def unset_role(username, role, **kwargs):
 
         salt '*' nxos.unset_role username=daniel role=vdc-admin
     """
-    role_line = "no username {} role {}".format(username, role)
+    role_line = f"no username {username} role {role}"
     kwargs = clean_kwargs(**kwargs)
     return config(role_line, **kwargs)
 
