@@ -136,7 +136,7 @@ def _clear_context(bin_env=None):
     """
     contextkey = "pip.version"
     if bin_env is not None:
-        contextkey = "{}.{}".format(contextkey, bin_env)
+        contextkey = f"{contextkey}.{bin_env}"
     __context__.pop(contextkey, None)
 
 
@@ -189,7 +189,7 @@ def _get_pip_bin(bin_env):
                         bin_path,
                     )
         raise CommandNotFoundError(
-            "Could not find a pip binary in virtualenv {}".format(bin_env)
+            f"Could not find a pip binary in virtualenv {bin_env}"
         )
 
     # bin_env is the python or pip binary
@@ -201,12 +201,10 @@ def _get_pip_bin(bin_env):
             # We have been passed a pip binary, use the pip binary.
             return [os.path.normpath(bin_env)]
 
-        raise CommandExecutionError(
-            "Could not find a pip binary within {}".format(bin_env)
-        )
+        raise CommandExecutionError(f"Could not find a pip binary within {bin_env}")
     else:
         raise CommandNotFoundError(
-            "Access denied to {}, could not find a pip binary".format(bin_env)
+            f"Access denied to {bin_env}, could not find a pip binary"
         )
 
 
@@ -412,9 +410,7 @@ def _format_env_vars(env_vars):
                     val = str(val)
                 ret[key] = val
         else:
-            raise CommandExecutionError(
-                "env_vars {} is not a dictionary".format(env_vars)
-            )
+            raise CommandExecutionError(f"env_vars {env_vars} is not a dictionary")
     return ret
 
 
@@ -759,7 +755,7 @@ def install(
 
     if log:
         if os.path.isdir(log):
-            raise OSError("'{}' is a directory. Use --log path_to_file".format(log))
+            raise OSError(f"'{log}' is a directory. Use --log path_to_file")
         if not os.path.exists(log):
             parent = os.path.dirname(log)
             if not os.path.exists(parent):
@@ -771,7 +767,7 @@ def install(
                     f"Trying to create '{log}' but parent directory '{parent}' is not writeable."
                 )
         elif not os.access(log, os.W_OK):
-            raise OSError("'{}' is not writeable".format(log))
+            raise OSError(f"'{log}' is not writeable")
 
         cmd.extend(["--log", log])
 
@@ -796,9 +792,7 @@ def install(
                 raise ValueError("Timeout cannot be a float")
             int(timeout)
         except ValueError:
-            raise ValueError(
-                "'{}' is not a valid timeout, must be an integer".format(timeout)
-            )
+            raise ValueError(f"'{timeout}' is not a valid timeout, must be an integer")
         cmd.extend(["--timeout", timeout])
 
     if find_links:
@@ -809,9 +803,7 @@ def install(
             if not (
                 salt.utils.url.validate(link, VALID_PROTOS) or os.path.exists(link)
             ):
-                raise CommandExecutionError(
-                    "'{}' is not a valid URL or path".format(link)
-                )
+                raise CommandExecutionError(f"'{link}' is not a valid URL or path")
             cmd.extend(["--find-links", link])
 
     if no_index and (index_url or extra_index_url):
@@ -821,14 +813,12 @@ def install(
 
     if index_url:
         if not salt.utils.url.validate(index_url, VALID_PROTOS):
-            raise CommandExecutionError("'{}' is not a valid URL".format(index_url))
+            raise CommandExecutionError(f"'{index_url}' is not a valid URL")
         cmd.extend(["--index-url", index_url])
 
     if extra_index_url:
         if not salt.utils.url.validate(extra_index_url, VALID_PROTOS):
-            raise CommandExecutionError(
-                "'{}' is not a valid URL".format(extra_index_url)
-            )
+            raise CommandExecutionError(f"'{extra_index_url}' is not a valid URL")
         cmd.extend(["--extra-index-url", extra_index_url])
 
     if no_index:
@@ -848,7 +838,7 @@ def install(
         cmd.append("--use-mirrors")
         for mirror in mirrors:
             if not mirror.startswith("http://"):
-                raise CommandExecutionError("'{}' is not a valid URL".format(mirror))
+                raise CommandExecutionError(f"'{mirror}' is not a valid URL")
             cmd.extend(["--mirrors", mirror])
 
     if disable_version_check:
@@ -872,9 +862,13 @@ def install(
     if download_cache or cache_dir:
         cmd.extend(
             [
-                "--cache-dir"
-                if salt.utils.versions.compare(ver1=cur_version, oper=">=", ver2="6.0")
-                else "--download-cache",
+                (
+                    "--cache-dir"
+                    if salt.utils.versions.compare(
+                        ver1=cur_version, oper=">=", ver2="6.0"
+                    )
+                    else "--download-cache"
+                ),
                 download_cache or cache_dir,
             ]
         )
@@ -1006,7 +1000,7 @@ def install(
                 # Don't allow any recursion into keyword arg definitions
                 # Don't allow multiple definitions of a keyword
                 if isinstance(val, (dict, list)):
-                    raise TypeError("Too many levels in: {}".format(key))
+                    raise TypeError(f"Too many levels in: {key}")
                 # This is a a normal one-to-one keyword argument
                 cmd.extend([key, val])
             # It is a positional argument, append it to the list
@@ -1119,7 +1113,7 @@ def uninstall(
             # TODO make this check if writeable
             os.path.exists(log)
         except OSError:
-            raise OSError("'{}' is not writeable".format(log))
+            raise OSError(f"'{log}' is not writeable")
 
         cmd.extend(["--log", log])
 
@@ -1144,9 +1138,7 @@ def uninstall(
                 raise ValueError("Timeout cannot be a float")
             int(timeout)
         except ValueError:
-            raise ValueError(
-                "'{}' is not a valid timeout, must be an integer".format(timeout)
-            )
+            raise ValueError(f"'{timeout}' is not a valid timeout, must be an integer")
         cmd.extend(["--timeout", timeout])
 
     if pkgs:
@@ -1406,7 +1398,7 @@ def version(bin_env=None, cwd=None, user=None):
     cwd = _pip_bin_env(cwd, bin_env)
     contextkey = "pip.version"
     if bin_env is not None:
-        contextkey = "{}.{}".format(contextkey, bin_env)
+        contextkey = f"{contextkey}.{bin_env}"
 
     if contextkey in __context__:
         return __context__[contextkey]
@@ -1669,18 +1661,16 @@ def list_all_versions(
         if salt.utils.versions.compare(ver1=pip_version, oper=">=", ver2="20.3"):
             cmd.append("--use-deprecated=legacy-resolver")
         regex = re.compile(r"\s*Could not find a version.* \(from versions: (.*)\)")
-        cmd.extend(["install", "{}==versions".format(pkg)])
+        cmd.extend(["install", f"{pkg}==versions"])
 
     if index_url:
         if not salt.utils.url.validate(index_url, VALID_PROTOS):
-            raise CommandExecutionError("'{}' is not a valid URL".format(index_url))
+            raise CommandExecutionError(f"'{index_url}' is not a valid URL")
         cmd.extend(["--index-url", index_url])
 
     if extra_index_url:
         if not salt.utils.url.validate(extra_index_url, VALID_PROTOS):
-            raise CommandExecutionError(
-                "'{}' is not a valid URL".format(extra_index_url)
-            )
+            raise CommandExecutionError(f"'{extra_index_url}' is not a valid URL")
         cmd.extend(["--extra-index-url", extra_index_url])
     cmd_kwargs = dict(
         cwd=cwd, runas=user, output_loglevel="quiet", redirect_stderr=True
