@@ -1,11 +1,8 @@
-# -*- coding: utf-8 -*-
 """
 Module to provide RabbitMQ compatibility to Salt.
 Todo: A lot, need to add cluster support, logging, and minion configuration
 data.
 """
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
 import logging
 import os
@@ -13,18 +10,13 @@ import random
 import re
 import string
 
-# Import Salt libs
 import salt.utils.itertools
 import salt.utils.json
 import salt.utils.path
 import salt.utils.platform
 import salt.utils.user
 from salt.exceptions import CommandExecutionError, SaltInvocationError
-
-# Import 3rd-party libs
-from salt.ext import six
-from salt.ext.six.moves import range
-from salt.utils.versions import LooseVersion as _LooseVersion
+from salt.utils.versions import Version
 
 log = logging.getLogger(__name__)
 
@@ -40,7 +32,7 @@ def __virtual__():
     global RABBITMQ_PLUGINS
 
     if salt.utils.platform.is_windows():
-        from salt.ext.six.moves import winreg
+        import winreg
 
         key = None
         try:
@@ -52,11 +44,9 @@ def __virtual__():
             )
             (dir_path, value_type) = winreg.QueryValueEx(key, "Install_Dir")
             if value_type != winreg.REG_SZ:
-                raise TypeError(
-                    "Invalid RabbitMQ Server directory type: {0}".format(value_type)
-                )
+                raise TypeError(f"Invalid RabbitMQ Server directory type: {value_type}")
             if not os.path.isdir(dir_path):
-                raise IOError("RabbitMQ directory not found: {0}".format(dir_path))
+                raise OSError(f"RabbitMQ directory not found: {dir_path}")
             subdir_match = ""
             for name in os.listdir(dir_path):
                 if name.startswith("rabbitmq_server-"):
@@ -65,10 +55,8 @@ def __virtual__():
                     if os.path.isdir(subdir_path) and subdir_path > subdir_match:
                         subdir_match = subdir_path
             if not subdir_match:
-                raise IOError(
-                    '"rabbitmq_server-*" subdirectory not found in: {0}'.format(
-                        dir_path
-                    )
+                raise OSError(
+                    f'"rabbitmq_server-*" subdirectory not found in: {dir_path}'
                 )
             RABBITMQCTL = os.path.join(subdir_match, "sbin", "rabbitmqctl.bat")
             RABBITMQ_PLUGINS = os.path.join(
@@ -92,24 +80,24 @@ def _check_response(response):
     if isinstance(response, dict):
         if response["retcode"] != 0 or response["stderr"]:
             raise CommandExecutionError(
-                "RabbitMQ command failed: {0}".format(response["stderr"])
+                "RabbitMQ command failed: {}".format(response["stderr"])
             )
     else:
         if "Error" in response:
-            raise CommandExecutionError("RabbitMQ command failed: {0}".format(response))
+            raise CommandExecutionError(f"RabbitMQ command failed: {response}")
 
 
 def _format_response(response, msg):
     if isinstance(response, dict):
         if response["retcode"] != 0 or response["stderr"]:
             raise CommandExecutionError(
-                "RabbitMQ command failed: {0}".format(response["stderr"])
+                "RabbitMQ command failed: {}".format(response["stderr"])
             )
         else:
             response = response["stdout"]
     else:
         if "Error" in response:
-            raise CommandExecutionError("RabbitMQ command failed: {0}".format(response))
+            raise CommandExecutionError(f"RabbitMQ command failed: {response}")
     return {msg: response}
 
 
@@ -125,8 +113,10 @@ def _get_rabbitmq_plugin():
     if RABBITMQ_PLUGINS is None:
         version = __salt__["pkg.version"]("rabbitmq-server").split("-")[0]
         RABBITMQ_PLUGINS = (
-            "/usr/lib/rabbitmq/lib/rabbitmq_server-{0}" "/sbin/rabbitmq-plugins"
-        ).format(version)
+            "/usr/lib/rabbitmq/lib/rabbitmq_server-{}/sbin/rabbitmq-plugins".format(
+                version
+            )
+        )
 
     return RABBITMQ_PLUGINS
 
@@ -167,13 +157,15 @@ def _output_to_dict(cmdoutput, values_mapper=None):
     if isinstance(cmdoutput, dict):
         if cmdoutput["retcode"] != 0 or cmdoutput["stderr"]:
             raise CommandExecutionError(
-                "RabbitMQ command failed: {0}".format(cmdoutput["stderr"])
+                "RabbitMQ command failed: {}".format(cmdoutput["stderr"])
             )
         cmdoutput = cmdoutput["stdout"]
 
     ret = {}
     if values_mapper is None:
-        values_mapper = lambda string: string.split("\t")
+
+        def values_mapper(string):
+            return string.split("\t")
 
     # remove first and last line: Listing ... - ...done
     data_rows = _strip_listing_to_done(cmdoutput.splitlines())
@@ -245,11 +237,11 @@ def list_users(runas=None):
     )
 
     # func to get tags from string such as "[admin, monitoring]"
-    func = (
-        lambda string: [x.strip() for x in string[1:-1].split(",")]
-        if "," in string
-        else [x for x in string[1:-1].split(" ")]
-    )
+    def func(string):
+        if "," in string:
+            return [x.strip() for x in string[1:-1].split(",")]
+        return [x for x in string[1:-1].split(" ")]
+
     return _output_to_dict(res, func)
 
 
@@ -386,7 +378,7 @@ def add_user(name, password=None, runas=None):
         #         command,\r\noperable program or batch file.
         # Work around this by using a shell and a quoted command.
         python_shell = True
-        cmd = '"{0}" add_user "{1}" "{2}"'.format(RABBITMQCTL, name, password)
+        cmd = f'"{RABBITMQCTL}" add_user "{name}" "{password}"'
     else:
         python_shell = False
         cmd = [RABBITMQCTL, "add_user", name, password]
@@ -456,7 +448,7 @@ def change_password(name, password, runas=None):
         #         command,\r\noperable program or batch file.
         # Work around this by using a shell and a quoted command.
         python_shell = True
-        cmd = '"{0}" change_password "{1}" "{2}"'.format(RABBITMQCTL, name, password)
+        cmd = f'"{RABBITMQCTL}" change_password "{name}" "{password}"'
     else:
         python_shell = False
         cmd = [RABBITMQCTL, "change_password", name, password]
@@ -547,9 +539,7 @@ def check_password(name, password, runas=None):
             #         command,\r\noperable program or batch file.
             # Work around this by using a shell and a quoted command.
             python_shell = True
-            cmd = '"{0}" authenticate_user "{1}" "{2}"'.format(
-                RABBITMQCTL, name, password
-            )
+            cmd = f'"{RABBITMQCTL}" authenticate_user "{name}" "{password}"'
         else:
             python_shell = False
             cmd = [RABBITMQCTL, "authenticate_user", name, password]
@@ -568,8 +558,10 @@ def check_password(name, password, runas=None):
 
     cmd = (
         "rabbit_auth_backend_internal:check_user_login"
-        '(<<"{0}">>, [{{password, <<"{1}">>}}]).'
-    ).format(name.replace('"', '\\"'), password.replace('"', '\\"'))
+        '(<<"{}">>, [{{password, <<"{}">>}}]).'.format(
+            name.replace('"', '\\"'), password.replace('"', '\\"')
+        )
+    )
 
     res = __salt__["cmd.run_all"](
         [RABBITMQCTL, "eval", cmd],
@@ -669,13 +661,19 @@ def list_permissions(vhost, runas=None):
     if runas is None and not salt.utils.platform.is_windows():
         runas = salt.utils.user.get_user()
     res = __salt__["cmd.run_all"](
-        [RABBITMQCTL, "list_permissions", "-q", "-p", vhost],
+        [RABBITMQCTL, "list_permissions", "--formatter=json", "-p", vhost],
         reset_system_locale=False,
         runas=runas,
         python_shell=False,
     )
 
-    return _output_to_dict(res)
+    perms = salt.utils.json.loads(res["stdout"])
+    perms_dict = {}
+    for perm in perms:
+        user = perm["user"]
+        perms_dict[user] = perm
+        del perms_dict[user]["user"]
+    return perms_dict
 
 
 def list_user_permissions(name, runas=None):
@@ -691,13 +689,19 @@ def list_user_permissions(name, runas=None):
     if runas is None and not salt.utils.platform.is_windows():
         runas = salt.utils.user.get_user()
     res = __salt__["cmd.run_all"](
-        [RABBITMQCTL, "list_user_permissions", name, "-q"],
+        [RABBITMQCTL, "list_user_permissions", name, "--formatter=json"],
         reset_system_locale=False,
         runas=runas,
         python_shell=False,
     )
 
-    return _output_to_dict(res)
+    perms = salt.utils.json.loads(res["stdout"])
+    perms_dict = {}
+    for perm in perms:
+        vhost = perm["vhost"]
+        perms_dict[vhost] = perm
+        del perms_dict[vhost]["vhost"]
+    return perms_dict
 
 
 def set_user_tags(name, tags, runas=None):
@@ -782,7 +786,7 @@ def join_cluster(host, user="rabbit", ram_node=None, runas=None):
     cmd = [RABBITMQCTL, "join_cluster"]
     if ram_node:
         cmd.append("--ram")
-    cmd.append("{0}@{1}".format(user, host))
+    cmd.append(f"{user}@{host}")
 
     if runas is None and not salt.utils.platform.is_windows():
         runas = salt.utils.user.get_user()
@@ -969,7 +973,7 @@ def list_policies(vhost="/", runas=None):
             ret[vhost] = {}
         ret[vhost][name] = {}
 
-        if _LooseVersion(version) >= _LooseVersion("3.7"):
+        if Version(version) >= Version("3.7"):
             # in version 3.7 the position of apply_to and pattern has been
             # switched
             ret[vhost][name]["pattern"] = parts[2]
@@ -1013,7 +1017,7 @@ def set_policy(
         runas = salt.utils.user.get_user()
     if isinstance(definition, dict):
         definition = salt.utils.json.dumps(definition)
-    if not isinstance(definition, six.string_types):
+    if not isinstance(definition, str):
         raise SaltInvocationError(
             "The 'definition' argument must be a dictionary or JSON string"
         )
