@@ -20,7 +20,7 @@ A simple example might be something like the following:
 .. code-block:: jinja
 
     {# a boolean check #}
-    {% set option_deprecated = salt['salt_version.less_than']("3001") %}
+    {% set option_deprecated = salt['salt_version.less_than']("Sodium") %}
 
     {% if option_deprecated %}
       <use old syntax>
@@ -30,12 +30,11 @@ A simple example might be something like the following:
 
 """
 
-# Import Python libs
-
 import logging
 
 import salt.utils.versions
 import salt.version
+from salt.exceptions import CommandExecutionError
 
 log = logging.getLogger(__name__)
 
@@ -52,7 +51,7 @@ def __virtual__():
 def get_release_number(name):
     """
     Returns the release number of a given release code name in a
-    ``MAJOR.PATCH`` format.
+    ``MAJOR.PATCH`` format (for Salt versions < 3000) or ``MAJOR`` for newer Salt versions.
 
     If the release name has not been given an assigned release number, the
     function returns a string. If the release cannot be found, it returns
@@ -67,18 +66,20 @@ def get_release_number(name):
 
         salt '*' salt_version.get_release_number 'Oxygen'
     """
+    if not isinstance(name, str):
+        raise CommandExecutionError("'name' argument must be a string")
+
     name = name.lower()
     version_map = salt.version.SaltStackVersion.LNAMES
     version = version_map.get(name)
     if version is None:
-        log.info("Version {} not found.".format(name))
+        log.info("Version %s not found.", name)
         return None
 
     try:
         if version[1] == 0:
             log.info(
-                "Version {} found, but no release number has been assigned "
-                "yet.".format(name)
+                "Version %s found, but no release number has been assigned yet.", name
             )
             return "No version assigned."
     except IndexError:
@@ -103,7 +104,7 @@ def equal(name):
         salt '*' salt_version.equal 'Oxygen'
     """
     if _check_release_cmp(name) == 0:
-        log.info("The minion's version code name matches '{}'.".format(name))
+        log.info("The minion's version code name matches '%s'.", name)
         return True
 
     return False
@@ -124,7 +125,7 @@ def greater_than(name):
         salt '*' salt_version.greater_than 'Oxygen'
     """
     if _check_release_cmp(name) == 1:
-        log.info("The minion's version code name is greater than '{}'.".format(name))
+        log.info("The minion's version code name is greater than '%s'.", name)
         return True
 
     return False
@@ -145,7 +146,7 @@ def less_than(name):
         salt '*' salt_version.less_than 'Oxygen'
     """
     if _check_release_cmp(name) == -1:
-        log.info("The minion's version code name is less than '{}'.".format(name))
+        log.info("The minion's version code name is less than '%s'.", name)
         return True
 
     return False
@@ -162,10 +163,14 @@ def _check_release_cmp(name):
     """
     map_version = get_release_number(name)
     if map_version is None:
-        log.info("Release code name {} was not found.".format(name))
+        log.info("Release code name %s was not found.", name)
         return None
 
-    current_version = str(salt.version.SaltStackVersion(*salt.version.__version_info__))
+    current_version = str(
+        salt.version.SaltStackVersion(  # pylint: disable=no-value-for-parameter
+            *salt.version.__version_info__
+        )
+    )
     current_version = current_version.rsplit(".", 1)[0]
     version_cmp = salt.utils.versions.version_cmp(current_version, map_version)
     return version_cmp
