@@ -297,7 +297,6 @@ Supported assertions
   ``saltcheck.run_highstate_tests`` are needed.
 """
 
-
 import copy
 import logging
 import multiprocessing
@@ -476,7 +475,7 @@ def run_state_tests(state, saltenv=None, check_all=False, only_fails=False):
 
         # Check for situations to disable parallization
         if parallel:
-            if type(num_proc) == float:
+            if isinstance(num_proc, float):
                 num_proc = int(num_proc)
 
             if multiprocessing.cpu_count() < 2:
@@ -648,7 +647,7 @@ def _is_valid_function(module_name, function):
         functions = __salt__["sys.list_functions"](module_name)
     except salt.exceptions.SaltException:
         functions = ["unable to look up functions"]
-    return "{}.{}".format(module_name, function) in functions
+    return f"{module_name}.{function}" in functions
 
 
 def _get_top_states(saltenv="base"):
@@ -875,19 +874,19 @@ class SaltCheck:
         if output_details:
             if assertion_section:
                 assertion_section_repr_title = " {}".format("assertion_section")
-                assertion_section_repr_value = " {}".format(assertion_section)
+                assertion_section_repr_value = f" {assertion_section}"
             else:
                 assertion_section_repr_title = ""
                 assertion_section_repr_value = ""
-            value[
-                "module.function [args]{}".format(assertion_section_repr_title)
-            ] = "{} {}{}".format(
-                mod_and_func,
-                dumps(args),
-                assertion_section_repr_value,
+            value[f"module.function [args]{assertion_section_repr_title}"] = (
+                "{} {}{}".format(
+                    mod_and_func,
+                    dumps(args),
+                    assertion_section_repr_value,
+                )
             )
             value["saltcheck assertion"] = "{}{} {}".format(
-                ("" if expected_return is None else "{} ".format(expected_return)),
+                ("" if expected_return is None else f"{expected_return} "),
                 assertion_desc,
                 ("hidden" if not assert_print_result else module_output),
             )
@@ -932,7 +931,7 @@ class SaltCheck:
                 for num, assert_group in enumerate(
                     test_dict.get("assertions"), start=1
                 ):
-                    result["assertion{}".format(num)] = self._run_assertions(
+                    result[f"assertion{num}"] = self._run_assertions(
                         mod_and_func,
                         args,
                         assert_group,
@@ -1032,7 +1031,7 @@ class SaltCheck:
         """
         result = "Pass"
         try:
-            assert returned is True, "{} not True".format(returned)
+            assert returned is True, f"{returned} not True"
         except AssertionError as err:
             result = "Fail: " + str(err)
         return result
@@ -1046,7 +1045,7 @@ class SaltCheck:
         if isinstance(returned, str):
             returned = bool(returned)
         try:
-            assert returned is False, "{} not False".format(returned)
+            assert returned is False, f"{returned} not False"
         except AssertionError as err:
             result = "Fail: " + str(err)
         return result
@@ -1092,7 +1091,7 @@ class SaltCheck:
         """
         result = "Pass"
         try:
-            assert expected > returned, "{} not False".format(returned)
+            assert expected > returned, f"{returned} not False"
         except AssertionError as err:
             result = "Fail: " + str(err)
         return result
@@ -1104,7 +1103,7 @@ class SaltCheck:
         """
         result = "Pass"
         try:
-            assert expected >= returned, "{} not False".format(returned)
+            assert expected >= returned, f"{returned} not False"
         except AssertionError as err:
             result = "Fail: " + str(err)
         return result
@@ -1116,7 +1115,7 @@ class SaltCheck:
         """
         result = "Pass"
         try:
-            assert expected < returned, "{} not False".format(returned)
+            assert expected < returned, f"{returned} not False"
         except AssertionError as err:
             result = "Fail: " + str(err)
         return result
@@ -1128,7 +1127,7 @@ class SaltCheck:
         """
         result = "Pass"
         try:
-            assert expected <= returned, "{} not False".format(returned)
+            assert expected <= returned, f"{returned} not False"
         except AssertionError as err:
             result = "Fail: " + str(err)
         return result
@@ -1140,7 +1139,7 @@ class SaltCheck:
         """
         result = "Pass"
         try:
-            assert not returned, "{} is not empty".format(returned)
+            assert not returned, f"{returned} is not empty"
         except AssertionError as err:
             result = "Fail: " + str(err)
         return result
@@ -1252,7 +1251,7 @@ class StateTestLoader:
         all_sls_paths.append(test_path)
 
         state_name_base = state_name.split(".")[0]
-        test_path = "salt://{}/{}".format(state_name_base, self.saltcheck_test_location)
+        test_path = f"salt://{state_name_base}/{self.saltcheck_test_location}"
         all_sls_paths.append(test_path)
 
         unique_paths = set(all_sls_paths)
@@ -1368,13 +1367,13 @@ class StateTestLoader:
                         os.path.join(
                             os.sep.join(split_sls[: len(split_sls) - 1]),
                             os.path.normpath(self.saltcheck_test_location),
-                            "{}.tst".format(split_sls[-1]),
+                            f"{split_sls[-1]}.tst",
                         ),
                         os.path.join(
                             split_sls[0],
                             os.path.normpath(self.saltcheck_test_location),
                             os.sep.join(split_sls[1:-1]),
-                            "{}.tst".format(split_sls[-1]),
+                            f"{split_sls[-1]}.tst",
                         ),
                     }
                     # for this state, find matching test files and load them
