@@ -79,7 +79,7 @@ def module_report():
             if hasattr(__salt__, ref):
                 ret["module_attrs"].append(ref)
             for func in __salt__[ref]:
-                full = "{}.{}".format(ref, func)
+                full = f"{ref}.{func}"
                 if hasattr(getattr(__salt__, ref), func):
                     ret["function_attrs"].append(full)
                 if func in __salt__[ref]:
@@ -427,7 +427,7 @@ def provider(module):
     """
     func = ""
     for key in __salt__:
-        if not key.startswith("{}.".format(module)):
+        if not key.startswith(f"{module}."):
             continue
         func = key
         break
