@@ -1,40 +1,40 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 Interface to Red Hat tuned-adm module
 
 :maintainer:    Syed Ali <alicsyed@gmail.com>
 :maturity:      new
 :depends:       tuned-adm
 :platform:      Linux
-'''
+"""
 
-# Import Python libs
-from __future__ import absolute_import
 import re
 
-# Import Salt libs
-import salt.utils
+import salt.utils.path
 
 __func_alias__ = {
-    'list_': 'list',
+    "list_": "list",
 }
 
-__virtualname__ = 'tuned'
+__virtualname__ = "tuned"
 
 
 def __virtual__():
-    '''
+    """
     Check to see if tuned-adm binary is installed on the system
 
-    '''
-    tuned_adm = salt.utils.which('tuned-adm')
+    """
+    tuned_adm = salt.utils.path.which("tuned-adm")
     if not tuned_adm:
-        return (False, 'The tuned execution module failed to load: the tuned-adm binary is not in the path.')
+        return (
+            False,
+            "The tuned execution module failed to load: the tuned-adm binary is not in"
+            " the path.",
+        )
     return __virtualname__
 
 
 def list_():
-    '''
+    """
     List the profiles available
 
     CLI Example:
@@ -42,21 +42,26 @@ def list_():
     .. code-block:: bash
 
         salt '*' tuned.list
-    '''
+    """
 
-    result = __salt__['cmd.run']('tuned-adm list').splitlines()
+    result = __salt__["cmd.run"]("tuned-adm list").splitlines()
     # Remove "Available profiles:"
     result.pop(0)
+    # Cut off any warnings
+    try:
+        result = result[: result.index("** COLLECTED WARNINGS **") - 1]
+    except ValueError:
+        pass
     # Remove "Current active profile:.*"
     result.pop()
     # Output can be : " - <profile name> - <description>" (v2.7.1)
     # or " - <profile name> " (v2.4.1)
-    result = [i.split('- ')[1].strip() for i in result]
+    result = [i.split("- ")[1].strip() for i in result]
     return result
 
 
 def active():
-    '''
+    """
     Return current active profile
 
     CLI Example:
@@ -64,17 +69,19 @@ def active():
     .. code-block:: bash
 
         salt '*' tuned.active
-    '''
+    """
 
     # turn off all profiles
-    result = __salt__['cmd.run']('tuned-adm active')
-    pattern = re.compile(r'''(?P<stmt>Current active profile:) (?P<profile>\w+.*)''')
-    match = re.match(pattern, result)
-    return '{0}'.format(match.group('profile'))
+    result = __salt__["cmd.run_all"]("tuned-adm active", ignore_retcode=True)
+    if result["retcode"] != 0:
+        return "none"
+    pattern = re.compile(r"""(?P<stmt>Current active profile:) (?P<profile>\w+.*)""")
+    match = re.match(pattern, result["stdout"])
+    return "{}".format(match.group("profile"))
 
 
 def off():
-    '''
+    """
     Turn off all profiles
 
     CLI Example:
@@ -82,17 +89,17 @@ def off():
     .. code-block:: bash
 
         salt '*' tuned.off
-    '''
+    """
 
     # turn off all profiles
-    result = __salt__['cmd.retcode']('tuned-adm off')
+    result = __salt__["cmd.retcode"]("tuned-adm off")
     if int(result) != 0:
         return False
     return True
 
 
 def profile(profile_name):
-    '''
+    """
     Activate specified profile
 
     CLI Example:
@@ -100,10 +107,10 @@ def profile(profile_name):
     .. code-block:: bash
 
         salt '*' tuned.profile virtual-guest
-    '''
+    """
 
     # run tuned-adm with the profile specified
-    result = __salt__['cmd.retcode']('tuned-adm profile {0}'.format(profile_name))
+    result = __salt__["cmd.retcode"](f"tuned-adm profile {profile_name}")
     if int(result) != 0:
         return False
-    return '{0}'.format(profile_name)
+    return f"{profile_name}"
