@@ -173,11 +173,11 @@ def _load_minion(minion_id, cache):
         pillar = {}
 
     addrs = {
-        4: sorted([ipaddress.IPv4Address(addr) for addr in grains.get("ipv4", [])]),
-        6: sorted([ipaddress.IPv6Address(addr) for addr in grains.get("ipv6", [])]),
+        4: sorted(ipaddress.IPv4Address(addr) for addr in grains.get("ipv4", [])),
+        6: sorted(ipaddress.IPv6Address(addr) for addr in grains.get("ipv6", [])),
     }
 
-    mine = cache.fetch("minions/{}".format(minion_id), "mine")
+    mine = cache.fetch(f"minions/{minion_id}", "mine")
 
     return grains, pillar, addrs, mine
 
@@ -199,15 +199,21 @@ def _data_lookup(ref, lookup):
 def _minion_lookup(minion_id, key, minion):
     grains, pillar, addrs, mine = minion
 
+    def _data_lookup_ref(data_id):
+        if data_id == "pillar":
+            return pillar
+        if data_id == "grains":
+            return grains
+        if data_id == "mine":
+            return mine
+
     if key == "id":
         # Just paste in the minion ID
         return minion_id
     elif isinstance(key, dict):
         # Lookup the key in the dict
         for data_id, lookup in key.items():
-            ref = {"pillar": pillar, "grain": grains, "mine": mine}[data_id]
-
-            for k in _data_lookup(ref, lookup):
+            for k in _data_lookup(_data_lookup_ref(data_id), lookup):
                 if k:
                     return k
 
@@ -220,7 +226,7 @@ def _minion_lookup(minion_id, key, minion):
         try:
             net = ipaddress.ip_network(key, strict=True)
         except ValueError:
-            log.error("%s is an invalid CIDR network", net)
+            log.error("%s is an invalid CIDR network", key)
             return None
 
         for addr in addrs[net.version]:
@@ -229,9 +235,9 @@ def _minion_lookup(minion_id, key, minion):
     else:
         # Take the addresses from the grains and filter them
         filters = {
-            "global": lambda addr: addr.is_global
-            if addr.version == 6
-            else not addr.is_private,
+            "global": lambda addr: (
+                addr.is_global if addr.version == 6 else not addr.is_private
+            ),
             "public": lambda addr: not addr.is_private,
             "private": lambda addr: addr.is_private
             and not addr.is_loopback
@@ -250,6 +256,4 @@ def _minion_lookup(minion_id, key, minion):
                     if filters[key](addr):
                         return str(addr)
             except KeyError:
-                raise KeyError(
-                    "Invalid filter {} specified in roster_order".format(key)
-                )
+                raise KeyError(f"Invalid filter {key} specified in roster_order")
