@@ -34,6 +34,7 @@ This API currently only supports RSA key types.  Support for other key types wil
 if interest warrants.
 
 """
+
 import logging
 import os
 import re
@@ -112,7 +113,7 @@ def _paginate(url, topkey, *args, **kwargs):
     aggregate_ret = ret["dict"][topkey]
     url = args[0]
     for p in range(2, numpages):
-        param_url = url + "?offset={}".format(lim * (p - 1))
+        param_url = url + f"?offset={lim * (p - 1)}"
         next_ret = salt.utils.http.query(param_url, kwargs)
         aggregate_ret[topkey].extend(next_ret["dict"][topkey])
 
@@ -131,9 +132,9 @@ def list_domains(container_id=None):
         salt-run digicert.list_domains
     """
     if container_id:
-        url = "{}/domain?{}".format(_base_url(), container_id)
+        url = f"{_base_url()}/domain?{container_id}"
     else:
-        url = "{}/domain".format(_base_url())
+        url = f"{_base_url()}/domain"
 
     orgs = _paginate(
         url,
@@ -160,9 +161,9 @@ def list_requests(status=None):
         salt-run digicert.list_requests pending
     """
     if status:
-        url = "{}/request?status={}".format(_base_url(), status)
+        url = f"{_base_url()}/request?status={status}"
     else:
-        url = "{}/request".format(_base_url())
+        url = f"{_base_url()}/request"
 
     reqs = _paginate(
         url,
@@ -188,7 +189,7 @@ def list_orders(status=None):
 
         salt-run digicert.list_orders
     """
-    url = "{}/order/certificate".format(_base_url())
+    url = f"{_base_url()}/order/certificate"
 
     reqs = _paginate(
         url,
@@ -238,7 +239,7 @@ def get_certificate(
 
     if order_id:
         order_cert = salt.utils.http.query(
-            "{}/order/certificate/{}".format(_base_url(), order_id),
+            f"{_base_url()}/order/certificate/{order_id}",
             method="GET",
             raise_error=False,
             decode=True,
@@ -262,7 +263,10 @@ def get_certificate(
             "certificate": {
                 "errors": {
                     "code": "unknown",
-                    "message": "Unknown error, no certificate ID passed on command line or in body returned from API",
+                    "message": (
+                        "Unknown error, no certificate ID passed on command line or in"
+                        " body returned from API"
+                    ),
                 }
             }
         }
@@ -369,7 +373,7 @@ def list_organizations(container_id=None, include_validation=True):
     """
 
     orgs = _paginate(
-        "{}/organization".format(_base_url()),
+        f"{_base_url()}/organization",
         "organizations",
         method="GET",
         decode=True,
@@ -492,7 +496,7 @@ def order_certificate(
     encoded_body = salt.utils.json.dumps(body)
 
     qdata = salt.utils.http.query(
-        "{}/order/certificate/ssl".format(_base_url()),
+        f"{_base_url()}/order/certificate/ssl",
         method="POST",
         data=encoded_body,
         decode=True,
@@ -568,7 +572,7 @@ def get_org_details(organization_id):
     """
 
     qdata = salt.utils.http.query(
-        "{}/organization/{}".format(_base_url(), organization_id),
+        f"{_base_url()}/organization/{organization_id}",
         method="GET",
         decode=True,
         decode_type="json",
@@ -620,8 +624,8 @@ def gen_csr(
     if "private_key" not in data:
         data["private_key"] = gen_key(minion_id, dns_name, password, key_len=key_len)
 
-    tmppriv = "{}/priv".format(tmpdir)
-    tmpcsr = "{}/csr".format(tmpdir)
+    tmppriv = f"{tmpdir}/priv"
+    tmpcsr = f"{tmpdir}/csr"
     with salt.utils.files.fopen(tmppriv, "w") as if_:
         if_.write(salt.utils.stringutils.to_str(data["private_key"]))
 
@@ -633,9 +637,9 @@ def gen_csr(
     )
 
     if ou_name:
-        subject = subject + "/OU={}".format(ou_name)
+        subject = subject + f"/OU={ou_name}"
 
-    subject = subject + "/CN={}".format(dns_name)
+    subject = subject + f"/CN={dns_name}"
 
     cmd = "openssl req -new -{} -key {} -out {} -subj '{}'".format(
         shatype, tmppriv, tmpcsr, subject
@@ -686,7 +690,7 @@ def show_organization(domain):
         salt-run digicert.show_company example.com
     """
     data = salt.utils.http.query(
-        "{}/companies/domain/{}".format(_base_url(), domain),
+        f"{_base_url()}/companies/domain/{domain}",
         status=True,
         decode=True,
         decode_type="json",
@@ -709,7 +713,7 @@ def show_csrs():
         salt-run digicert.show_csrs
     """
     data = salt.utils.http.query(
-        "{}/certificaterequests".format(_base_url()),
+        f"{_base_url()}/certificaterequests",
         status=True,
         decode=True,
         decode_type="json",
