@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
     salt.serializers
     ~~~~~~~~~~~~~~~~~~~~~~
@@ -15,8 +14,6 @@
 
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
-
 from salt.exceptions import SaltException, SaltRenderError
 
 
