@@ -2,7 +2,7 @@
 ACME / Let's Encrypt certificate management state
 =================================================
 
-.. versionadded:: 2016.3
+.. versionadded:: 2016.3.0
 
 See also the module documentation
 
@@ -109,15 +109,13 @@ def cert(
     else:
         ret["result"] = True
         ret["comment"].append(
-            "Certificate {} exists and does not need renewal." "".format(certname)
+            f"Certificate {certname} exists and does not need renewal."
         )
 
     if action:
         if __opts__["test"]:
             ret["result"] = None
-            ret["comment"].append(
-                "Certificate {} would have been {}ed." "".format(certname, action)
-            )
+            ret["comment"].append(f"Certificate {certname} would have been {action}ed.")
             ret["changes"] = {"old": "current certificate", "new": "new certificate"}
         else:
             res = __salt__["acme.cert"](
