@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Management of Docker containers
 
@@ -45,7 +44,6 @@ configuration remains unchanged.
     :ref:`here <docker-authentication>` for more information on how to
     configure access to docker registries in :ref:`Pillar <pillar>` data.
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 import copy
 import logging
@@ -54,7 +52,6 @@ import salt.utils.args
 import salt.utils.data
 import salt.utils.dockermod
 from salt.exceptions import CommandExecutionError
-from salt.ext import six
 
 # Enable proper logging
 log = logging.getLogger(__name__)  # pylint: disable=invalid-name
@@ -78,7 +75,7 @@ def _format_comments(ret, comments):
     DRY code for joining comments together and conditionally adding a period at
     the end, and adding this comment string to the state return dict.
     """
-    if isinstance(comments, six.string_types):
+    if isinstance(comments, str):
         ret["comment"] = comments
     else:
         ret["comment"] = ". ".join(comments)
@@ -127,14 +124,14 @@ def _parse_networks(networks):
             raise CommandExecutionError(
                 "Invalid network configuration (see documentation)"
             )
-        for net_name, net_conf in six.iteritems(networks):
+        for net_name, net_conf in networks.items():
             if net_conf is None:
                 networks[net_name] = {}
             else:
                 networks[net_name] = salt.utils.data.repack_dictlist(net_conf)
                 if not networks[net_name]:
                     raise CommandExecutionError(
-                        "Invalid configuration for network '{0}' "
+                        "Invalid configuration for network '{}' "
                         "(see documentation)".format(net_name)
                     )
                 for key in ("links", "aliases"):
@@ -148,12 +145,12 @@ def _parse_networks(networks):
         # Iterate over the networks again now, looking for
         # incorrectly-formatted arguments
         errors = []
-        for net_name, net_conf in six.iteritems(networks):
+        for net_name, net_conf in networks.items():
             if net_conf is not None:
-                for key, val in six.iteritems(net_conf):
+                for key, val in net_conf.items():
                     if val is None:
                         errors.append(
-                            "Config option '{0}' for network '{1}' is "
+                            "Config option '{}' for network '{}' is "
                             "missing a value".format(key, net_name)
                         )
         if errors:
@@ -166,13 +163,13 @@ def _parse_networks(networks):
             ]
         except CommandExecutionError as exc:
             raise CommandExecutionError(
-                "Failed to get list of existing networks: {0}.".format(exc)
+                f"Failed to get list of existing networks: {exc}."
             )
         else:
             missing_networks = [x for x in sorted(networks) if x not in all_networks]
             if missing_networks:
                 raise CommandExecutionError(
-                    "The following networks are not present: {0}".format(
+                    "The following networks are not present: {}".format(
                         ", ".join(missing_networks)
                     )
                 )
@@ -191,12 +188,11 @@ def _resolve_image(ret, image, client_timeout):
             # Image not pulled locally, so try pulling it
             try:
                 pull_result = __salt__["docker.pull"](
-                    image, client_timeout=client_timeout,
+                    image,
+                    client_timeout=client_timeout,
                 )
             except Exception as exc:  # pylint: disable=broad-except
-                raise CommandExecutionError(
-                    "Failed to pull {0}: {1}".format(image, exc)
-                )
+                raise CommandExecutionError(f"Failed to pull {image}: {exc}")
             else:
                 ret["changes"]["image"] = pull_result
                 # Try resolving again now that we've pulled
@@ -204,7 +200,7 @@ def _resolve_image(ret, image, client_timeout):
                 if image_id is False:
                     # Shouldn't happen unless the pull failed
                     raise CommandExecutionError(
-                        "Image '{0}' not present despite a docker pull "
+                        "Image '{}' not present despite a docker pull "
                         "raising no errors".format(image)
                     )
     return image_id
@@ -222,7 +218,7 @@ def running(
     shutdown_timeout=None,
     client_timeout=salt.utils.dockermod.CLIENT_TIMEOUT,
     networks=None,
-    **kwargs
+    **kwargs,
 ):
     """
     Ensure that a container with a specific configuration is present and
@@ -1674,8 +1670,8 @@ def running(
         ret["result"] = False
         ret["comment"] = "The 'image' argument is required"
         return ret
-    elif not isinstance(image, six.string_types):
-        image = six.text_type(image)
+    elif not isinstance(image, str):
+        image = str(image)
 
     try:
         # Since we're rewriting the "networks" value below, save the original
@@ -1690,7 +1686,7 @@ def running(
         if exc.info is not None:
             return _format_comments(ret, exc.info)
         else:
-            ret["comment"] = exc.__str__()
+            ret["comment"] = str(exc)
             return ret
 
     comments = []
@@ -1705,7 +1701,7 @@ def running(
     except KeyError:
         ret["result"] = False
         comments.append(
-            "Unable to detect current image for container '{0}'. "
+            "Unable to detect current image for container '{}'. "
             "This might be due to a change in the Docker API.".format(name)
         )
         return _format_comments(ret, comments)
@@ -1728,7 +1724,7 @@ def running(
         elif current_image_id != image_id:
             ret["changes"]["image"] = {"old": current_image_id, "new": image_id}
         comments.append(
-            "Container '{0}' would be {1}".format(
+            "Container '{}' would be {}".format(
                 name, "created" if not exists else "replaced"
             )
         )
@@ -1744,20 +1740,20 @@ def running(
             ignore_collisions=ignore_collisions,
             validate_ip_addrs=validate_ip_addrs,
             client_timeout=client_timeout,
-            **kwargs
+            **kwargs,
         )
         temp_container_name = temp_container["Name"]
     except KeyError as exc:
         ret["result"] = False
         comments.append(
-            "Key '{0}' missing from API response, this may be due to a "
+            "Key '{}' missing from API response, this may be due to a "
             "change in the Docker Remote API. Please report this on the "
             "SaltStack issue tracker if it has not already been reported.".format(exc)
         )
         return _format_comments(ret, comments)
     except Exception as exc:  # pylint: disable=broad-except
         ret["result"] = False
-        msg = exc.__str__()
+        msg = str(exc)
         if (
             isinstance(exc, CommandExecutionError)
             and isinstance(exc.info, dict)
@@ -1783,9 +1779,9 @@ def running(
             result = __salt__["docker.rename"](new, orig)
         except CommandExecutionError as exc:
             result = False
-            comments.append("Failed to rename temp container: {0}".format(exc))
+            comments.append(f"Failed to rename temp container: {exc}")
         if result:
-            comments.append("Replaced container '{0}'".format(orig))
+            comments.append(f"Replaced container '{orig}'")
         else:
             comments.append("Failed to replace container '{0}'")
         return result
@@ -1803,7 +1799,7 @@ def running(
         pre_net_connect = __salt__["docker.inspect_container"](
             name if exists else temp_container_name
         )
-        for net_name, net_conf in six.iteritems(networks):
+        for net_name, net_conf in networks.items():
             try:
                 __salt__["docker.connect_container_to_network"](
                     temp_container_name, net_name, **net_conf
@@ -1814,7 +1810,7 @@ def running(
                 # of the network's subnet. An exception will be raised once
                 # you try to start the container, however.
                 ret["result"] = False
-                comments.append(exc.__str__())
+                comments.append(str(exc))
                 return _format_comments(ret, comments)
 
         post_net_connect = __salt__["docker.inspect_container"](temp_container_name)
@@ -1847,8 +1843,17 @@ def running(
         )
 
         if not skip_comparison:
+            docker_version_info = __salt__["docker.version"]()["VersionInfo"]
+            if docker_version_info < (25, 0):
+                compare_containers_ignore = "Hostname"
+            else:
+                # With docker >= 25.0 we get a new value to compare,
+                # MacAddress, which we'll ignore for now.
+                compare_containers_ignore = "Hostname,MacAddress"
             container_changes = __salt__["docker.compare_containers"](
-                name, temp_container_name, ignore="Hostname",
+                name,
+                temp_container_name,
+                ignore=compare_containers_ignore,
             )
             if container_changes:
                 if _check_diff(container_changes):
@@ -1856,7 +1861,7 @@ def running(
                         "The detected changes may be due to incorrect "
                         "handling of arguments in earlier Salt releases. If "
                         "this warning persists after running the state "
-                        "again{0}, and no changes were made to the SLS file, "
+                        "again{}, and no changes were made to the SLS file, "
                         "then please report this.".format(
                             " without test=True" if __opts__["test"] else ""
                         )
@@ -1867,7 +1872,7 @@ def running(
                 if __opts__["test"]:
                     ret["result"] = None
                     comments.append(
-                        "Container '{0}' would be {1}".format(
+                        "Container '{}' would be {}".format(
                             name, "created" if not exists else "replaced"
                         )
                     )
@@ -1879,9 +1884,9 @@ def running(
                     if not _replace(name, temp_container_name):
                         ret["result"] = False
                         return _format_comments(ret, comments)
-                    ret["changes"].setdefault("container_id", {})[
-                        "added"
-                    ] = temp_container["Id"]
+                    ret["changes"].setdefault("container_id", {})["added"] = (
+                        temp_container["Id"]
+                    )
             else:
                 # No changes between existing container and temp container.
                 # First check if a requisite is asking to send a signal to the
@@ -1889,22 +1894,18 @@ def running(
                 if send_signal:
                     if __opts__["test"]:
                         comments.append(
-                            "Signal {0} would be sent to container".format(watch_action)
+                            f"Signal {watch_action} would be sent to container"
                         )
                     else:
                         try:
                             __salt__["docker.signal"](name, signal=watch_action)
                         except CommandExecutionError as exc:
                             ret["result"] = False
-                            comments.append(
-                                "Failed to signal container: {0}".format(exc)
-                            )
+                            comments.append(f"Failed to signal container: {exc}")
                             return _format_comments(ret, comments)
                         else:
                             ret["changes"]["signal"] = watch_action
-                            comments.append(
-                                "Sent signal {0} to container".format(watch_action)
-                            )
+                            comments.append(f"Sent signal {watch_action} to container")
                 elif container_changes:
                     if not comments:
                         log.warning(
@@ -1913,7 +1914,7 @@ def running(
                             name,
                         )
                         comments.append(
-                            "Container '{0}'{1} updated.".format(
+                            "Container '{}'{} updated.".format(
                                 name, " would be" if __opts__["test"] else ""
                             )
                         )
@@ -1922,9 +1923,7 @@ def running(
                     # existing container and the temp container were detected,
                     # and no signal was sent to the container.
                     comments.append(
-                        "Container '{0}' is already configured as specified".format(
-                            name
-                        )
+                        f"Container '{name}' is already configured as specified"
                     )
 
         if net_changes:
@@ -1947,7 +1946,7 @@ def running(
                             )
                             disconnected = True
                     except CommandExecutionError as exc:
-                        errors.append(exc.__str__())
+                        errors.append(str(exc))
 
                     if net_name in networks:
                         try:
@@ -1956,7 +1955,7 @@ def running(
                             )
                             connected = True
                         except CommandExecutionError as exc:
-                            errors.append(exc.__str__())
+                            errors.append(str(exc))
                             if disconnected:
                                 # We succeeded in disconnecting but failed
                                 # to reconnect. This can happen if the
@@ -1981,15 +1980,13 @@ def running(
 
                     if disconnected and connected:
                         comments.append(
-                            "Reconnected to network '{0}' with updated "
+                            "Reconnected to network '{}' with updated "
                             "configuration".format(net_name)
                         )
                     elif disconnected:
-                        comments.append(
-                            "Disconnected from network '{0}'".format(net_name)
-                        )
+                        comments.append(f"Disconnected from network '{net_name}'")
                     elif connected:
-                        comments.append("Connected to network '{0}'".format(net_name))
+                        comments.append(f"Connected to network '{net_name}'")
 
                 if network_failure:
                     ret["result"] = False
@@ -2000,7 +1997,7 @@ def running(
 
     if skip_comparison:
         if not exists:
-            comments.append("Created container '{0}'".format(name))
+            comments.append(f"Created container '{name}'")
         else:
             if not _replace(name, temp_container):
                 ret["result"] = False
@@ -2027,9 +2024,7 @@ def running(
                 post_state = __salt__["docker.start"](name)["state"]["new"]
             except Exception as exc:  # pylint: disable=broad-except
                 ret["result"] = False
-                comments.append(
-                    "Failed to start container '{0}': '{1}'".format(name, exc)
-                )
+                comments.append(f"Failed to start container '{name}': '{exc}'")
                 return _format_comments(ret, comments)
     else:
         post_state = __salt__["docker.state"](name)
@@ -2054,8 +2049,8 @@ def running(
         autoip_keys = __salt__["config.option"](
             "docker.compare_container_networks"
         ).get("automatic", [])
-        for net_name, net_changes in six.iteritems(
-            ret["changes"].get("container", {}).get("Networks", {})
+        for net_name, net_changes in (
+            ret["changes"].get("container", {}).get("Networks", {}).items()
         ):
             if (
                 "IPConfiguration" in net_changes
@@ -2074,9 +2069,7 @@ def running(
     if pre_state != post_state:
         ret["changes"]["state"] = {"old": pre_state, "new": post_state}
         if pre_state is not None:
-            comments.append(
-                "State changed from '{0}' to '{1}'".format(pre_state, post_state)
-            )
+            comments.append(f"State changed from '{pre_state}' to '{post_state}'")
 
     if exists and current_image_id != image_id:
         comments.append("Container has a new image")
@@ -2100,7 +2093,7 @@ def run(
     ignore_collisions=False,
     validate_ip_addrs=True,
     client_timeout=salt.utils.dockermod.CLIENT_TIMEOUT,
-    **kwargs
+    **kwargs,
 ):
     """
     .. versionadded:: 2018.3.0
@@ -2190,15 +2183,15 @@ def run(
     for unsupported in ("watch_action", "start", "shutdown_timeout", "follow"):
         if unsupported in kwargs:
             ret["result"] = False
-            ret["comment"] = "The '{0}' argument is not supported".format(unsupported)
+            ret["comment"] = f"The '{unsupported}' argument is not supported"
             return ret
 
     if image is None:
         ret["result"] = False
         ret["comment"] = "The 'image' argument is required"
         return ret
-    elif not isinstance(image, six.string_types):
-        image = six.text_type(image)
+    elif not isinstance(image, str):
+        image = str(image)
 
     try:
         if "networks" in kwargs and kwargs["networks"] is not None:
@@ -2209,12 +2202,12 @@ def run(
         if exc.info is not None:
             return _format_comments(ret, exc.info)
         else:
-            ret["comment"] = exc.__str__()
+            ret["comment"] = str(exc)
             return ret
 
     if __opts__["test"]:
         ret["result"] = None
-        ret["comment"] = "Container would be run{0}".format(
+        ret["comment"] = "Container would be run{}".format(
             " in the background" if bg else ""
         )
         return ret
@@ -2240,8 +2233,7 @@ def run(
                 if not ignore_collisions:
                     ret["result"] = False
                     ret["comment"] = (
-                        "'rm' is an alias for 'auto_remove', they cannot "
-                        "both be used"
+                        "'rm' is an alias for 'auto_remove', they cannot both be used"
                     )
                     return ret
             else:
@@ -2264,12 +2256,12 @@ def run(
             bg=bg,
             replace=replace,
             force=force,
-            **kwargs
+            **kwargs,
         )
     except Exception as exc:  # pylint: disable=broad-except
         log.exception("Encountered error running container")
         ret["result"] = False
-        ret["comment"] = "Encountered error running container: {0}".format(exc)
+        ret["comment"] = f"Encountered error running container: {exc}"
     else:
         if bg:
             ret["comment"] = "Container was run in the background"
@@ -2281,8 +2273,7 @@ def run(
             else:
                 ret["result"] = False if failhard and retcode != 0 else True
                 ret["comment"] = (
-                    "Container ran and exited with a return code of "
-                    "{0}".format(retcode)
+                    f"Container ran and exited with a return code of {retcode}"
                 )
 
     if remove:
@@ -2292,7 +2283,7 @@ def run(
                 __salt__["docker.rm"](ret["changes"]["Id"])
             except CommandExecutionError as exc:
                 ret.setdefault("warnings", []).append(
-                    "Failed to auto_remove container: {0}".format(exc)
+                    f"Failed to auto_remove container: {exc}"
                 )
 
     return ret
@@ -2304,7 +2295,7 @@ def stopped(
     shutdown_timeout=None,
     unpause=False,
     error_on_absent=True,
-    **kwargs
+    **kwargs,
 ):
     """
     Ensure that a container (or containers) is stopped
@@ -2364,12 +2355,12 @@ def stopped(
             return ret
         targets = []
         for target in containers:
-            if not isinstance(target, six.string_types):
-                target = six.text_type(target)
+            if not isinstance(target, str):
+                target = str(target)
             targets.append(target)
     elif name:
-        if not isinstance(name, six.string_types):
-            targets = [six.text_type(name)]
+        if not isinstance(name, str):
+            targets = [str(name)]
         else:
             targets = [name]
 
@@ -2385,7 +2376,7 @@ def stopped(
     errors = []
     if error_on_absent and "absent" in containers:
         errors.append(
-            "The following container(s) are absent: {0}".format(
+            "The following container(s) are absent: {}".format(
                 ", ".join(containers["absent"])
             )
         )
@@ -2393,7 +2384,7 @@ def stopped(
     if not unpause and "paused" in containers:
         ret["result"] = False
         errors.append(
-            "The following container(s) are paused: {0}".format(
+            "The following container(s) are paused: {}".format(
                 ", ".join(containers["paused"])
             )
         )
@@ -2408,7 +2399,7 @@ def stopped(
     if not to_stop:
         ret["result"] = True
         if len(targets) == 1:
-            ret["comment"] = "Container '{0}' is ".format(targets[0])
+            ret["comment"] = f"Container '{targets[0]}' is "
         else:
             ret["comment"] = "All specified containers are "
         if "absent" in containers:
@@ -2418,7 +2409,7 @@ def stopped(
 
     if __opts__["test"]:
         ret["result"] = None
-        ret["comment"] = "The following container(s) will be stopped: {0}".format(
+        ret["comment"] = "The following container(s) will be stopped: {}".format(
             ", ".join(to_stop)
         )
         return ret
@@ -2435,14 +2426,14 @@ def stopped(
             if "comment" in changes:
                 stop_errors.append(changes["comment"])
             else:
-                stop_errors.append("Failed to stop container '{0}'".format(target))
+                stop_errors.append(f"Failed to stop container '{target}'")
 
     if stop_errors:
         ret["comment"] = "; ".join(stop_errors)
         return ret
 
     ret["result"] = True
-    ret["comment"] = "The following container(s) were stopped: {0}".format(
+    ret["comment"] = "The following container(s) were stopped: {}".format(
         ", ".join(to_stop)
     )
     return ret
@@ -2476,35 +2467,33 @@ def absent(name, force=False):
 
     if name not in __salt__["docker.list_containers"](all=True):
         ret["result"] = True
-        ret["comment"] = "Container '{0}' does not exist".format(name)
+        ret["comment"] = f"Container '{name}' does not exist"
         return ret
 
     pre_state = __salt__["docker.state"](name)
     if pre_state != "stopped" and not force:
-        ret["comment"] = (
-            "Container is running, set force to True to " "forcibly remove it"
-        )
+        ret["comment"] = "Container is running, set force to True to forcibly remove it"
         return ret
 
     if __opts__["test"]:
         ret["result"] = None
-        ret["comment"] = "Container '{0}' will be removed".format(name)
+        ret["comment"] = f"Container '{name}' will be removed"
         return ret
 
     try:
         ret["changes"]["removed"] = __salt__["docker.rm"](name, force=force)
     except Exception as exc:  # pylint: disable=broad-except
-        ret["comment"] = "Failed to remove container '{0}': {1}".format(name, exc)
+        ret["comment"] = f"Failed to remove container '{name}': {exc}"
         return ret
 
     if name in __salt__["docker.list_containers"](all=True):
-        ret["comment"] = "Failed to remove container '{0}'".format(name)
+        ret["comment"] = f"Failed to remove container '{name}'"
     else:
         if force and pre_state != "stopped":
             method = "Forcibly"
         else:
             method = "Successfully"
-        ret["comment"] = "{0} removed container '{1}'".format(method, name)
+        ret["comment"] = f"{method} removed container '{name}'"
         ret["result"] = True
     return ret
 
@@ -2538,5 +2527,5 @@ def mod_watch(name, sfun=None, **kwargs):
         "name": name,
         "changes": {},
         "result": False,
-        "comment": ("watch requisite is not" " implemented for {0}".format(sfun)),
+        "comment": f"watch requisite is not implemented for {sfun}",
     }
