@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Management of user groups
 =========================
@@ -34,18 +33,11 @@ In Windows, if no domain is specified in the user or group name (i.e.
           - user2
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import sys
 
-# Import Salt libs
 import salt.utils.platform
 import salt.utils.win_functions
 
-# Import 3rd-party libs
-from salt.ext import six
-
 
 def _changes(name, gid=None, addusers=None, delusers=None, members=None):
     """
@@ -107,8 +99,18 @@ def _changes(name, gid=None, addusers=None, delusers=None, members=None):
     return change
 
 
-def present(name, gid=None, system=False, addusers=None, delusers=None, members=None):
+def present(
+    name,
+    gid=None,
+    system=False,
+    addusers=None,
+    delusers=None,
+    members=None,
+    non_unique=False,
+):
     r"""
+    .. versionchanged:: 3006.0
+
     Ensure that a group is present
 
     Args:
@@ -138,6 +140,11 @@ def present(name, gid=None, system=False, addusers=None, delusers=None, members=
             Replace existing group members with a list of new members. Cannot be
             used in conjunction with addusers or delusers.
 
+        non_unique (bool):
+            Allow creating groups with duplicate (non-unique) GIDs
+
+            .. versionadded:: 3006.0
+
     Example:
 
     .. code-block:: yaml
@@ -165,7 +172,7 @@ def present(name, gid=None, system=False, addusers=None, delusers=None, members=
         "name": name,
         "changes": {},
         "result": True,
-        "comment": "Group {0} is present and up to date".format(name),
+        "comment": f"Group {name} is present and up to date",
     }
 
     if members is not None and (addusers is not None or delusers is not None):
@@ -180,24 +187,24 @@ def present(name, gid=None, system=False, addusers=None, delusers=None, members=
         # -- if trying to add and delete the same user(s) at the same time.
         if not set(addusers).isdisjoint(set(delusers)):
             ret["result"] = None
-            ret[
-                "comment"
-            ] = "Error. Same user(s) can not be added and deleted simultaneously"
+            ret["comment"] = (
+                "Error. Same user(s) can not be added and deleted simultaneously"
+            )
             return ret
 
     changes = _changes(name, gid, addusers, delusers, members)
     if changes:
         ret["comment"] = "The following group attributes are set to be changed:\n"
-        for key, val in six.iteritems(changes):
-            ret["comment"] += "{0}: {1}\n".format(key, val)
+        for key, val in changes.items():
+            ret["comment"] += f"{key}: {val}\n"
 
         if __opts__["test"]:
             ret["result"] = None
             return ret
 
-        for key, val in six.iteritems(changes):
+        for key, val in changes.items():
             if key == "gid":
-                __salt__["group.chgid"](name, gid)
+                __salt__["group.chgid"](name, gid, non_unique=non_unique)
                 continue
             if key == "addusers":
                 for user in val:
@@ -226,12 +233,12 @@ def present(name, gid=None, system=False, addusers=None, delusers=None, members=
         # The group is not present, make it!
         if __opts__["test"]:
             ret["result"] = None
-            ret["comment"] = "Group {0} set to be added".format(name)
+            ret["comment"] = f"Group {name} set to be added"
             return ret
 
         grps = __salt__["group.getent"]()
         # Test if gid is free
-        if gid is not None:
+        if gid is not None and not non_unique:
             gid_group = None
             for lgrp in grps:
                 if lgrp["gid"] == gid:
@@ -241,13 +248,13 @@ def present(name, gid=None, system=False, addusers=None, delusers=None, members=
             if gid_group is not None:
                 ret["result"] = False
                 ret["comment"] = (
-                    "Group {0} is not present but gid {1} is already taken by"
-                    " group {2}".format(name, gid, gid_group)
+                    "Group {} is not present but gid {} is already taken by"
+                    " group {}".format(name, gid, gid_group)
                 )
                 return ret
 
         # Group is not present, make it.
-        if __salt__["group.add"](name, gid=gid, system=system):
+        if __salt__["group.add"](name, gid=gid, system=system, non_unique=non_unique):
             # if members to be added
             grp_members = None
             if members:
@@ -260,19 +267,19 @@ def present(name, gid=None, system=False, addusers=None, delusers=None, members=
             sys.modules[__salt__["test.ping"].__module__].__context__.pop(
                 "group.getent", None
             )
-            ret["comment"] = "New group {0} created".format(name)
+            ret["comment"] = f"New group {name} created"
             ret["changes"] = __salt__["group.info"](name)
             changes = _changes(name, gid, addusers, delusers, members)
             if changes:
                 ret["result"] = False
                 ret["comment"] = (
-                    "Group {0} has been created but, some changes could not"
+                    "Group {} has been created but, some changes could not"
                     " be applied".format(name)
                 )
                 ret["changes"] = {"Failed": changes}
         else:
             ret["result"] = False
-            ret["comment"] = "Failed to create new group {0}".format(name)
+            ret["comment"] = f"Failed to create new group {name}"
     return ret
 
 
@@ -298,15 +305,15 @@ def absent(name):
         # Group already exists. Remove the group.
         if __opts__["test"]:
             ret["result"] = None
-            ret["comment"] = "Group {0} is set for removal".format(name)
+            ret["comment"] = f"Group {name} is set for removal"
             return ret
         ret["result"] = __salt__["group.delete"](name)
         if ret["result"]:
             ret["changes"] = {name: ""}
-            ret["comment"] = "Removed group {0}".format(name)
+            ret["comment"] = f"Removed group {name}"
             return ret
         else:
-            ret["comment"] = "Failed to remove group {0}".format(name)
+            ret["comment"] = f"Failed to remove group {name}"
             return ret
     else:
         ret["comment"] = "Group not present"
