@@ -18,7 +18,6 @@ requisite to a pkg.installed state for the package which provides pip
           - pkg: python-pip
 """
 
-
 import logging
 import re
 import sys
@@ -198,7 +197,7 @@ def _check_pkg_version_format(pkg):
                 for vcs in supported_vcs:
                     if pkg.startswith(vcs):
                         from_vcs = True
-                        install_req = _from_line(pkg.split("{}+".format(vcs))[-1])
+                        install_req = _from_line(pkg.split(f"{vcs}+")[-1])
                         break
             else:
                 install_req = _from_line(pkg)
@@ -355,7 +354,10 @@ def _pep440_version_cmp(pkg1, pkg2, ignore_epoch=False):
             "The pkg_resources packages was not loaded. Please install setuptools."
         )
         return None
-    normalize = lambda x: str(x).split("!", 1)[-1] if ignore_epoch else str(x)
+
+    def normalize(x):
+        return str(x).split("!", 1)[-1] if ignore_epoch else str(x)
+
     pkg1 = normalize(pkg1)
     pkg2 = normalize(pkg2)
 
@@ -368,7 +370,7 @@ def _pep440_version_cmp(pkg1, pkg2, ignore_epoch=False):
             return 1
     except Exception as exc:  # pylint: disable=broad-except
         logger.exception(
-            f'Comparison of package versions "{pkg1}" and "{pkg2}" failed: {exc}'
+            'Comparison of package versions "%s" and "%s" failed: %s', pkg1, pkg2, exc
         )
     return None
 
@@ -735,11 +737,13 @@ def installed(
     # prepro = lambda pkg: pkg if type(pkg) == str else \
     #     ' '.join((pkg.items()[0][0], pkg.items()[0][1].replace(',', ';')))
     # pkgs = ','.join([prepro(pkg) for pkg in pkgs])
-    prepro = (
-        lambda pkg: pkg
-        if isinstance(pkg, str)
-        else " ".join((pkg.items()[0][0], pkg.items()[0][1]))
-    )
+    def prepro(pkg):
+        return (
+            pkg
+            if isinstance(pkg, str)
+            else " ".join((pkg.items()[0][0], pkg.items()[0][1]))
+        )
+
     pkgs = [prepro(pkg) for pkg in pkgs]
 
     ret = {"name": ";".join(pkgs), "result": None, "comment": "", "changes": {}}
@@ -748,7 +752,7 @@ def installed(
         cur_version = __salt__["pip.version"](bin_env)
     except (CommandNotFoundError, CommandExecutionError) as err:
         ret["result"] = False
-        ret["comment"] = "Error installing '{}': {}".format(name, err)
+        ret["comment"] = f"Error installing '{name}': {err}"
         return ret
     # Check that the pip binary supports the 'use_wheel' option
     if use_wheel:
@@ -841,7 +845,7 @@ def installed(
                 # TODO: Check requirements file against currently-installed
                 # packages to provide more accurate state output.
                 comments.append(
-                    "Requirements file '{}' will be processed.".format(requirements)
+                    f"Requirements file '{requirements}' will be processed."
                 )
             if editable:
                 comments.append(
@@ -862,7 +866,8 @@ def installed(
         # If we fail, then just send False, and we'll try again in the next function call
         except Exception as exc:  # pylint: disable=broad-except
             logger.exception(
-                f"Pre-caching of PIP packages during states.pip.installed failed by exception from pip.list: {exc}"
+                "Pre-caching of PIP packages during states.pip.installed failed by exception from pip.list: %s",
+                exc,
             )
             pip_list = False
 
@@ -945,7 +950,7 @@ def installed(
 
     # Call to install the package. Actual installation takes place here
     pip_install_call = __salt__["pip.install"](
-        pkgs="{}".format(pkgs_str) if pkgs_str else "",
+        pkgs=f"{pkgs_str}" if pkgs_str else "",
         requirements=requirements,
         bin_env=bin_env,
         use_wheel=use_wheel,
@@ -1072,10 +1077,10 @@ def installed(
                             and prefix.lower() not in already_installed_packages
                         ):
                             ver = pipsearch[prefix]
-                            ret["changes"]["{}=={}".format(prefix, ver)] = "Installed"
+                            ret["changes"][f"{prefix}=={ver}"] = "Installed"
                 # Case for packages that are an URL
                 else:
-                    ret["changes"]["{}==???".format(state_name)] = "Installed"
+                    ret["changes"][f"{state_name}==???"] = "Installed"
 
             # Set comments
             aicomms = "\n".join(already_installed_comments)
@@ -1100,19 +1105,15 @@ def installed(
         if requirements or editable:
             comments = []
             if requirements:
-                comments.append(
-                    'Unable to process requirements file "{}"'.format(requirements)
-                )
+                comments.append(f'Unable to process requirements file "{requirements}"')
             if editable:
-                comments.append(
-                    "Unable to install from VCS checkout {}.".format(editable)
-                )
+                comments.append(f"Unable to install from VCS checkout {editable}.")
             comments.append(error)
             ret["comment"] = " ".join(comments)
         else:
             pkgs_str = ", ".join([state_name for _, state_name in target_pkgs])
             aicomms = "\n".join(already_installed_comments)
-            error_comm = "Failed to install packages: {}. {}".format(pkgs_str, error)
+            error_comm = f"Failed to install packages: {pkgs_str}. {error}"
             ret["comment"] = aicomms + ("\n" if aicomms else "") + error_comm
     else:
         ret["result"] = False
@@ -1150,7 +1151,7 @@ def removed(
         pip_list = __salt__["pip.list"](bin_env=bin_env, user=user, cwd=cwd)
     except (CommandExecutionError, CommandNotFoundError) as err:
         ret["result"] = False
-        ret["comment"] = "Error uninstalling '{}': {}".format(name, err)
+        ret["comment"] = f"Error uninstalling '{name}': {err}"
         return ret
 
     if name not in pip_list:
@@ -1160,7 +1161,7 @@ def removed(
 
     if __opts__["test"]:
         ret["result"] = None
-        ret["comment"] = "Package {} is set to be removed".format(name)
+        ret["comment"] = f"Package {name} is set to be removed"
         return ret
 
     if __salt__["pip.uninstall"](
