@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Send a message to PushOver
 ==========================
@@ -28,9 +27,6 @@ The api key can be specified in the master or minion configuration like below:
 
 """
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 
 def __virtual__():
     """
@@ -106,18 +102,18 @@ def post_message(
     ret = {"name": name, "changes": {}, "result": False, "comment": ""}
 
     if __opts__["test"]:
-        ret["comment"] = "The following message is to be sent to PushOver: {0}".format(
+        ret["comment"] = "The following message is to be sent to PushOver: {}".format(
             message
         )
         ret["result"] = None
         return ret
 
     if not user:
-        ret["comment"] = "PushOver user is missing: {0}".format(user)
+        ret["comment"] = f"PushOver user is missing: {user}"
         return ret
 
     if not message:
-        ret["comment"] = "PushOver message is missing: {0}".format(message)
+        ret["comment"] = f"PushOver message is missing: {message}"
         return ret
 
     result = __salt__["pushover.post_message"](
@@ -133,8 +129,8 @@ def post_message(
 
     if result:
         ret["result"] = True
-        ret["comment"] = "Sent message: {0}".format(name)
+        ret["comment"] = f"Sent message: {name}"
     else:
-        ret["comment"] = "Failed to send message: {0}".format(name)
+        ret["comment"] = f"Failed to send message: {name}"
 
     return ret
