@@ -349,9 +349,11 @@ def state(
         cmd_ret = {
             __opts__["id"]: {
                 "ret": tmp_ret,
-                "out": tmp_ret.get("out", "highstate")
-                if isinstance(tmp_ret, dict)
-                else "highstate",
+                "out": (
+                    tmp_ret.get("out", "highstate")
+                    if isinstance(tmp_ret, dict)
+                    else "highstate"
+                ),
             }
         }
 
@@ -662,7 +664,7 @@ def wait_for_event(name, id_list, event_id="id", timeout=300, node="master"):
     ret = {"name": name, "changes": {}, "comment": "", "result": False}
 
     if __opts__.get("test"):
-        ret["comment"] = "Orchestration would wait for event '{}'".format(name)
+        ret["comment"] = f"Orchestration would wait for event '{name}'"
         ret["result"] = None
         return ret
 
@@ -782,7 +784,9 @@ def runner(name, **kwargs):
     try:
         kwargs["__pub_user"] = __user__
         log.debug(
-            f"added __pub_user to kwargs using dunder user '{__user__}', kwargs '{kwargs}'"
+            "added __pub_user to kwargs using dunder user '%s', kwargs '%s'",
+            __user__,
+            kwargs,
         )
     except NameError:
         log.warning("unable to find user for fire args event due to missing __user__")
@@ -792,7 +796,7 @@ def runner(name, **kwargs):
             "name": name,
             "result": None,
             "changes": {},
-            "comment": "Runner function '{}' would be executed.".format(name),
+            "comment": f"Runner function '{name}' would be executed.",
         }
         return ret
 
@@ -917,7 +921,7 @@ def parallel_runners(name, runners, **kwargs):  # pylint: disable=unused-argumen
             "result": False,
             "success": False,
             "changes": {},
-            "comment": "One of the runners raised an exception: {}".format(exc),
+            "comment": f"One of the runners raised an exception: {exc}",
         }
     # We bundle the results of the runners with the IDs of the runners so that
     # we can easily identify which output belongs to which runner. At the same
@@ -996,7 +1000,7 @@ def parallel_runners(name, runners, **kwargs):  # pylint: disable=unused-argumen
             comment = "All runner functions executed successfully."
         else:
             if len(failed_runners) == 1:
-                comment = "Runner {} failed.".format(failed_runners[0])
+                comment = f"Runner {failed_runners[0]} failed."
             else:
                 comment = "Runners {} failed.".format(", ".join(failed_runners))
         changes = {"ret": {runner_id: out for runner_id, out in outputs.items()}}
@@ -1042,7 +1046,7 @@ def wheel(name, **kwargs):
     if __opts__.get("test", False):
         ret["result"] = None
         ret["changes"] = {}
-        ret["comment"] = "Wheel function '{}' would be executed.".format(name)
+        ret["comment"] = f"Wheel function '{name}' would be executed."
         return ret
 
     out = __salt__["saltutil.wheel"](
