@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Managing implicit state and baselines using snapshots
 =====================================================
@@ -107,8 +106,6 @@ and include this change.
 :platform:      Linux
 """
 
-from __future__ import absolute_import, print_function, unicode_literals
-
 import os
 
 
@@ -180,9 +177,7 @@ def baseline_snapshot(
     if tag:
         snapshot = _get_baseline_from_tag(config, tag)
         if not snapshot:
-            ret.update(
-                {"result": False, "comment": 'Baseline tag "{0}" not found'.format(tag)}
-            )
+            ret.update({"result": False, "comment": f'Baseline tag "{tag}" not found'})
             return ret
         number = snapshot["id"]
 
@@ -211,7 +206,7 @@ def baseline_snapshot(
 
     if __opts__["test"] and status:
         ret["changes"] = status
-        ret["comment"] = "{0} files changes are set to be undone".format(
+        ret["comment"] = "{} files changes are set to be undone".format(
             len(status.keys())
         )
         ret["result"] = None
