@@ -1,7 +1,6 @@
-# -*- coding: utf-8 -*-
 """
-Management of user accounts
-===========================
+Management of user accounts.
+============================
 
 The user module is used to create and manage user settings, users can be set
 as either absent or present
@@ -23,13 +22,10 @@ as either absent or present
     testuser:
       user.absent
 """
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
 import logging
 import os
 
-# Import Salt libs
 import salt.utils.data
 import salt.utils.dateutils
 import salt.utils.platform
@@ -37,9 +33,6 @@ import salt.utils.user
 import salt.utils.versions
 from salt.exceptions import CommandExecutionError
 
-# Import 3rd-party libs
-from salt.ext import six
-
 log = logging.getLogger(__name__)
 
 
@@ -47,11 +40,29 @@ def _group_changes(cur, wanted, remove=False):
     """
     Determine if the groups need to be changed
     """
-    old = set(cur)
-    new = set(wanted)
-    if (remove and old != new) or (not remove and not new.issubset(old)):
-        return True
-    return False
+    cur = set(cur)
+    wanted = set(wanted)
+
+    if cur == wanted or (not remove and wanted.issubset(cur)):
+        return False
+
+    all_grps = {name: __salt__["group.info"](name) for name in cur.union(wanted)}
+
+    if remove:
+        diff = wanted.symmetric_difference(cur)
+    else:
+        diff = wanted.difference(cur)
+
+    remain = list(diff)
+    for diff_grp in diff:
+        for grp, info in all_grps.items():
+            if grp == diff_grp:
+                continue
+            if all_grps[diff_grp]["gid"] == info["gid"]:
+                # dupe detected
+                remain.remove(diff_grp)
+
+    return bool(remain)
 
 
 def _changes(
@@ -85,6 +96,7 @@ def _changes(
     win_description=None,
     allow_uid_change=False,
     allow_gid_change=False,
+    password_lock=None,
 ):
     """
     Return a dict of the changes required for a user if the user is present,
@@ -105,9 +117,18 @@ def _changes(
         return False
 
     change = {}
-    if groups is None:
-        groups = lusr["groups"]
     wanted_groups = sorted(set((groups or []) + (optional_groups or [])))
+    lusr_groups_gids = [
+        __salt__["file.group_to_gid"](gname) for gname in lusr["groups"]
+    ]
+    dupe_groups = {}
+    for idx, _gid in enumerate(lusr_groups_gids):
+        if lusr_groups_gids.count(_gid) > 1:
+            if _gid not in dupe_groups:
+                dupe_groups[_gid] = []
+            dupe_groups[_gid].append(lusr["groups"][idx])
+    if not remove_groups or groups is None and not optional_groups:
+        wanted_groups = sorted(set(wanted_groups + lusr["groups"]))
     if uid and lusr["uid"] != uid:
         change["uid"] = uid
     if gid is not None and lusr["gid"] not in (gid, __salt__["file.group_to_gid"](gid)):
@@ -115,24 +136,44 @@ def _changes(
     default_grp = __salt__["file.gid_to_group"](gid if gid is not None else lusr["gid"])
     old_default_grp = __salt__["file.gid_to_group"](lusr["gid"])
     # Remove the default group from the list for comparison purposes.
-    if default_grp in lusr["groups"]:
-        lusr["groups"].remove(default_grp)
+    # Remove default group from wanted_groups, as this requirement is
+    # already met
+    if default_grp in lusr["groups"] or default_grp in wanted_groups:
+        if default_grp in salt.utils.data.flatten(dupe_groups.values()):
+            dupe_gid = __salt__["file.group_to_gid"](default_grp)
+            for gname in dupe_groups[dupe_gid]:
+                if gname in lusr["groups"]:
+                    lusr["groups"].remove(gname)
+                if gname in wanted_groups:
+                    wanted_groups.remove(gname)
+        else:
+            if default_grp in lusr["groups"]:
+                lusr["groups"].remove(default_grp)
+            if default_grp in wanted_groups:
+                wanted_groups.remove(default_grp)
     # If the group is being changed, make sure that the old primary group is
     # also removed from the list. Otherwise, if a user's gid is being changed
     # and their old primary group is reassigned as an additional group, Salt
     # will not properly detect the need for the change.
     if old_default_grp != default_grp and old_default_grp in lusr["groups"]:
-        lusr["groups"].remove(old_default_grp)
+        if old_default_grp in salt.utils.data.flatten(dupe_groups.values()):
+            dupe_gid = __salt__["file.group_to_gid"](old_default_grp)
+            for gname in dupe_groups[dupe_gid]:
+                lusr["groups"].remove(gname)
+        else:
+            lusr["groups"].remove(old_default_grp)
     # If there's a group by the same name as the user, remove it from the list
     # for comparison purposes.
     if name in lusr["groups"] and name not in wanted_groups:
-        lusr["groups"].remove(name)
-    # Remove default group from wanted_groups, as this requirement is
-    # already met
-    if default_grp in wanted_groups:
-        wanted_groups.remove(default_grp)
+        if name in salt.utils.data.flatten(dupe_groups.values()):
+            dupe_gid = __salt__["file.group_to_gid"](name)
+            for gname in dupe_groups[dupe_gid]:
+                lusr["groups"].remove(gname)
+        else:
+            lusr["groups"].remove(name)
     if _group_changes(lusr["groups"], wanted_groups, remove_groups):
-        change["groups"] = wanted_groups
+        if wanted_groups or remove_groups:
+            change["groups"] = wanted_groups
     if home and lusr["home"] != home:
         change["home"] = home
     if createhome:
@@ -165,6 +206,10 @@ def _changes(
             change["warndays"] = warndays
         if expire and lshad["expire"] != expire:
             change["expire"] = expire
+        if (password_lock and not lshad["passwd"].startswith("!")) or (
+            password_lock is False and lshad["passwd"].startswith("!")
+        ):
+            change["password_lock"] = password_lock
     elif "shadow.info" in __salt__ and salt.utils.platform.is_windows():
         if (
             expire
@@ -173,6 +218,8 @@ def _changes(
             != salt.utils.dateutils.strftime(expire)
         ):
             change["expire"] = expire
+        if password_lock is False and lusr["account_locked"]:
+            change["password_lock"] = password_lock
 
     # GECOS fields
     fullname = salt.utils.data.decode(fullname)
@@ -219,13 +266,13 @@ def _changes(
     errors = []
     if not allow_uid_change and "uid" in change:
         errors.append(
-            "Changing uid ({0} -> {1}) not permitted, set allow_uid_change to "
+            "Changing uid ({} -> {}) not permitted, set allow_uid_change to "
             "True to force this change. Note that this will not change file "
             "ownership.".format(lusr["uid"], uid)
         )
     if not allow_gid_change and "gid" in change:
         errors.append(
-            "Changing gid ({0} -> {1}) not permitted, set allow_gid_change to "
+            "Changing gid ({} -> {}) not permitted, set allow_gid_change to "
             "True to force this change. Note that this will not change file "
             "ownership.".format(lusr["gid"], gid)
         )
@@ -273,7 +320,7 @@ def present(
     nologinit=False,
     allow_uid_change=False,
     allow_gid_change=False,
-    **kwargs
+    password_lock=None,
 ):
     """
     Ensure that the named user is present with the specified properties
@@ -376,6 +423,14 @@ def present(
     empty_password
         Set to True to enable password-less login for user, Default is ``False``.
 
+    password_lock
+        Set to ``False`` to unlock a user's password (or Windows account). On
+        non-Windows systems ONLY, this parameter can be set to ``True`` to lock
+        a user's password. Default is ``None``, which does not take action on
+        the password (or Windows account).
+
+        .. versionadded:: 3006.0
+
     shell
         The login shell, defaults to the system default shell
 
@@ -448,7 +503,7 @@ def present(
         home directory will be a unc path. Otherwise the home directory will be
         mapped to the specified drive. Must be a letter followed by a colon.
         Because of the colon, the value must be surrounded by single quotes. ie:
-        - win_homedrive: 'U:
+        ``- win_homedrive: 'U:'``
 
         .. versionchanged:: 2015.8.0
 
@@ -490,29 +545,29 @@ def present(
             if algo == "1":
                 log.warning("Using MD5 for hashing passwords is considered insecure!")
             log.debug(
-                "Re-using existing shadow salt for hashing password using {}".format(
-                    algorithms.get(algo)
-                )
+                "Re-using existing shadow salt for hashing password using %s",
+                algorithms.get(algo),
             )
             password = __salt__["shadow.gen_password"](
                 password, crypt_salt=shadow_salt, algorithm=algorithms.get(algo)
             )
         except ValueError:
             log.info(
-                "No existing shadow salt found, defaulting to a randomly generated new one"
+                "No existing shadow salt found, defaulting to a randomly generated"
+                " new one"
             )
             password = __salt__["shadow.gen_password"](password)
 
     if fullname is not None:
-        fullname = salt.utils.data.decode(fullname)
+        fullname = salt.utils.data.decode(str(fullname))
     if roomnumber is not None:
-        roomnumber = salt.utils.data.decode(roomnumber)
+        roomnumber = salt.utils.data.decode(str(roomnumber))
     if workphone is not None:
-        workphone = salt.utils.data.decode(workphone)
+        workphone = salt.utils.data.decode(str(workphone))
     if homephone is not None:
-        homephone = salt.utils.data.decode(homephone)
+        homephone = salt.utils.data.decode(str(homephone))
     if other is not None:
-        other = salt.utils.data.decode(other)
+        other = salt.utils.data.decode(str(other))
 
     # createhome not supported on Windows
     if __grains__["kernel"] == "Windows":
@@ -522,21 +577,21 @@ def present(
         "name": name,
         "changes": {},
         "result": True,
-        "comment": "User {0} is present and up to date".format(name),
+        "comment": f"User {name} is present and up to date",
     }
 
     # the comma is used to separate field in GECOS, thus resulting into
     # salt adding the end of fullname each time this function is called
     for gecos_field in [fullname, roomnumber, workphone]:
-        if isinstance(gecos_field, six.string_types) and "," in gecos_field:
-            ret["comment"] = "Unsupported char ',' in {0}".format(gecos_field)
+        if isinstance(gecos_field, str) and "," in gecos_field:
+            ret["comment"] = f"Unsupported char ',' in {gecos_field}"
             ret["result"] = False
             return ret
 
     if groups:
         missing_groups = [x for x in groups if not __salt__["group.info"](x)]
         if missing_groups:
-            ret["comment"] = "The following group(s) are not present: " "{0}".format(
+            ret["comment"] = "The following group(s) are not present: {}".format(
                 ",".join(missing_groups)
             )
             ret["result"] = False
@@ -560,34 +615,11 @@ def present(
     if groups and optional_groups:
         for isected in set(groups).intersection(optional_groups):
             log.warning(
-                'Group "%s" specified in both groups and optional_groups '
-                "for user %s",
+                'Group "%s" specified in both groups and optional_groups for user %s',
                 isected,
                 name,
             )
 
-    # Warn until Silicon release, when old gid_from_name argument is used.
-    # Since gid_from_name is the only thing that we're pulling from the kwargs,
-    # we can also remove **kwargs from the function definition once we remove
-    # the entire if block below. The following two tests will also become
-    # redundant when this block is cleaned up:
-    #
-    # integration.states.test_user.UserTest.test_user_present_gid_from_name
-    # integration.states.test_user.UserTest.test_user_present_gid_from_name_and_usergroup
-    gid_from_name = kwargs.pop("gid_from_name", None)
-    if gid_from_name is not None:
-        msg = (
-            "The 'gid_from_name' argument in the user.present state has "
-            "been replaced with 'usergroup'"
-        )
-        if usergroup is not None:
-            msg += ". Ignoring since 'usergroup' was also used."
-        else:
-            msg += ". Update your SLS file to get rid of this warning."
-            usergroup = gid_from_name
-        salt.utils.versions.warn_until("Silicon", msg)
-        ret.setdefault("warnings", []).append(msg)
-
     # If usergroup was specified, we'll also be creating a new
     # group. We should report this change without setting the gid
     # variable.
@@ -628,6 +660,7 @@ def present(
             win_description,
             allow_uid_change,
             allow_gid_change,
+            password_lock=password_lock,
         )
     except CommandExecutionError as exc:
         ret["result"] = False
@@ -637,13 +670,13 @@ def present(
     if changes:
         if __opts__["test"]:
             ret["result"] = None
-            ret["comment"] = "The following user attributes are set to be " "changed:\n"
-            for key, val in six.iteritems(changes):
+            ret["comment"] = "The following user attributes are set to be changed:\n"
+            for key, val in changes.items():
                 if key == "passwd":
                     val = "XXX-REDACTED-XXX"
                 elif key == "group" and not remove_groups:
                     key = "ensure groups"
-                ret["comment"] += "{0}: {1}\n".format(key, val)
+                ret["comment"] += f"{key}: {val}\n"
             return ret
         # The user is present
         if "shadow.info" in __salt__:
@@ -664,6 +697,17 @@ def present(
         if changes.pop("empty_password", False) is True:
             __salt__["shadow.del_password"](name)
 
+        if "password_lock" in changes:
+            passlock = changes.pop("password_lock")
+            if not passlock and salt.utils.platform.is_windows():
+                __salt__["shadow.unlock_account"](name)
+            elif not passlock:
+                __salt__["shadow.unlock_password"](name)
+            elif passlock and not salt.utils.platform.is_windows():
+                __salt__["shadow.lock_password"](name)
+            else:
+                log.warning("Account locking is not available on Windows.")
+
         if "date" in changes:
             del changes["date"]
             __salt__["shadow.set_date"](name, date)
@@ -730,11 +774,9 @@ def present(
         # NOTE: list(changes) required here to avoid modifying dictionary
         # during iteration.
         for key in [
-            x
-            for x in list(changes)
-            if x != "groups" and "user.ch{0}".format(x) in __salt__
+            x for x in list(changes) if x != "groups" and f"user.ch{x}" in __salt__
         ]:
-            __salt__["user.ch{0}".format(key)](name, changes.pop(key))
+            __salt__[f"user.ch{key}"](name, changes.pop(key))
 
         # Do group changes last
         if "groups" in changes:
@@ -742,7 +784,7 @@ def present(
 
         if changes:
             ret.get("warnings", []).append(
-                "Unhandled changes: {0}".format(", ".join(changes))
+                "Unhandled changes: {}".format(", ".join(changes))
             )
 
         post = __salt__["user.info"](name)
@@ -765,7 +807,7 @@ def present(
         if __grains__["kernel"] in ("OpenBSD", "FreeBSD") and lcpost != lcpre:
             ret["changes"]["loginclass"] = lcpost
         if ret["changes"]:
-            ret["comment"] = "Updated user {0}".format(name)
+            ret["comment"] = f"Updated user {name}"
         changes = _changes(
             name,
             uid,
@@ -797,6 +839,7 @@ def present(
             win_description,
             allow_uid_change=True,
             allow_gid_change=True,
+            password_lock=password_lock,
         )
         # allow_uid_change and allow_gid_change passed as True to avoid race
         # conditions where a uid/gid is modified outside of Salt. If an
@@ -804,7 +847,7 @@ def present(
         # first time we ran _changes().
 
         if changes:
-            ret["comment"] = "These values could not be changed: {0}".format(changes)
+            ret["comment"] = f"These values could not be changed: {changes}"
             ret["result"] = False
         return ret
 
@@ -812,7 +855,7 @@ def present(
         # The user is not present, make it!
         if __opts__["test"]:
             ret["result"] = None
-            ret["comment"] = "User {0} set to be added".format(name)
+            ret["comment"] = f"User {name} set to be added"
             return ret
         if groups and present_optgroups:
             groups.extend(present_optgroups)
@@ -853,9 +896,9 @@ def present(
                 "profile": win_profile,
                 "logonscript": win_logonscript,
             }
-
-        if __salt__["user.add"](**params):
-            ret["comment"] = "New user {0} created".format(name)
+        result = __salt__["user.add"](**params)
+        if result is True:
+            ret["comment"] = f"New user {name} created"
             ret["changes"] = __salt__["user.info"](name)
             if not createhome:
                 # pwd incorrectly reports presence of home
@@ -870,9 +913,9 @@ def present(
                     spost = __salt__["shadow.info"](name)
                     if spost["passwd"] != password:
                         ret["comment"] = (
-                            "User {0} created but failed to set"
-                            " password to"
-                            " {1}".format(name, "XXX-REDACTED-XXX")
+                            "User {} created but failed to set password to {}".format(
+                                name, "XXX-REDACTED-XXX"
+                            )
                         )
                         ret["result"] = False
                     ret["changes"]["password"] = "XXX-REDACTED-XXX"
@@ -881,8 +924,7 @@ def present(
                     spost = __salt__["shadow.info"](name)
                     if spost["passwd"] != "":
                         ret["comment"] = (
-                            "User {0} created but failed to "
-                            "empty password".format(name)
+                            f"User {name} created but failed to empty password"
                         )
                         ret["result"] = False
                     ret["changes"]["password"] = ""
@@ -891,9 +933,9 @@ def present(
                     spost = __salt__["shadow.info"](name)
                     if spost["lstchg"] != date:
                         ret["comment"] = (
-                            "User {0} created but failed to set"
+                            "User {} created but failed to set"
                             " last change date to"
-                            " {1}".format(name, date)
+                            " {}".format(name, date)
                         )
                         ret["result"] = False
                     ret["changes"]["date"] = date
@@ -902,9 +944,9 @@ def present(
                     spost = __salt__["shadow.info"](name)
                     if spost["min"] != mindays:
                         ret["comment"] = (
-                            "User {0} created but failed to set"
+                            "User {} created but failed to set"
                             " minimum days to"
-                            " {1}".format(name, mindays)
+                            " {}".format(name, mindays)
                         )
                         ret["result"] = False
                     ret["changes"]["mindays"] = mindays
@@ -913,9 +955,9 @@ def present(
                     spost = __salt__["shadow.info"](name)
                     if spost["max"] != maxdays:
                         ret["comment"] = (
-                            "User {0} created but failed to set"
+                            "User {} created but failed to set"
                             " maximum days to"
-                            " {1}".format(name, maxdays)
+                            " {}".format(name, maxdays)
                         )
                         ret["result"] = False
                     ret["changes"]["maxdays"] = maxdays
@@ -924,9 +966,9 @@ def present(
                     spost = __salt__["shadow.info"](name)
                     if spost["inact"] != inactdays:
                         ret["comment"] = (
-                            "User {0} created but failed to set"
+                            "User {} created but failed to set"
                             " inactive days to"
-                            " {1}".format(name, inactdays)
+                            " {}".format(name, inactdays)
                         )
                         ret["result"] = False
                     ret["changes"]["inactdays"] = inactdays
@@ -935,9 +977,9 @@ def present(
                     spost = __salt__["shadow.info"](name)
                     if spost["warn"] != warndays:
                         ret["comment"] = (
-                            "User {0} created but failed to set"
-                            " warn days to"
-                            " {1}".format(name, warndays)
+                            "User {} created but failed to set warn days to {}".format(
+                                name, warndays
+                            )
                         )
                         ret["result"] = False
                     ret["changes"]["warndays"] = warndays
@@ -946,9 +988,9 @@ def present(
                     spost = __salt__["shadow.info"](name)
                     if spost["expire"] != expire:
                         ret["comment"] = (
-                            "User {0} created but failed to set"
+                            "User {} created but failed to set"
                             " expire days to"
-                            " {1}".format(name, expire)
+                            " {}".format(name, expire)
                         )
                         ret["result"] = False
                     ret["changes"]["expire"] = expire
@@ -956,9 +998,9 @@ def present(
                 if password and not empty_password:
                     if not __salt__["user.setpassword"](name, password):
                         ret["comment"] = (
-                            "User {0} created but failed to set"
-                            " password to"
-                            " {1}".format(name, "XXX-REDACTED-XXX")
+                            "User {} created but failed to set password to {}".format(
+                                name, "XXX-REDACTED-XXX"
+                            )
                         )
                         ret["result"] = False
                     ret["changes"]["passwd"] = "XXX-REDACTED-XXX"
@@ -969,25 +1011,29 @@ def present(
                         spost["expire"]
                     ) != salt.utils.dateutils.strftime(expire):
                         ret["comment"] = (
-                            "User {0} created but failed to set"
+                            "User {} created but failed to set"
                             " expire days to"
-                            " {1}".format(name, expire)
+                            " {}".format(name, expire)
                         )
                         ret["result"] = False
                     ret["changes"]["expiration_date"] = spost["expire"]
             elif salt.utils.platform.is_darwin() and password and not empty_password:
                 if not __salt__["shadow.set_password"](name, password):
                     ret["comment"] = (
-                        "User {0} created but failed to set"
-                        " password to"
-                        " {1}".format(name, "XXX-REDACTED-XXX")
+                        "User {} created but failed to set password to {}".format(
+                            name, "XXX-REDACTED-XXX"
+                        )
                     )
                     ret["result"] = False
                 ret["changes"]["passwd"] = "XXX-REDACTED-XXX"
         else:
-            ret["comment"] = "Failed to create new user {0}".format(name)
+            # if we failed to create a user, result is either false or
+            # str in the case of windows so handle both cases here
+            if isinstance(result, str):
+                ret["comment"] = result
+            else:
+                ret["comment"] = f"Failed to create new user {name}"
             ret["result"] = False
-
     return ret
 
 
@@ -1014,22 +1060,22 @@ def absent(name, purge=False, force=False):
         # The user is present, make it not present
         if __opts__["test"]:
             ret["result"] = None
-            ret["comment"] = "User {0} set for removal".format(name)
+            ret["comment"] = f"User {name} set for removal"
             return ret
         beforegroups = set(salt.utils.user.get_group_list(name))
         ret["result"] = __salt__["user.delete"](name, purge, force)
-        aftergroups = set([g for g in beforegroups if __salt__["group.info"](g)])
+        aftergroups = {g for g in beforegroups if __salt__["group.info"](g)}
         if ret["result"]:
             ret["changes"] = {}
             for g in beforegroups - aftergroups:
-                ret["changes"]["{0} group".format(g)] = "removed"
+                ret["changes"][f"{g} group"] = "removed"
             ret["changes"][name] = "removed"
-            ret["comment"] = "Removed user {0}".format(name)
+            ret["comment"] = f"Removed user {name}"
         else:
             ret["result"] = False
-            ret["comment"] = "Failed to remove user {0}".format(name)
+            ret["comment"] = f"Failed to remove user {name}"
         return ret
 
-    ret["comment"] = "User {0} is not present".format(name)
+    ret["comment"] = f"User {name} is not present"
 
     return ret
