@@ -141,9 +141,7 @@ class ContextDict(MutableMapping):
 
 
 class ChildContextDict(MutableMapping):
-    """An overrideable child of ContextDict
-
-    """
+    """An overrideable child of ContextDict"""
 
     def __init__(self, parent, overrides=None, threadsafe=False):
         self.parent = parent
