@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
     :codeauthor: Pedro Algarvio (pedro@algarvio.me)
 
@@ -8,7 +7,6 @@
 
     Immutable types
 """
-from __future__ import absolute_import, unicode_literals
 
 import copy
 from collections.abc import Mapping, Sequence, Set
@@ -32,7 +30,7 @@ class ImmutableDict(Mapping):
         return freeze(self.__obj[key])
 
     def __repr__(self):
-        return "<{0} {1}>".format(self.__class__.__name__, repr(self.__obj))
+        return f"<{self.__class__.__name__} {repr(self.__obj)}>"
 
     def __deepcopy__(self, memo):
         return copy.deepcopy(self.__obj)
@@ -68,11 +66,17 @@ class ImmutableList(Sequence):
         return freeze(self.__obj[key])
 
     def __repr__(self):
-        return "<{0} {1}>".format(self.__class__.__name__, repr(self.__obj))
+        return f"<{self.__class__.__name__} {repr(self.__obj)}>"
 
     def __deepcopy__(self, memo):
         return copy.deepcopy(self.__obj)
 
+    def copy(self):
+        """
+        Return an un-frozen copy of self
+        """
+        return copy.deepcopy(self.__obj)
+
 
 class ImmutableSet(Set):
     """
@@ -92,11 +96,17 @@ class ImmutableSet(Set):
         return key in self.__obj
 
     def __repr__(self):
-        return "<{0} {1}>".format(self.__class__.__name__, repr(self.__obj))
+        return f"<{self.__class__.__name__} {repr(self.__obj)}>"
 
     def __deepcopy__(self, memo):
         return copy.deepcopy(self.__obj)
 
+    def copy(self):
+        """
+        Return an un-frozen copy of self
+        """
+        return copy.deepcopy(self.__obj)
+
 
 def freeze(obj):
     """
