@@ -1,6 +1,7 @@
 """
 Functions for daemonizing and otherwise modifying running processes
 """
+
 import contextlib
 import copy
 import errno
@@ -27,6 +28,7 @@ import salt.utils.path
 import salt.utils.platform
 import salt.utils.versions
 from salt.ext.tornado import gen
+from salt.utils.platform import get_machine_identifier as _get_machine_identifier
 
 log = logging.getLogger(__name__)
 
@@ -45,6 +47,9 @@ try:
 except ImportError:
     HAS_SETPROCTITLE = False
 
+# Process finalization function list
+_INTERNAL_PROCESS_FINALIZE_FUNCTION_LIST = []
+
 
 def appendproctitle(name):
     """
@@ -54,7 +59,7 @@ def appendproctitle(name):
         current = setproctitle.getproctitle()
         if current.strip().endswith("MainProcess"):
             current, _ = current.rsplit("MainProcess", 1)
-        setproctitle.setproctitle("{} {}".format(current.rstrip(), name))
+        setproctitle.setproctitle(f"{current.rstrip()} {name}")
 
 
 def daemonize(redirect_out=True):
@@ -68,7 +73,6 @@ def daemonize(redirect_out=True):
         pid = os.fork()
         if pid > 0:
             # exit first parent
-            salt.utils.crypt.reinit_crypto()
             os._exit(salt.defaults.exitcodes.EX_OK)
     except OSError as exc:
         log.error("fork #1 failed: %s (%s)", exc.errno, exc)
@@ -84,14 +88,11 @@ def daemonize(redirect_out=True):
     try:
         pid = os.fork()
         if pid > 0:
-            salt.utils.crypt.reinit_crypto()
             sys.exit(salt.defaults.exitcodes.EX_OK)
     except OSError as exc:
         log.error("fork #2 failed: %s (%s)", exc.errno, exc)
         sys.exit(salt.defaults.exitcodes.EX_GENERIC)
 
-    salt.utils.crypt.reinit_crypto()
-
     # A normal daemonization redirects the process output to /dev/null.
     # Unfortunately when a python multiprocess is called the output is
     # not cleanly redirected and the parent process dies when the
@@ -172,7 +173,7 @@ def notify_systemd():
             if notify_socket:
                 # Handle abstract namespace socket
                 if notify_socket.startswith("@"):
-                    notify_socket = "\0{}".format(notify_socket[1:])
+                    notify_socket = f"\0{notify_socket[1:]}"
                 try:
                     sock = socket.socket(socket.AF_UNIX, socket.SOCK_DGRAM)
                     sock.connect(notify_socket)
@@ -206,7 +207,7 @@ def get_process_info(pid=None):
 
     # pid_exists can have false positives
     # for example Windows reserves PID 5 in a hack way
-    # another reasons is the the process requires kernel permissions
+    # another reasons is the process requires kernel permissions
     try:
         raw_process_info.status()
     except psutil.NoSuchProcess:
@@ -350,7 +351,7 @@ def set_pidfile(pidfile, user):
             pidfile, user
         )
         log.debug("%s Traceback follows:", msg, exc_info=True)
-        sys.stderr.write("{}\n".format(msg))
+        sys.stderr.write(f"{msg}\n")
         sys.exit(err.errno)
     log.debug("Chowned pidfile: %s to user: %s", pidfile, user)
 
@@ -524,11 +525,14 @@ class ProcessManager:
                 target=tgt, args=args, kwargs=kwargs, name=name or tgt.__qualname__
             )
 
+        process.register_finalize_method(cleanup_finalize_process, args, kwargs)
+
         if isinstance(process, SignalHandlingProcess):
             with default_signals(signal.SIGINT, signal.SIGTERM):
                 process.start()
         else:
             process.start()
+
         log.debug("Started '%s' with pid %s", process.name, process.pid)
         self._process_map[process.pid] = {
             "tgt": tgt,
@@ -536,6 +540,7 @@ class ProcessManager:
             "kwargs": kwargs,
             "Process": process,
         }
+
         return process
 
     def restart_process(self, pid):
@@ -590,7 +595,7 @@ class ProcessManager:
             # with the tree option will not be able to find them.
             return
 
-        for pid in self._process_map.copy().keys():
+        for pid in self._process_map.copy():
             try:
                 os.kill(pid, signal_)
             except OSError as exc:
@@ -684,6 +689,7 @@ class ProcessManager:
                         pass
                 try:
                     p_map["Process"].terminate()
+
                 except OSError as exc:
                     if exc.errno not in (errno.ESRCH, errno.EACCES):
                         raise
@@ -920,9 +926,9 @@ class Process(multiprocessing.Process):
         self.__init__(*args, **kwargs)
         # Override self.__logging_config__ with what's in state
         self.__logging_config__ = logging_config
-        for (function, args, kwargs) in state["after_fork_methods"]:
+        for function, args, kwargs in state["after_fork_methods"]:
             self.register_after_fork_method(function, *args, **kwargs)
-        for (function, args, kwargs) in state["finalize_methods"]:
+        for function, args, kwargs in state["finalize_methods"]:
             self.register_finalize_method(function, *args, **kwargs)
 
     def __getstate__(self):
@@ -942,7 +948,7 @@ class Process(multiprocessing.Process):
             "logging_config": self.__logging_config__,
         }
 
-    def __decorate_run(self, run_func):
+    def __decorate_run(self, run_func):  # pylint: disable=unused-private-member
         @functools.wraps(run_func)
         def wrapped_run_func():
             # Static after fork method, always needs to happen first
@@ -1061,13 +1067,28 @@ class SignalHandlingProcess(Process):
     def _handle_signals(self, signum, sigframe):
         signal.signal(signal.SIGTERM, signal.SIG_IGN)
         signal.signal(signal.SIGINT, signal.SIG_IGN)
-        msg = "{} received a ".format(self.__class__.__name__)
+        msg = f"{self.__class__.__name__} received a "
         if signum == signal.SIGINT:
             msg += "SIGINT"
         elif signum == signal.SIGTERM:
             msg += "SIGTERM"
         msg += ". Exiting"
         log.debug(msg)
+
+        # Run any registered process finalization routines
+        for method, args, kwargs in self._finalize_methods:
+            try:
+                method(*args, **kwargs)
+            except Exception:  # pylint: disable=broad-except
+                log.exception(
+                    "Failed to run finalize callback on %s; method=%r; args=%r; and kwargs=%r",
+                    self,
+                    method,
+                    args,
+                    kwargs,
+                )
+                continue
+
         if HAS_PSUTIL:
             try:
                 process = psutil.Process(os.getpid())
@@ -1083,6 +1104,7 @@ class SignalHandlingProcess(Process):
                                 self.pid,
                                 os.getpid(),
                             )
+
             except psutil.NoSuchProcess:
                 log.warning(
                     "Unable to kill children of process %d, it does not exist."
@@ -1154,3 +1176,57 @@ class SubprocessList:
                 self.processes.remove(proc)
                 self.count -= 1
                 log.debug("Subprocess %s cleaned up", proc.name)
+
+
+def cleanup_finalize_process(*args, **kwargs):
+    """
+    Generic process to allow for any registered process cleanup routines to execute.
+
+    While class Process has a register_finalize_method, when a process is looked up by pid
+    using psutil.Process, there is no method available to register a cleanup process.
+
+    Hence, this function is added as part of the add_process to allow usage of other cleanup processes
+    which cannot be added by the register_finalize_method.
+    """
+
+    # Run any registered process cleanup routines
+    for method, args, kwargs in _INTERNAL_PROCESS_FINALIZE_FUNCTION_LIST:
+        log.debug(
+            "cleanup_finalize_process, method=%r, args=%r, kwargs=%r",
+            method,
+            args,
+            kwargs,
+        )
+        try:
+            method(*args, **kwargs)
+        except Exception:  # pylint: disable=broad-except
+            log.exception(
+                "Failed to run registered function finalize callback; method=%r; args=%r; and kwargs=%r",
+                method,
+                args,
+                kwargs,
+            )
+            continue
+
+
+def register_cleanup_finalize_function(function, *args, **kwargs):
+    """
+    Register a function to run as process terminates
+
+    While class Process has a register_finalize_method, when a process is looked up by pid
+    using psutil.Process, there is no method available to register a cleanup process.
+
+    Hence, this function can be used to register a function to allow cleanup processes
+    which cannot be added by class Process register_finalize_method.
+
+    Note: there is no deletion, since it is assummed that if something is registered, it will continue to be used
+    """
+    log.debug(
+        "register_cleanup_finalize_function entry, function=%r, args=%r, kwargs=%r",
+        function,
+        args,
+        kwargs,
+    )
+    finalize_function_tuple = (function, args, kwargs)
+    if finalize_function_tuple not in _INTERNAL_PROCESS_FINALIZE_FUNCTION_LIST:
+        _INTERNAL_PROCESS_FINALIZE_FUNCTION_LIST.append(finalize_function_tuple)
