@@ -15,11 +15,15 @@ import tarfile
 import tempfile
 import zipfile
 
+import distro
 import jinja2
+import looseversion
 import msgpack
+import packaging
+import yaml
+
 import salt
 import salt.exceptions
-import salt.ext.six as _six
 import salt.ext.tornado as tornado
 import salt.utils.files
 import salt.utils.hashutils
@@ -27,7 +31,6 @@ import salt.utils.json
 import salt.utils.path
 import salt.utils.stringutils
 import salt.version
-import yaml
 
 # This is needed until we drop support for python 3.6
 has_immutables = False
@@ -81,15 +84,8 @@ except ImportError:
         from salt.ext import ssl_match_hostname
     except ImportError:
         ssl_match_hostname = None
-# pylint: enable=import-error,no-name-in-module
-if _six.PY2:
-    import concurrent
 
-    distro = None
-else:
-    import distro
-
-    concurrent = None
+concurrent = None
 
 
 log = logging.getLogger(__name__)
@@ -152,7 +148,7 @@ def find_site_modules(name):
     except RuntimeError:
         log.debug("No site package directories found")
     for site_path in site_paths:
-        path = os.path.join(site_path, "{}.py".format(name))
+        path = os.path.join(site_path, f"{name}.py")
         lib = import_module(name, path)
         if lib:
             libs.append(lib)
@@ -285,6 +281,8 @@ def get_tops_python(py_ver, exclude=None, ext_py_ver=None):
         "ssl_match_hostname",
         "markupsafe",
         "backports_abc",
+        "looseversion",
+        "packaging",
     ]
     if ext_py_ver and tuple(ext_py_ver) >= (3, 0):
         mods.append("distro")
@@ -294,9 +292,7 @@ def get_tops_python(py_ver, exclude=None, ext_py_ver=None):
             continue
 
         if not salt.utils.path.which(py_ver):
-            log.error(
-                "{} does not exist. Could not auto detect dependencies".format(py_ver)
-            )
+            log.error("%s does not exist. Could not auto detect dependencies", py_ver)
             return {}
         py_shell_cmd = [py_ver, "-c", "import {0}; print({0}.__file__)".format(mod)]
         cmd = subprocess.Popen(py_shell_cmd, stdout=subprocess.PIPE)
@@ -305,9 +301,9 @@ def get_tops_python(py_ver, exclude=None, ext_py_ver=None):
 
         if not stdout or not os.path.exists(mod_file):
             log.error(
-                "Could not auto detect file location for module {} for python version {}".format(
-                    mod, py_ver
-                )
+                "Could not auto detect file location for module %s for python version %s",
+                mod,
+                py_ver,
             )
             continue
 
@@ -326,11 +322,11 @@ def get_ext_tops(config):
 
     :return:
     """
-    config = copy.deepcopy(config)
+    config = copy.deepcopy(config) or {}
     alternatives = {}
     required = ["jinja2", "yaml", "tornado", "msgpack"]
     tops = []
-    for ns, cfg in salt.ext.six.iteritems(config or {}):
+    for ns, cfg in config.items():
         alternatives[ns] = cfg
         locked_py_version = cfg.get("py-version")
         err_msg = None
@@ -434,6 +430,8 @@ def get_tops(extra_mods="", so_mods=""):
         ssl_match_hostname,
         markupsafe,
         backports_abc,
+        looseversion,
+        packaging,
     ]
     modules = find_site_modules("contextvars")
     if modules:
@@ -460,16 +458,16 @@ def get_tops(extra_mods="", so_mods=""):
                 else:
                     tops.append(os.path.join(moddir, base + ".py"))
             except ImportError as err:
-                log.exception(err)
-                log.error('Unable to import extra-module "%s"', mod)
+                log.error(
+                    'Unable to import extra-module "%s": %s', mod, err, exc_info=True
+                )
 
     for mod in [m for m in so_mods.split(",") if m]:
         try:
             locals()[mod] = __import__(mod)
             tops.append(locals()[mod].__file__)
         except ImportError as err:
-            log.exception(err)
-            log.error('Unable to import so-module "%s"', mod)
+            log.error('Unable to import so-module "%s"', mod, exc_info=True)
 
     return tops
 
@@ -486,14 +484,14 @@ def _get_supported_py_config(tops, extended_cfg):
     :return:
     """
     pymap = []
-    for py_ver, tops in _six.iteritems(copy.deepcopy(tops)):
+    for py_ver, tops in copy.deepcopy(tops).items():
         py_ver = int(py_ver)
         if py_ver == 2:
             pymap.append("py2:2:7")
         elif py_ver == 3:
             pymap.append("py3:3:0")
-
-    for ns, cfg in _six.iteritems(copy.deepcopy(extended_cfg) or {}):
+    cfg_copy = copy.deepcopy(extended_cfg) or {}
+    for ns, cfg in cfg_copy.items():
         pymap.append("{}:{}:{}".format(ns, *cfg.get("py-version")))
     pymap.append("")
 
@@ -521,7 +519,7 @@ def _pack_alternative(extended_cfg, digest_collector, tfp):
     # Pack alternative data
     config = copy.deepcopy(extended_cfg)
     # Check if auto_detect is enabled and update dependencies
-    for ns, cfg in _six.iteritems(config):
+    for ns, cfg in config.items():
         if cfg.get("auto_detect"):
             py_ver = "python" + str(cfg.get("py-version", [""])[0])
             if cfg.get("py_bin"):
@@ -543,7 +541,7 @@ def _pack_alternative(extended_cfg, digest_collector, tfp):
             for dep in auto_deps:
                 config[ns]["dependencies"][dep] = auto_deps[dep]
 
-    for ns, cfg in _six.iteritems(get_ext_tops(config)):
+    for ns, cfg in get_ext_tops(config).items():
         tops = [cfg.get("path")] + cfg.get("dependencies")
         py_ver_major, py_ver_minor = cfg.get("py-version")
 
@@ -551,9 +549,7 @@ def _pack_alternative(extended_cfg, digest_collector, tfp):
             top = os.path.normpath(top)
             base, top_dirname = os.path.basename(top), os.path.dirname(top)
             os.chdir(top_dirname)
-            site_pkg_dir = (
-                _is_shareable(base) and "pyall" or "py{}".format(py_ver_major)
-            )
+            site_pkg_dir = _is_shareable(base) and "pyall" or f"py{py_ver_major}"
             log.debug(
                 'Packing alternative "%s" to "%s/%s" destination',
                 base,
@@ -592,8 +588,6 @@ def gen_thin(
     extra_mods="",
     overwrite=False,
     so_mods="",
-    python2_bin="python2",
-    python3_bin="python3",
     absonly=True,
     compress="gzip",
     extended_cfg=None,
@@ -612,11 +606,6 @@ def gen_thin(
         salt-run thin.generate mako,wempy 1
         salt-run thin.generate overwrite=1
     """
-    if python2_bin != "python2" or python3_bin != "python3":
-        salt.utils.versions.warn_until(
-            "Silicon",
-            "python2_bin and python3_bin are no longer used, please update your call to gen_thin",
-        )
     if sys.version_info < (3,):
         raise salt.exceptions.SaltSystemExit(
             'The minimum required python version to run salt-ssh is "3".'
@@ -649,9 +638,7 @@ def gen_thin(
                     overwrite = fh_.read() != salt.version.__version__
                 if overwrite is False and os.path.isfile(pythinver):
                     with salt.utils.files.fopen(pythinver) as fh_:
-                        overwrite = fh_.read() != str(
-                            sys.version_info[0]
-                        )  # future lint: disable=blacklisted-function
+                        overwrite = fh_.read() != str(sys.version_info[0])
             else:
                 overwrite = True
 
@@ -700,7 +687,7 @@ def gen_thin(
 
     # Pack default data
     log.debug("Packing default libraries based on current Salt version")
-    for py_ver, tops in _six.iteritems(tops_py_version_mapping):
+    for py_ver, tops in tops_py_version_mapping.items():
         for top in tops:
             if absonly and not os.path.isabs(top):
                 continue
@@ -712,11 +699,11 @@ def gen_thin(
                 # This is likely a compressed python .egg
                 tempdir = tempfile.mkdtemp()
                 egg = zipfile.ZipFile(top_dirname)
-                egg.extractall(tempdir)
+                egg.extractall(tempdir)  # nosec
                 top = os.path.join(tempdir, base)
                 os.chdir(tempdir)
 
-            site_pkg_dir = _is_shareable(base) and "pyall" or "py{}".format(py_ver)
+            site_pkg_dir = _is_shareable(base) and "pyall" or f"py{py_ver}"
 
             log.debug('Packing "%s" to "%s" destination', base, site_pkg_dir)
             if not os.path.isdir(top):
@@ -753,9 +740,7 @@ def gen_thin(
     with salt.utils.files.fopen(thinver, "w+") as fp_:
         fp_.write(salt.version.__version__)
     with salt.utils.files.fopen(pythinver, "w+") as fp_:
-        fp_.write(
-            str(sys.version_info.major)
-        )  # future lint: disable=blacklisted-function
+        fp_.write(str(sys.version_info.major))
     with salt.utils.files.fopen(code_checksum, "w+") as fp_:
         fp_.write(digest_collector.digest())
     os.chdir(os.path.dirname(thinver))
@@ -786,7 +771,7 @@ def thin_sum(cachedir, form="sha1"):
     code_checksum_path = os.path.join(cachedir, "thin", "code-checksum")
     if os.path.isfile(code_checksum_path):
         with salt.utils.files.fopen(code_checksum_path, "r") as fh:
-            code_checksum = "'{}'".format(fh.read().strip())
+            code_checksum = f"'{fh.read().strip()}'"
     else:
         code_checksum = "'0'"
 
@@ -798,8 +783,6 @@ def gen_min(
     extra_mods="",
     overwrite=False,
     so_mods="",
-    python2_bin="python2",
-    python3_bin="python3",
 ):
     """
     Generate the salt-min tarball and print the location of the tarball
@@ -815,11 +798,6 @@ def gen_min(
         salt-run min.generate mako,wempy 1
         salt-run min.generate overwrite=1
     """
-    if python2_bin != "python2" or python3_bin != "python3":
-        salt.utils.versions.warn_until(
-            "Silicon",
-            "python2_bin and python3_bin are no longer used, please update your call to gen_min",
-        )
     mindir = os.path.join(cachedir, "min")
     if not os.path.isdir(mindir):
         os.makedirs(mindir)
@@ -836,9 +814,7 @@ def gen_min(
                     overwrite = fh_.read() != salt.version.__version__
                 if overwrite is False and os.path.isfile(pyminver):
                     with salt.utils.files.fopen(pyminver) as fh_:
-                        overwrite = fh_.read() != str(
-                            sys.version_info[0]
-                        )  # future lint: disable=blacklisted-function
+                        overwrite = fh_.read() != str(sys.version_info[0])
             else:
                 overwrite = True
 
@@ -928,7 +904,6 @@ def gen_min(
         "salt/client/__init__.py",
         "salt/ext",
         "salt/ext/__init__.py",
-        "salt/ext/six.py",
         "salt/ext/ipaddress.py",
         "salt/version.py",
         "salt/syspaths.py",
@@ -949,12 +924,12 @@ def gen_min(
         "salt/pillar",
         "salt/pillar/__init__.py",
         "salt/utils/textformat.py",
-        "salt/log",
-        "salt/log/__init__.py",
-        "salt/log/handlers",
-        "salt/log/handlers/__init__.py",
-        "salt/log/mixins.py",
-        "salt/log/setup.py",
+        "salt/log_handlers",
+        "salt/log_handlers/__init__.py",
+        "salt/_logging/__init__.py",
+        "salt/_logging/handlers.py",
+        "salt/_logging/impl.py",
+        "salt/_logging/mixins.py",
         "salt/cli",
         "salt/cli/__init__.py",
         "salt/cli/caller.py",
@@ -963,7 +938,10 @@ def gen_min(
         "salt/cli/call.py",
         "salt/fileserver",
         "salt/fileserver/__init__.py",
-        "salt/transport",
+        "salt/channel",
+        "salt/channel/__init__.py",
+        "salt/channel/client.py",
+        "salt/transport",  # XXX Are the transport imports still needed?
         "salt/transport/__init__.py",
         "salt/transport/client.py",
         "salt/exceptions.py",
@@ -983,7 +961,7 @@ def gen_min(
         "salt/output/nested.py",
     )
 
-    for py_ver, tops in _six.iteritems(tops_py_version_mapping):
+    for py_ver, tops in tops_py_version_mapping.items():
         for top in tops:
             base = os.path.basename(top)
             top_dirname = os.path.dirname(top)
@@ -993,12 +971,12 @@ def gen_min(
                 # This is likely a compressed python .egg
                 tempdir = tempfile.mkdtemp()
                 egg = zipfile.ZipFile(top_dirname)
-                egg.extractall(tempdir)
+                egg.extractall(tempdir)  # nosec
                 top = os.path.join(tempdir, base)
                 os.chdir(tempdir)
             if not os.path.isdir(top):
                 # top is a single file module
-                tfp.add(base, arcname=os.path.join("py{}".format(py_ver), base))
+                tfp.add(base, arcname=os.path.join(f"py{py_ver}", base))
                 continue
             for root, dirs, files in salt.utils.path.os_walk(base, followlinks=True):
                 for name in files:
@@ -1011,7 +989,7 @@ def gen_min(
                         continue
                     tfp.add(
                         os.path.join(root, name),
-                        arcname=os.path.join("py{}".format(py_ver), root, name),
+                        arcname=os.path.join(f"py{py_ver}", root, name),
                     )
             if tempdir is not None:
                 shutil.rmtree(tempdir)
@@ -1022,7 +1000,7 @@ def gen_min(
     with salt.utils.files.fopen(minver, "w+") as fp_:
         fp_.write(salt.version.__version__)
     with salt.utils.files.fopen(pyminver, "w+") as fp_:
-        fp_.write(str(sys.version_info[0]))  # future lint: disable=blacklisted-function
+        fp_.write(str(sys.version_info[0]))
     os.chdir(os.path.dirname(minver))
     tfp.add("version")
     tfp.add(".min-gen-py-version")
