@@ -60,14 +60,14 @@ def _get_token_and_url_from_master():
     # When rendering pillars, the module executes on the master, but the token
     # should be issued for the minion, so that the correct policies are applied
     if __opts__.get("__role", "minion") == "minion":
-        private_key = "{}/minion.pem".format(pki_dir)
+        private_key = f"{pki_dir}/minion.pem"
         log.debug("Running on minion, signing token request with key %s", private_key)
         signature = base64.b64encode(salt.crypt.sign_message(private_key, minion_id))
         result = __salt__["publish.runner"](
             "vault.generate_token", arg=[minion_id, signature, False, ttl, uses]
         )
     else:
-        private_key = "{}/master.pem".format(pki_dir)
+        private_key = f"{pki_dir}/master.pem"
         log.debug(
             "Running on master, signing token request for %s with key %s",
             minion_id,
@@ -136,10 +136,16 @@ def get_vault_connection():
                     if namespace is not None:
                         headers = {"X-Vault-Namespace": namespace}
                         response = requests.post(
-                            url, headers=headers, json=payload, verify=verify
+                            url,
+                            headers=headers,
+                            json=payload,
+                            verify=verify,
+                            timeout=120,
                         )
                     else:
-                        response = requests.post(url, json=payload, verify=verify)
+                        response = requests.post(
+                            url, json=payload, verify=verify, timeout=120
+                        )
                     if response.status_code != 200:
                         errmsg = "An error occurred while getting a token from approle"
                         raise salt.exceptions.CommandExecutionError(errmsg)
@@ -153,7 +159,9 @@ def get_vault_connection():
                     headers = {"X-Vault-Token": __opts__["vault"]["auth"]["token"]}
                     if namespace is not None:
                         headers["X-Vault-Namespace"] = namespace
-                    response = requests.post(url, headers=headers, verify=verify)
+                    response = requests.post(
+                        url, headers=headers, verify=verify, timeout=120
+                    )
                     if response.status_code != 200:
                         errmsg = "An error occured while unwrapping vault token"
                         raise salt.exceptions.CommandExecutionError(errmsg)
@@ -322,7 +330,7 @@ def make_request(
     namespace=None,
     get_token_url=False,
     retry=False,
-    **args
+    **args,
 ):
     """
     Make a request to Vault
@@ -334,19 +342,21 @@ def make_request(
     token = connection["token"] if not token else token
     vault_url = connection["url"] if not vault_url else vault_url
     namespace = namespace or connection.get("namespace")
-    if "verify" in args:
-        args["verify"] = args["verify"]
-    else:
+    if "verify" not in args:
         try:
             args["verify"] = __opts__.get("vault").get("verify", None)
         except (TypeError, AttributeError):
             # Don't worry about setting verify if it doesn't exist
             pass
-    url = "{}/{}".format(vault_url, resource)
+    if "timeout" not in args:
+        args["timeout"] = 120
+    url = f"{vault_url}/{resource}"
     headers = {"X-Vault-Token": str(token), "Content-Type": "application/json"}
     if namespace is not None:
         headers["X-Vault-Namespace"] = namespace
-    response = requests.request(method, url, headers=headers, **args)
+    response = requests.request(  # pylint: disable=missing-timeout
+        method, url, headers=headers, **args
+    )
     if not response.ok and response.json().get("errors", None) == ["permission denied"]:
         log.info("Permission denied from vault")
         del_cache()
@@ -359,7 +369,7 @@ def make_request(
                 vault_url=vault_url,
                 get_token_url=get_token_url,
                 retry=True,
-                **args
+                **args,
             )
         else:
             log.error("Unable to connect to vault server: %s", response.text)
@@ -407,13 +417,13 @@ def _selftoken_expired():
         headers = {"X-Vault-Token": __opts__["vault"]["auth"]["token"]}
         if namespace is not None:
             headers["X-Vault-Namespace"] = namespace
-        response = requests.get(url, headers=headers, verify=verify)
+        response = requests.get(url, headers=headers, verify=verify, timeout=120)
         if response.status_code != 200:
             return True
         return False
     except Exception as e:  # pylint: disable=broad-except
         raise salt.exceptions.CommandExecutionError(
-            "Error while looking up self token : {}".format(e)
+            f"Error while looking up self token : {e}"
         )
 
 
@@ -431,13 +441,13 @@ def _wrapped_token_valid():
         headers = {"X-Vault-Token": __opts__["vault"]["auth"]["token"]}
         if namespace is not None:
             headers["X-Vault-Namespace"] = namespace
-        response = requests.post(url, headers=headers, verify=verify)
+        response = requests.post(url, headers=headers, verify=verify, timeout=120)
         if response.status_code != 200:
             return False
         return True
     except Exception as e:  # pylint: disable=broad-except
         raise salt.exceptions.CommandExecutionError(
-            "Error while looking up wrapped token : {}".format(e)
+            f"Error while looking up wrapped token : {e}"
         )
 
 
@@ -538,7 +548,7 @@ def _get_secret_path_metadata(path):
     else:
         log.debug("Fetching metadata for %s", path)
         try:
-            url = "v1/sys/internal/ui/mounts/{}".format(path)
+            url = f"v1/sys/internal/ui/mounts/{path}"
             response = make_request("GET", url)
             if response.ok:
                 response.raise_for_status()
@@ -599,12 +609,12 @@ def expand_pattern_lists(pattern, **mappings):
     # very expensive, since patterns will typically involve a handful of lists at
     # most.
 
-    for (_, field_name, _, _) in f.parse(pattern):
+    for _, field_name, _, _ in f.parse(pattern):
         if field_name is None:
             continue
         (value, _) = f.get_field(field_name, None, mappings)
         if isinstance(value, list):
-            token = "{{{0}}}".format(field_name)
+            token = f"{{{field_name}}}"
             expanded = [pattern.replace(token, str(elem)) for elem in value]
             for expanded_item in expanded:
                 result = expand_pattern_lists(expanded_item, **mappings)
