@@ -3,6 +3,7 @@ A few checks to make sure the environment is sane
 """
 
 import errno
+import itertools
 import logging
 import os
 import re
@@ -15,15 +16,16 @@ import salt.utils.files
 import salt.utils.path
 import salt.utils.platform
 import salt.utils.user
+from salt._logging import LOG_LEVELS
 from salt.exceptions import CommandExecutionError, SaltClientError, SaltSystemExit
-from salt.log import is_console_configured
-from salt.log.setup import LOG_LEVELS
 
 # Original Author: Jeff Schroeder <jeffschroeder@computer.org>
 
 
 try:
     import win32file
+
+    import salt.utils.win_reg
 except ImportError:
     import resource
 
@@ -49,11 +51,7 @@ def zmq_version():
 
     # Fallthrough and hope for the best
     if not match:
-        msg = "Using untested zmq python bindings version: '{}'".format(ver)
-        if is_console_configured():
-            log.warning(msg)
-        else:
-            sys.stderr.write("WARNING {}\n".format(msg))
+        log.warning("Using untested zmq python bindings version: '%s'", ver)
         return True
 
     major, minor, point = match.groups()
@@ -70,11 +68,7 @@ def zmq_version():
     if major == 2 and minor == 1:
         # zmq 2.1dev could be built against a newer libzmq
         if "dev" in ver and not point:
-            msg = "Using dev zmq module, please report unexpected results"
-            if is_console_configured():
-                log.warning(msg)
-            else:
-                sys.stderr.write("WARNING: {}\n".format(msg))
+            log.warning("Using dev zmq module, please report unexpected results")
             return True
         elif point and point >= 9:
             return True
@@ -84,15 +78,11 @@ def zmq_version():
     # If all else fails, gracefully croak and warn the user
     log.critical("ZeroMQ python bindings >= 2.1.9 are required")
     if "salt-master" in sys.argv[0]:
-        msg = (
+        log.critical(
             "The Salt Master is unstable using a ZeroMQ version "
             "lower than 2.1.11 and requires this fix: http://lists.zeromq."
             "org/pipermail/zeromq-dev/2011-June/012094.html"
         )
-        if is_console_configured():
-            log.critical(msg)
-        else:
-            sys.stderr.write("CRITICAL {}\n".format(msg))
     return False
 
 
@@ -127,16 +117,13 @@ def verify_socket(interface, pub_port, ret_port):
             sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
             sock.bind((interface, int(port)))
         except Exception as exc:  # pylint: disable=broad-except
-            msg = "Unable to bind socket {}:{}".format(interface, port)
+            msg = f"Unable to bind socket {interface}:{port}"
             if exc.args:
-                msg = "{}, error: {}".format(msg, str(exc))
+                msg = f"{msg}, error: {str(exc)}"
             else:
-                msg = "{}, this might not be a problem.".format(msg)
+                msg = f"{msg}, this might not be a problem."
             msg += "; Is there another salt-master running?"
-            if is_console_configured():
-                log.warning(msg)
-            else:
-                sys.stderr.write("WARNING: {}\n".format(msg))
+            log.warning(msg)
             return False
         finally:
             sock.close()
@@ -145,6 +132,9 @@ def verify_socket(interface, pub_port, ret_port):
 
 
 def verify_logs_filter(files):
+    """
+    Filter files to verify.
+    """
     to_verify = []
     for filename in files:
         verify_file = True
@@ -177,13 +167,12 @@ def _get_pwnam(user):
     try:
         return pwd.getpwnam(user)
     except KeyError:
-        msg = "Failed to prepare the Salt environment for user {}. The user is not available.".format(
-            user
+        print(
+            "Failed to prepare the Salt environment for user {}. "
+            "The user is not available.".format(user),
+            file=sys.stderr,
+            flush=True,
         )
-        if is_console_configured():
-            log.critical(msg)
-        else:
-            print(msg, file=sys.stderr, flush=True)
         sys.exit(salt.defaults.exitcodes.EX_NOUSER)
 
 
@@ -213,7 +202,7 @@ def verify_files(files, user):
 
         except OSError as err:
             if os.path.isfile(dirname):
-                msg = "Failed to create path {}, is {} a file?".format(fn_, dirname)
+                msg = f"Failed to create path {fn_}, is {dirname} a file?"
                 raise SaltSystemExit(msg=msg)
             if err.errno != errno.EACCES:
                 raise
@@ -223,7 +212,7 @@ def verify_files(files, user):
             raise SaltSystemExit(msg=msg)
 
         except OSError as err:  # pylint: disable=duplicate-except
-            msg = 'Failed to create path "{}" - {}'.format(fn_, err)
+            msg = f'Failed to create path "{fn_}" - {err}'
             raise SaltSystemExit(msg=msg)
 
         stats = os.stat(fn_)
@@ -282,32 +271,24 @@ def verify_env(
                     os.chown(dir_, uid, gid)
             for subdir in [a for a in os.listdir(dir_) if "jobs" not in a]:
                 fsubdir = os.path.join(dir_, subdir)
-                if "{}jobs".format(os.path.sep) in fsubdir:
+                if f"{os.path.sep}jobs" in fsubdir:
                     continue
                 for root, dirs, files in salt.utils.path.os_walk(fsubdir):
-                    for name in files:
+                    for name in itertools.chain(files, dirs):
                         if name.startswith("."):
                             continue
                         path = os.path.join(root, name)
                         try:
                             fmode = os.stat(path)
+                            if fmode.st_uid != uid or fmode.st_gid != gid:
+                                if permissive and fmode.st_gid in groups:
+                                    pass
+                                else:
+                                    # chown the file for the new user
+                                    os.chown(path, uid, gid)
                         except OSError:
-                            pass
-                        if fmode.st_uid != uid or fmode.st_gid != gid:
-                            if permissive and fmode.st_gid in groups:
-                                pass
-                            else:
-                                # chown the file for the new user
-                                os.chown(path, uid, gid)
-                    for name in dirs:
-                        path = os.path.join(root, name)
-                        fmode = os.stat(path)
-                        if fmode.st_uid != uid or fmode.st_gid != gid:
-                            if permissive and fmode.st_gid in groups:
-                                pass
-                            else:
-                                # chown the file for the new user
-                                os.chown(path, uid, gid)
+                            continue
+
         # Allow the pki dir to be 700 or 750, but nothing else.
         # This prevents other users from writing out keys, while
         # allowing the use-case of 3rd-party software (like django)
@@ -323,12 +304,9 @@ def verify_env(
                 if os.access(dir_, os.W_OK):
                     os.chmod(dir_, 448)
                 else:
-                    msg = 'Unable to securely set the permissions of "{0}".'
-                    msg = msg.format(dir_)
-                    if is_console_configured():
-                        log.critical(msg)
-                    else:
-                        sys.stderr.write("CRITICAL: {}\n".format(msg))
+                    log.critical(
+                        'Unable to securely set the permissions of "%s".', dir_
+                    )
 
     if skip_extra is False:
         # Run the extra verification checks
@@ -349,7 +327,7 @@ def check_user(user):
 
     try:
         if hasattr(os, "initgroups"):
-            os.initgroups(user, pwuser.pw_gid)  # pylint: disable=minimum-python-version
+            os.initgroups(user, pwuser.pw_gid)
         else:
             os.setgroups(salt.utils.user.get_gid_list(user, include_default=False))
         os.setgid(pwuser.pw_gid)
@@ -368,11 +346,7 @@ def check_user(user):
                 os.environ[envvar] = pwuser.pw_name
 
     except OSError:
-        msg = 'Salt configured to run as user "{}" but unable to switch.'.format(user)
-        if is_console_configured():
-            log.critical(msg)
-        else:
-            sys.stderr.write("CRITICAL: {}\n".format(msg))
+        log.critical('Salt configured to run as user "%s" but unable to switch.', user)
         return False
     return True
 
@@ -411,7 +385,7 @@ def check_path_traversal(path, user="root", skip_perm_errors=False):
     """
     for tpath in list_path_traversal(path):
         if not os.access(tpath, os.R_OK):
-            msg = "Could not access {}.".format(tpath)
+            msg = f"Could not access {tpath}."
             if not os.path.exists(tpath):
                 msg += " Path does not exist."
             else:
@@ -419,9 +393,9 @@ def check_path_traversal(path, user="root", skip_perm_errors=False):
                 # Make the error message more intelligent based on how
                 # the user invokes salt-call or whatever other script.
                 if user != current_user:
-                    msg += " Try running as user {}.".format(user)
+                    msg += f" Try running as user {user}."
                 else:
-                    msg += " Please give {} read permissions.".format(user)
+                    msg += f" Please give {user} read permissions."
 
             # We don't need to bail on config file permission errors
             # if the CLI
@@ -444,7 +418,10 @@ def check_max_open_files(opts):
         # and the python binding http://timgolden.me.uk/pywin32-docs/win32file.html
         mof_s = mof_h = win32file._getmaxstdio()
     else:
-        mof_s, mof_h = resource.getrlimit(resource.RLIMIT_NOFILE)
+
+        mof_s, mof_h = resource.getrlimit(  # pylint: disable=used-before-assignment
+            resource.RLIMIT_NOFILE
+        )
 
     accepted_keys_dir = os.path.join(opts.get("pki_dir"), "minions")
     accepted_count = len(os.listdir(accepted_keys_dir))
@@ -483,8 +460,8 @@ def check_max_open_files(opts):
         msg += (
             "According to the system's hard limit, there's still a "
             "margin of {} to raise the salt's max_open_files "
-            "setting. "
-        ).format(mof_h - mof_c)
+            "setting. ".format(mof_h - mof_c)
+        )
 
     msg += "Please consider raising this value."
     log.log(level=level, msg=msg)
@@ -508,7 +485,8 @@ def _realpath_windows(path):
     for part in path.split(os.path.sep):
         if base != "":
             try:
-                part = os.readlink(os.path.sep.join([base, part]))
+                # Need to use salt.utils.path.readlink as it handles junctions
+                part = salt.utils.path.readlink(os.path.sep.join([base, part]))
                 base = os.path.abspath(part)
             except OSError:
                 base = os.path.abspath(os.path.sep.join([base, part]))
@@ -535,25 +513,28 @@ def _realpath(path):
     return os.path.realpath(path)
 
 
-def clean_path(root, path, subdir=False):
+def clean_path(root, path, subdir=False, realpath=True):
     """
     Accepts the root the path needs to be under and verifies that the path is
     under said root. Pass in subdir=True if the path can result in a
-    subdirectory of the root instead of having to reside directly in the root
+    subdirectory of the root instead of having to reside directly in the root.
+    Pass realpath=False if filesystem links should not be resolved.
     """
-    real_root = _realpath(root)
-    if not os.path.isabs(real_root):
-        return ""
+    if not os.path.isabs(root):
+        root = os.path.join(os.getcwd(), root)
+    root = os.path.normpath(root)
     if not os.path.isabs(path):
         path = os.path.join(root, path)
     path = os.path.normpath(path)
-    real_path = _realpath(path)
+    if realpath:
+        root = _realpath(root)
+        path = _realpath(path)
     if subdir:
-        if real_path.startswith(real_root):
-            return real_path
+        if os.path.commonpath([path, root]) == root:
+            return path
     else:
-        if os.path.dirname(real_path) == os.path.normpath(real_root):
-            return real_path
+        if os.path.dirname(path) == root:
+            return path
     return ""
 
 
@@ -582,6 +563,17 @@ def safe_py_code(code):
     return True
 
 
+def insecure_log():
+    """
+    Return the insecure logs types
+    """
+    insecure = []
+    for level, value in LOG_LEVELS.items():
+        if value < LOG_LEVELS.get("info", 20):
+            insecure.append(level)
+    return insecure
+
+
 def verify_log(opts):
     """
     If an insecre logging configuration is found, show a warning
@@ -599,13 +591,12 @@ def win_verify_env(path, dirs, permissive=False, pki_dir="", skip_extra=False):
     Verify that the named directories are in place and that the environment
     can shake the salt
     """
-    import salt.utils.win_functions
-    import salt.utils.win_dacl
     import salt.utils.path
+    import salt.utils.win_dacl
+    import salt.utils.win_functions
 
     # Make sure the file_roots is not set to something unsafe since permissions
     # on that directory are reset
-
     # `salt.utils.path.safe_path` will consider anything inside `C:\Windows` to
     # be unsafe. In some instances the test suite uses
     # `C:\Windows\Temp\salt-tests-tmpdir\rootdir` as the file_roots. So, we need
@@ -614,27 +605,74 @@ def win_verify_env(path, dirs, permissive=False, pki_dir="", skip_extra=False):
     allow_path = "\\".join([system_root, "TEMP"])
     if not salt.utils.path.safe_path(path=path, allow_path=allow_path):
         raise CommandExecutionError(
-            "`file_roots` set to a possibly unsafe location: {}".format(path)
+            f"`file_roots` set to a possibly unsafe location: {path}"
         )
 
     # Create the root path directory if missing
     if not os.path.isdir(path):
         os.makedirs(path)
 
-    # Set permissions to the root path directory
     current_user = salt.utils.win_functions.get_current_user()
+    # Set permissions to the registry key
+    if salt.utils.win_functions.is_admin(current_user):
+        reg_path = "HKLM\\SOFTWARE\\Salt Project\\salt"
+        if not salt.utils.win_reg.key_exists(
+            hive="HKLM", key="SOFTWARE\\Salt Project\\salt"
+        ):
+            salt.utils.win_reg.set_value(
+                hive="HKLM", key="SOFTWARE\\Salt Project\\salt"
+            )
+        try:
+            # Make the Administrators group owner
+            # Use the SID to be locale agnostic
+            salt.utils.win_dacl.set_owner(
+                obj_name=reg_path, principal="S-1-5-32-544", obj_type="registry"
+            )
+        except CommandExecutionError:
+            log.critical("Unable to securely set the owner of '%s'.", reg_path)
+
+        try:
+            # Get a clean dacl by not passing an obj_name
+            dacl = salt.utils.win_dacl.dacl(obj_type="registry")
+
+            # Add aces to the dacl, use the GUID (locale non-specific)
+            # Administrators Group
+            dacl.add_ace(
+                principal="S-1-5-32-544",
+                access_mode="grant",
+                permissions="full_control",
+                applies_to="this_key_subkeys",
+            )
+            # System
+            dacl.add_ace(
+                principal="S-1-5-18",
+                access_mode="grant",
+                permissions="full_control",
+                applies_to="this_key_subkeys",
+            )
+            # Owner
+            dacl.add_ace(
+                principal="S-1-3-4",
+                access_mode="grant",
+                permissions="full_control",
+                applies_to="this_key_subkeys",
+            )
+
+            # Save the dacl to the object
+            dacl.save(obj_name=reg_path, protected=True)
+
+        except CommandExecutionError:
+            log.critical("Unable to securely set the permissions of '%s'.", reg_path)
+
+    # Set permissions to the root path directory
     if salt.utils.win_functions.is_admin(current_user):
         try:
             # Make the Administrators group owner
             # Use the SID to be locale agnostic
-            salt.utils.win_dacl.set_owner(path, "S-1-5-32-544")
+            salt.utils.win_dacl.set_owner(obj_name=path, principal="S-1-5-32-544")
 
         except CommandExecutionError:
-            msg = 'Unable to securely set the owner of "{}".'.format(path)
-            if is_console_configured():
-                log.critical(msg)
-            else:
-                sys.stderr.write("CRITICAL: {}\n".format(msg))
+            log.critical('Unable to securely set the owner of "%s".', path)
 
         if not permissive:
             try:
@@ -644,29 +682,31 @@ def win_verify_env(path, dirs, permissive=False, pki_dir="", skip_extra=False):
                 # Add aces to the dacl, use the GUID (locale non-specific)
                 # Administrators Group
                 dacl.add_ace(
-                    "S-1-5-32-544",
-                    "grant",
-                    "full_control",
-                    "this_folder_subfolders_files",
+                    principal="S-1-5-32-544",
+                    access_mode="grant",
+                    permissions="full_control",
+                    applies_to="this_folder_subfolders_files",
                 )
                 # System
                 dacl.add_ace(
-                    "S-1-5-18", "grant", "full_control", "this_folder_subfolders_files"
+                    principal="S-1-5-18",
+                    access_mode="grant",
+                    permissions="full_control",
+                    applies_to="this_folder_subfolders_files",
                 )
                 # Owner
                 dacl.add_ace(
-                    "S-1-3-4", "grant", "full_control", "this_folder_subfolders_files"
+                    principal="S-1-3-4",
+                    access_mode="grant",
+                    permissions="full_control",
+                    applies_to="this_folder_subfolders_files",
                 )
 
                 # Save the dacl to the object
-                dacl.save(path, True)
+                dacl.save(obj_name=path, protected=True)
 
             except CommandExecutionError:
-                msg = "Unable to securely set the permissions of " '"{}".'.format(path)
-                if is_console_configured():
-                    log.critical(msg)
-                else:
-                    sys.stderr.write("CRITICAL: {}\n".format(msg))
+                log.critical("Unable to securely set the permissions of '%s'", path)
 
     # Create the directories
     for dir_ in dirs:
@@ -684,7 +724,7 @@ def win_verify_env(path, dirs, permissive=False, pki_dir="", skip_extra=False):
         if dir_ == pki_dir:
             try:
                 # Make Administrators group the owner
-                salt.utils.win_dacl.set_owner(path, "S-1-5-32-544")
+                salt.utils.win_dacl.set_owner(obj_name=path, principal="S-1-5-32-544")
 
                 # Give Admins, System and Owner permissions
                 # Get a clean dacl by not passing an obj_name
@@ -693,30 +733,31 @@ def win_verify_env(path, dirs, permissive=False, pki_dir="", skip_extra=False):
                 # Add aces to the dacl, use the GUID (locale non-specific)
                 # Administrators Group
                 dacl.add_ace(
-                    "S-1-5-32-544",
-                    "grant",
-                    "full_control",
-                    "this_folder_subfolders_files",
+                    principal="S-1-5-32-544",
+                    access_mode="grant",
+                    permissions="full_control",
+                    applies_to="this_folder_subfolders_files",
                 )
                 # System
                 dacl.add_ace(
-                    "S-1-5-18", "grant", "full_control", "this_folder_subfolders_files"
+                    principal="S-1-5-18",
+                    access_mode="grant",
+                    permissions="full_control",
+                    applies_to="this_folder_subfolders_files",
                 )
                 # Owner
                 dacl.add_ace(
-                    "S-1-3-4", "grant", "full_control", "this_folder_subfolders_files"
+                    principal="S-1-3-4",
+                    access_mode="grant",
+                    permissions="full_control",
+                    applies_to="this_folder_subfolders_files",
                 )
 
                 # Save the dacl to the object
-                dacl.save(dir_, True)
+                dacl.save(obj_name=dir_, protected=True)
 
             except CommandExecutionError:
-                msg = 'Unable to securely set the permissions of "{0}".'
-                msg = msg.format(dir_)
-                if is_console_configured():
-                    log.critical(msg)
-                else:
-                    sys.stderr.write("CRITICAL: {}\n".format(msg))
+                log.critical("Unable to securely set the permissions of '%s'.", dir_)
 
     if skip_extra is False:
         # Run the extra verification checks
