@@ -1,87 +1,103 @@
-# -*- coding: utf-8 -*-
 """
-    :copyright: Copyright 2017 by the SaltStack Team, see AUTHORS for more details.
-    :license: Apache 2.0, see LICENSE for more details.
-
-
     salt.utils.versions
     ~~~~~~~~~~~~~~~~~~~
 
-    Version parsing based on distutils.version which works under python 3
-    because on python 3 you can no longer compare strings against integers.
+    Version parsing based on `packaging.version` and `looseversion.LooseVersion`
+    which works under python 3 because on python 3 you can no longer compare
+    strings against integers.
 """
 
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
-import contextlib
 import datetime
 import inspect
 import logging
 import numbers
+import os
 import sys
 import warnings
 
-# pylint: disable=blacklisted-module,no-name-in-module
-from distutils.version import LooseVersion as _LooseVersion
-from distutils.version import StrictVersion as _StrictVersion
+import looseversion
+import packaging.version
 
-# Import Salt libs
 import salt.version
 
-# Import 3rd-party libs
-from salt.ext import six
-
-# pylint: enable=blacklisted-module,no-name-in-module
-
-
 log = logging.getLogger(__name__)
 
 
-class StrictVersion(_StrictVersion):
+class Version(packaging.version.Version):
+    def __lt__(self, other):
+        if isinstance(other, str):
+            other = Version(other)
+        return super().__lt__(other)
+
+    def __le__(self, other):
+        if isinstance(other, str):
+            other = Version(other)
+        return super().__le__(other)
+
+    def __eq__(self, other):
+        if isinstance(other, str):
+            other = Version(other)
+        return super().__eq__(other)
+
+    def __ge__(self, other):
+        if isinstance(other, str):
+            other = Version(other)
+        return super().__ge__(other)
+
+    def __gt__(self, other):
+        if isinstance(other, str):
+            other = Version(other)
+        return super().__gt__(other)
+
+    def __ne__(self, other):
+        if isinstance(other, str):
+            other = Version(other)
+        return super().__ne__(other)
+
+
+class StrictVersion(Version):
+    def __init__(self, *args, **kwargs):
+        warn_until(
+            3008,
+            f"'{__name__}.StrictVersion' is no longer a subclass of "
+            "'distutils.versions.StrictVersion'. It's usage has been "
+            "deprecated and should no longer be used. Please switch to "
+            f"'{__name__}.Version' which is a subclass of "
+            f"'packaging.version.Version'. '{__name__}.StrictVersion' will "
+            "be removed in {version}.",
+        )
+        super().__init__(*args, **kwargs)
+
+
+class LooseVersion(looseversion.LooseVersion):
     def parse(self, vstring):
-        _StrictVersion.parse(self, vstring)
+        super().parse(vstring)
+        # Convert every part of the version to string in order to be able to compare
+        self._str_version = [
+            str(vp).zfill(8) if isinstance(vp, int) else vp for vp in self.version
+        ]
 
     def _cmp(self, other):
-        if isinstance(other, six.string_types):
-            other = StrictVersion(other)
-        return _StrictVersion._cmp(self, other)
+        if isinstance(other, str):
+            other = LooseVersion(other)
 
+        string_in_version = False
+        for part in self.version + other.version:
+            if not isinstance(part, int):
+                string_in_version = True
+                break
 
-class LooseVersion(_LooseVersion):
-    def parse(self, vstring):
-        _LooseVersion.parse(self, vstring)
+        if string_in_version is False:
+            return super()._cmp(other)
 
-        if six.PY3:
-            # Convert every part of the version to string in order to be able to compare
-            self._str_version = [
-                six.text_type(vp).zfill(8) if isinstance(vp, int) else vp
-                for vp in self.version
-            ]
-
-    if six.PY3:
-
-        def _cmp(self, other):
-            if isinstance(other, six.string_types):
-                other = LooseVersion(other)
-
-            string_in_version = False
-            for part in self.version + other.version:
-                if not isinstance(part, int):
-                    string_in_version = True
-                    break
-
-            if string_in_version is False:
-                return _LooseVersion._cmp(self, other)
-
-            # If we reached this far, it means at least a part of the version contains a string
-            # In python 3, strings and integers are not comparable
-            if self._str_version == other._str_version:
-                return 0
-            if self._str_version < other._str_version:
-                return -1
-            if self._str_version > other._str_version:
-                return 1
+        # If we reached this far, it means at least a part of the version contains a string
+        # In python 3, strings and integers are not comparable
+        if self._str_version == other._str_version:
+            return 0
+        if self._str_version < other._str_version:
+            return -1
+        if self._str_version > other._str_version:
+            return 1
 
 
 def _format_warning(message, category, filename, lineno, line=None):
@@ -89,19 +105,7 @@ def _format_warning(message, category, filename, lineno, line=None):
     Replacement for warnings.formatwarning that disables the echoing of
     the 'line' parameter.
     """
-    return "{}:{}: {}: {}\n".format(filename, lineno, category.__name__, message)
-
-
-@contextlib.contextmanager
-def _patched_format_warning():
-    if six.PY2:
-        saved = warnings.formatwarning
-        warnings.formatwarning = _format_warning
-        yield
-        warnings.formatwarning = saved
-    else:
-        # Under Py3 we no longer have to patch warnings.formatwarning
-        yield
+    return f"{filename}:{lineno}: {category.__name__}: {message}\n"
 
 
 def warn_until(
@@ -118,9 +122,9 @@ def warn_until(
     be raised to remind the developers to remove the warning because the
     target version has been reached.
 
-    :param version: The version info or name after which the warning becomes a
-                    ``RuntimeError``. For example ``(0, 17)`` or ``Hydrogen``
-                    or an instance of :class:`salt.version.SaltStackVersion`.
+    :param version: The version info or name after which the warning becomes a ``RuntimeError``.
+                    For example ``(2019, 2)``, ``3000``, ``Hydrogen`` or an instance of
+                    :class:`salt.version.SaltStackVersion` or :class:`salt.version.SaltVersion`.
     :param message: The warning message to be displayed.
     :param category: The warning class to be thrown, by default
                      ``DeprecationWarning``
@@ -134,17 +138,27 @@ def warn_until(
                                 issued. When we're only after the salt version
                                 checks to raise a ``RuntimeError``.
     """
-    if not isinstance(
-        version, (tuple, six.string_types, salt.version.SaltStackVersion)
-    ):
-        raise RuntimeError(
-            "The 'version' argument should be passed as a tuple, string or "
-            "an instance of 'salt.version.SaltStackVersion'."
-        )
+    if isinstance(version, salt.version.SaltVersion):
+        version = salt.version.SaltStackVersion(*version.info)
+    elif isinstance(version, int):
+        version = salt.version.SaltStackVersion(version)
     elif isinstance(version, tuple):
         version = salt.version.SaltStackVersion(*version)
-    elif isinstance(version, six.string_types):
+    elif isinstance(version, str):
+        if version.lower() not in salt.version.SaltStackVersion.LNAMES:
+            raise RuntimeError(
+                "Incorrect spelling for the release name in the warn_utils "
+                "call. Expecting one of these release names: {}".format(
+                    [vs.name for vs in salt.version.SaltVersionsInfo.versions()]
+                )
+            )
         version = salt.version.SaltStackVersion.from_name(version)
+    elif not isinstance(version, salt.version.SaltStackVersion):
+        raise RuntimeError(
+            "The 'version' argument should be passed as a tuple, integer, string or "
+            "an instance of 'salt.version.SaltVersion' or "
+            "'salt.version.SaltStackVersion'."
+        )
 
     if stacklevel is None:
         # Attribute the warning to the calling function, not to warn_until()
@@ -157,7 +171,7 @@ def warn_until(
 
     if _version_ >= version:
         caller = inspect.getframeinfo(sys._getframe(stacklevel - 1))
-        raise RuntimeError(
+        deprecated_message = (
             "The warning triggered on filename '{filename}', line number "
             "{lineno}, is supposed to be shown until version "
             "{until_version} is released. Current version is now "
@@ -166,16 +180,22 @@ def warn_until(
                 lineno=caller.lineno,
                 until_version=version.formatted_version,
                 salt_version=_version_.formatted_version,
-            ),
+            )
         )
+        if os.environ.get("RAISE_DEPRECATIONS_RUNTIME_ERRORS", "0") == "1":
+            # We don't raise RuntimeError by default since that can break
+            # users systems. We do however want to raise them in a CI context.
+            raise RuntimeError(deprecated_message)
+        # Otherwise, print the deprecated message to STDERR
+        sys.stderr.write(f"\n{deprecated_message}\n")
+        sys.stderr.flush()
 
     if _dont_call_warnings is False:
-        with _patched_format_warning():
-            warnings.warn(
-                message.format(version=version.formatted_version),
-                category,
-                stacklevel=stacklevel,
-            )
+        warnings.warn(
+            message.format(version=version.formatted_version),
+            category,
+            stacklevel=stacklevel,
+        )
 
 
 def warn_until_date(
@@ -204,7 +224,7 @@ def warn_until_date(
                                 checks to raise a ``RuntimeError``.
     """
     _strptime_fmt = "%Y%m%d"
-    if not isinstance(date, (six.string_types, datetime.date, datetime.datetime)):
+    if not isinstance(date, (str, datetime.date, datetime.datetime)):
         raise RuntimeError(
             "The 'date' argument should be passed as a 'datetime.date()' or "
             "'datetime.datetime()' objects or as string parserable by "
@@ -212,7 +232,7 @@ def warn_until_date(
                 _strptime_fmt
             )
         )
-    elif isinstance(date, six.text_type):
+    elif isinstance(date, str):
         date = datetime.datetime.strptime(date, _strptime_fmt)
 
     # We're really not interested in the time
@@ -226,7 +246,7 @@ def warn_until_date(
     today = _current_date or datetime.datetime.utcnow().date()
     if today >= date:
         caller = inspect.getframeinfo(sys._getframe(stacklevel - 1))
-        raise RuntimeError(
+        deprecated_message = (
             "{message} This warning(now exception) triggered on "
             "filename '{filename}', line number {lineno}, is "
             "supposed to be shown until {date}. Today is {today}. "
@@ -238,14 +258,20 @@ def warn_until_date(
                 today=today.isoformat(),
             ),
         )
+        if os.environ.get("RAISE_DEPRECATIONS_RUNTIME_ERRORS", "0") == "1":
+            # We don't raise RuntimeError by default since that can break
+            # users systems. We do however want to raise them in a CI context.
+            raise RuntimeError(deprecated_message)
+        # Otherwise, print the deprecated message to STDERR
+        sys.stderr.write(f"\n{deprecated_message}\n")
+        sys.stderr.flush()
 
     if _dont_call_warnings is False:
-        with _patched_format_warning():
-            warnings.warn(
-                message.format(date=date.isoformat(), today=today.isoformat()),
-                category,
-                stacklevel=stacklevel,
-            )
+        warnings.warn(
+            message.format(date=date.isoformat(), today=today.isoformat()),
+            category,
+            stacklevel=stacklevel,
+        )
 
 
 def kwargs_warn_until(
@@ -284,16 +310,14 @@ def kwargs_warn_until(
                                 issued. When we're only after the salt version
                                 checks to raise a ``RuntimeError``.
     """
-    if not isinstance(
-        version, (tuple, six.string_types, salt.version.SaltStackVersion)
-    ):
+    if not isinstance(version, (tuple, str, salt.version.SaltStackVersion)):
         raise RuntimeError(
             "The 'version' argument should be passed as a tuple, string or "
             "an instance of 'salt.version.SaltStackVersion'."
         )
     elif isinstance(version, tuple):
         version = salt.version.SaltStackVersion(*version)
-    elif isinstance(version, six.string_types):
+    elif isinstance(version, str):
         version = salt.version.SaltStackVersion.from_name(version)
 
     if stacklevel is None:
@@ -307,11 +331,13 @@ def kwargs_warn_until(
     _version_ = salt.version.SaltStackVersion(*_version_info_)
 
     if kwargs or _version_.info >= version.info:
-        arg_names = ", ".join("'{0}'".format(key) for key in kwargs)
+        arg_names = ", ".join(f"'{key}'" for key in kwargs)
         warn_until(
             version,
-            message="The following parameter(s) have been deprecated and "
-            "will be removed in '{0}': {1}.".format(version.string, arg_names),
+            message=(
+                "The following parameter(s) have been deprecated and "
+                "will be removed in '{}': {}.".format(version.string, arg_names)
+            ),
             category=category,
             stacklevel=stacklevel,
             _version_info_=_version_.info,
@@ -321,17 +347,16 @@ def kwargs_warn_until(
 
 def version_cmp(pkg1, pkg2, ignore_epoch=False):
     """
-    Compares two version strings using salt.utils.versions.LooseVersion. This
+    Compares two version strings using `LooseVersion`. This
     is a fallback for providers which don't have a version comparison utility
     built into them.  Return -1 if version1 < version2, 0 if version1 ==
     version2, and 1 if version1 > version2. Return None if there was a problem
     making the comparison.
     """
-    normalize = (
-        lambda x: six.text_type(x).split(":", 1)[-1]
-        if ignore_epoch
-        else six.text_type(x)
-    )
+
+    def normalize(x):
+        return str(x).split(":", 1)[-1] if ignore_epoch else str(x)
+
     pkg1 = normalize(pkg1)
     pkg2 = normalize(pkg2)
 
@@ -367,7 +392,7 @@ def compare(ver1="", oper="==", ver2="", cmp_func=None, ignore_epoch=False):
 
     # Check if integer/long
     if not isinstance(cmp_result, numbers.Integral):
-        log.error("The version comparison function did not return an " "integer/long.")
+        log.error("The version comparison function did not return an integer/long.")
         return False
 
     if oper == "!=":
@@ -425,7 +450,7 @@ def check_boto_reqs(
             boto_ver = "2.0.0"
 
         if not has_boto or version_cmp(boto.__version__, boto_ver) == -1:
-            return False, "A minimum version of boto {0} is required.".format(boto_ver)
+            return False, f"A minimum version of boto {boto_ver} is required."
 
     if check_boto3 is True:
         try:
@@ -447,12 +472,12 @@ def check_boto_reqs(
         if not has_boto3 or version_cmp(boto3.__version__, boto3_ver) == -1:
             return (
                 False,
-                "A minimum version of boto3 {0} is required.".format(boto3_ver),
+                f"A minimum version of boto3 {boto3_ver} is required.",
             )
         elif version_cmp(botocore.__version__, botocore_ver) == -1:
             return (
                 False,
-                "A minimum version of botocore {0} is required".format(botocore_ver),
+                f"A minimum version of botocore {botocore_ver} is required",
             )
 
     return True
