@@ -322,7 +322,7 @@ def call(method, *args, **kwargs):
         napalm_device,  # pylint: disable=undefined-variable
         method,
         *args,
-        **clean_kwargs
+        **clean_kwargs,
     )
 
 
@@ -561,7 +561,7 @@ def netmiko_fun(fun, *args, **kwargs):
         salt '*' napalm.netmiko_fun send_command 'show version'
     """
     if "netmiko." not in fun:
-        fun = "netmiko.{fun}".format(fun=fun)
+        fun = f"netmiko.{fun}"
     netmiko_kwargs = netmiko_args()
     kwargs.update(netmiko_kwargs)
     return __salt__[fun](*args, **kwargs)
@@ -1038,14 +1038,14 @@ def junos_call(fun, *args, **kwargs):
     if not prep["result"]:
         return prep
     if "junos." not in fun:
-        mod_fun = "junos.{}".format(fun)
+        mod_fun = f"junos.{fun}"
     else:
         mod_fun = fun
     if mod_fun not in __salt__:
         return {
             "out": None,
             "result": False,
-            "comment": "{} is not a valid function".format(fun),
+            "comment": f"{fun} is not a valid function",
         }
     return __salt__[mod_fun](*args, **kwargs)
 
@@ -1177,7 +1177,7 @@ def pyeapi_config(
     context=None,
     defaults=None,
     saltenv="base",
-    **kwargs
+    **kwargs,
 ):
     """
     .. versionadded:: 2019.2.0
@@ -1235,7 +1235,7 @@ def pyeapi_config(
         context=context,
         defaults=defaults,
         saltenv=saltenv,
-        **pyeapi_kwargs
+        **pyeapi_kwargs,
     )
 
 
@@ -1271,7 +1271,7 @@ def nxos_api_config(
     context=None,
     defaults=None,
     saltenv="base",
-    **kwargs
+    **kwargs,
 ):
     """
      .. versionadded:: 2019.2.0
@@ -1327,7 +1327,7 @@ def nxos_api_config(
         context=context,
         defaults=defaults,
         saltenv=saltenv,
-        **nxos_api_kwargs
+        **nxos_api_kwargs,
     )
 
 
@@ -1915,7 +1915,7 @@ def scp_get(
         local_path=local_path,
         recursive=recursive,
         preserve_times=preserve_times,
-        **kwargs
+        **kwargs,
     )
 
 
@@ -1926,7 +1926,7 @@ def scp_put(
     recursive=False,
     preserve_times=False,
     saltenv="base",
-    **kwargs
+    **kwargs,
 ):
     """
     .. versionadded:: 2019.2.0
@@ -2021,5 +2021,5 @@ def scp_put(
         recursive=recursive,
         preserve_times=preserve_times,
         saltenv=saltenv,
-        **kwargs
+        **kwargs,
     )
